import React from "react";
import { BrowserRouter as Router, Switch, Route, Redirect } from "react-router-dom";
import ScrollToTop from "./helpers/ScrollToTop";
import HomeOne from "./pages/HomeOne";
import SuperAdmin from "./pages/superAdmin";
import Admins from "./pages/admin";
import Forum from "./pages/Forum";
import Answers from "./pages/Answers";
import Home from "./pages/home";
import NewsAndArticles from "./pages/newsAndArticles";
import MyProfile from "./pages/myProfile";
import NotFound from "./pages/NotFound";
import { useContext } from "react";
import { AuthContext } from "./context/AuthContext";
import ArticleDetails from "./pages/ArticleDetails";
import Publications from "./pages/publications";
import Notifications from "./pages/notifications";
import Experts from "./pages/experts";
import ChangePwd from "./pages/changePwd";
import VerifyUser from "./pages/VerifyUser";
function App() {
  const { user } = useContext(AuthContext);

  return (
    <Router>
      <ScrollToTop>
        <Switch>
          <Route exact path={`${process.env.PUBLIC_URL + "/"}`}>
            {user && user.userType === "super-admin" ? <Redirect to="/superAdminDashboard" /> : user && user.userType === "admin" ? <Redirect to="/admin" /> : user?<Redirect to="/home"/> : <HomeOne changePwd=""/>}
          </Route>
          <Route exact path={`${process.env.PUBLIC_URL + "/changepassword/:userToken"}`}>
            {user && user.userType === "super-admin" ? <Redirect to="/superAdminDashboard" /> : user && user.userType === "admin" ? <Redirect to="/admin" /> : user?<Redirect to="/home"/> : <ChangePwd />}
          </Route>
          <Route
            path={`${process.env.PUBLIC_URL + "/home-one"}`}
            component={HomeOne}
          />
          <Route path="/superAdminDashboard">
            {user && user.userType === "super-admin" ? <SuperAdmin /> : user && user.userType === "admin" ? <Redirect to="/admin" /> : <Redirect to="/login" />}
          </Route>
          <Route path="/admin">
            {user && user.userType === "admin" ? <Admins /> : user && user.userType === "super-admin" ? <SuperAdmin /> : <Redirect to="/login" />}
          </Route>
          <Route path="/community">
            {user && user.userType === "admin" ? <Admins /> : user && user.userType === "super-admin" ? <SuperAdmin /> :<Forum/>}
          </Route>
          <Route path="/home">
            {user && user.userType === "admin" ? <Admins /> : user && user.userType === "super-admin" ? <SuperAdmin /> :<Home/>}
          </Route>
          <Route path="/news">
            {user && user.userType === "admin" ? <Admins /> : user && user.userType === "super-admin" ? <SuperAdmin /> :<NewsAndArticles/>}
          </Route>
          <Route path="/articles/:articleId">
            {user && user.userType === "admin" ? <Admins /> : user && user.userType === "super-admin" ? <SuperAdmin /> :<ArticleDetails/>}
          </Route>
          <Route path="/answers/:questionId">
            {user && user.userType === "admin" ? <Admins /> : user && user.userType === "super-admin" ? <SuperAdmin /> :<Answers />}
          </Route>
          <Route path="/publications">
            {user && user.userType === "admin" ? <Admins /> : user && user.userType === "super-admin" ? <SuperAdmin /> :<Publications />}
          </Route>
          <Route path="/notifications">
            {user && user.userType === "admin" ? <Admins /> : user && user.userType === "super-admin" ? <SuperAdmin /> :<Notifications />}
          </Route>
          <Route path="/experts">
            {user && user.userType === "admin" ? <Admins /> : user && user.userType === "super-admin" ? <SuperAdmin /> :<Experts />}
          </Route>
          <Route path="/myprofile/:id">
            {user ? <MyProfile />  : <Redirect to="/login" />}
          </Route>
          <Route
            path={`${process.env.PUBLIC_URL + "/not-found"}`}
            component={NotFound}
          />
          <Route
            path={`${process.env.PUBLIC_URL + "/verify/:token"}`}
            component={VerifyUser}
          />
          <Route exact component={NotFound} />
        </Switch>
      </ScrollToTop>
    </Router>
  );
}

export default App;
