import React,{useState,useContext} from "react";
import { Cancel, Comment, Delete,Edit, MoreHoriz, Report, ThumbsUpDownRounded, ThumbUp } from "@material-ui/icons";
import Menu from "@material-ui/core/Menu";
import MenuItem from '@material-ui/core/MenuItem';
import { Button, Modal } from "react-bootstrap";
import IconButton from "@material-ui/core/IconButton";
import { AuthContext } from "../../context/AuthContext";
import axios from "axios";
import { format } from "timeago.js";

const Comments = ({c, article, fetchArticle, index}) => {
    let { user } = useContext(AuthContext);
    const [isReadMore, setIsReadMore] = useState(true);
    const [anchorEl, setAnchorEl] = useState(null);
    const open = Boolean(anchorEl);
    const [showEditModal, setShowEditModal] = useState(false);
    const [toggleEdit, setToggleEdit] = useState(false);
    const [editvalue, setEditvalue] = useState(null);

    if (!user) {
        user = {
            userId: 123,
            username: "Guest",
            userType: "Guest"
        }
    }
    
    const toggleReadMore = (index) => {
        setIsReadMore(!isReadMore);
    };

    function keyPressEnter(e){
        console.log(e.keyCode == 13 && e.shiftKey)
        if(e.keyCode == 13 && e.shiftKey)
        {}
        else if(e.key === "Enter")
        {
            updateComment(index)
        }
    }
    function commentValue () {
        if(!toggleEdit && c.comment){
            return(
                c.comment.length >= 150 ? 
                    <div>{isReadMore ? c.comment.slice(0, 150) : c.comment}
                        <span  onClick={()=>toggleReadMore(index)} className="read-or-hide">
                            {isReadMore ? "...read more" : " show less"}
                        </span>
                    </div> : 
                    <span>{c.comment}</span>
            );
        }
        else{
            return(
                <div className="d-flex">
                    <textarea 
                        className="form-control"
                        id="new_question"
                        rows="2"
                        value={editvalue===null?c.comment:editvalue}
                        onKeyDown={(e)=>keyPressEnter(e)}
                        onChange={(e) => { setEditvalue(e.target.value);}}>
                    </textarea>
                    <Cancel className="cursor" onClick={()=>{setToggleEdit(false); setEditvalue(null)}}/>
                    {/* // <Button variant="primary" onClick={()=>{updateComment(index)}}>
                    //     Update
                    // </Button> */}
                </div>
                
            );
        }
    }
    //------- Handling Menu 
    const handleMenuClick = (event) => {
        setAnchorEl(event.currentTarget);
    };
    const handleMenuClose = () => {
        setAnchorEl(null);
    };

    //------- Handling Edit Modal
    const handleEditModalOpen = () => {
        setShowEditModal(true)
    };
    const handleEditModalClose = () => {
        setEditvalue(null);
        setShowEditModal(false);
    };
    const deleteComment = async (index) => {
        console.log("-------------->>",index);
        article.comments.splice(index,1);
        try {
            await axios.put(`${process.env.REACT_APP_BACKEND_URL}/api/newsandarticles/` + article._id + `/comments`, article)
        }catch(err){
            console.log(err)
        }
        fetchArticle();
    }

    //-------- Update Comment
    const updateComment = async (index) => {
        article.comments[index].comment = editvalue;
        try{
            await axios.put(`${process.env.REACT_APP_BACKEND_URL}/api/newsandarticles/` + article._id + `/comments`, article)
        }catch(err){
            console.log("Error in deleting comment ", err);
        }
        setToggleEdit(false);
        // handleEditModalClose();
    }
    return (
        <div className="row no-gutters m-2 py-3 ca_comment_wrapper">
            <div className="col-1">
                <img src={c.userImage ? process.env.REACT_APP_BACKEND_URL + c.profilePicture : process.env.REACT_APP_BACKEND_URL + process.env.REACT_APP_ProfileAvathar_Url} className="userDetails"/>
            </div>
            <div className="col-11">
                <div className="row">
                    <div className="col-2">
                        <span style={{"fontSize" : "1.1rem", "fontWeight" : "600"}}>{c.username}</span>
                    </div>
                    <div className="col-10">
                        <span style={{"fontWeight" : "300", "fontSize" : "0.8rem", "float" : "right"}}>{format(c.createdAt)}</span>
                    </div>
                </div>
                <div className="row">
                    <div className="col-10" style={{"color" : "#7b7b7b", "fontSize" : "0.95rem", "fontWeight" : "400"}}>
                        {commentValue()}
                    </div>
                    <div className="col-2">
                        <IconButton
                                    onClick={handleMenuClick}
                                    size="small"
                                    sx={{ ml: 2 }}
                                    aria-controls={open ? 'account-menu' : undefined}
                                    aria-haspopup="true"
                                    aria-expanded={open ? 'true' : undefined}
                                    style={{"float" : "right"}}
                                >
                                    <MoreHoriz />
                                </IconButton>
                                <Menu
                                    anchorEl={anchorEl}
                                    getContentAnchorEl={null}
                                    id="account-menu"
                                    open={open}
                                    onClose={handleMenuClose}
                                    onClick={handleMenuClose}
                                    PaperProps={{
                                        elevation: 0,
                                        sx: {
                                            overflow: 'visible',
                                            filter: 'drop-shadow(0px 2px 8px rgba(0,0,0,0.32))',
                                            mt: 1.5,
                                            '& .MuiAvatar-root': {
                                                width: 32,
                                                height: 32,
                                                ml: -0.5,
                                                mr: 1,
                                            },
                                            '&:before': {
                                                content: '""',
                                                display: 'block',
                                                position: 'absolute',
                                                top: 0,
                                                right: 14,
                                                width: 10,
                                                height: 10,
                                                bgcolor: 'background.paper',
                                                transform: 'translateY(-50%) rotate(45deg)',
                                                zIndex: 0,
                                            },
                                        },
                                    }}
                                    transformOrigin={{ horizontal: 'right', vertical: 'top' }}
                                    anchorOrigin={{ horizontal: 'right', vertical: 'bottom' }}
                                >
                                    {(c.userId === user._id) && (user.userType !== "Guest") ?
                                        <MenuItem onClick={()=>setToggleEdit(!toggleEdit)}>
                                            <svg version="1.1" id="Layer_1" width="20px" xmlns="http://www.w3.org/2000/svg" xmlnsXlink="http://www.w3.org/1999/xlink" x="0px" y="0px"
                                                viewBox="0 0 120 120" enableBackground="new 0 0 120 120" xmlSpace="preserve">
                                                <path id="Icon_material-edit" fill="#07BEB8" d="M5.1,92.7V116H28l67.4-68.8L72.5,23.8L5.1,92.7z M113.1,29.1c2.4-2.4,2.4-6.3,0-8.8
                                                    L98.8,5.8c-2.3-2.4-6.1-2.4-8.5-0.1c0,0-0.1,0.1-0.1,0.1L79.1,17.2L102,40.5L113.1,29.1L113.1,29.1z"/>
                                            </svg> Edit
                                        </MenuItem> :
                                        <div></div>
                                    }
                                    {(c.userId === user._id) && (user.userType !== "Guest") ?
                                        <MenuItem onClick={()=>{deleteComment(index)}}>
                                            <Delete /> Delete
                                        </MenuItem> :
                                        <div></div>
                                    }
                                    <MenuItem>
                                        <Report /> Report
                                    </MenuItem>
                                </Menu>
                            
                            <Modal
                                    show={showEditModal}
                                    onHide={handleEditModalClose}
                                    size="md"
                                    aria-labelledby="contained-modal-title-vcenter"
                                    centered
                                >
                                    <Modal.Header >
                                        <Modal.Title>Edit</Modal.Title>
                                    </Modal.Header>
                                    <Modal.Body>
                                        <textarea
                                            class="form-control"
                                            id="new_question"
                                            rows="2"
                                            value={editvalue===null?c.comment:editvalue}
                                            onChange={(e) => { setEditvalue(e.target.value);}}>
                                        </textarea>
                                    </Modal.Body>
                                    <Modal.Footer>
                                        <Button variant="secondary" onClick={handleEditModalClose}>
                                            Close
                                        </Button>
                                        <Button variant="primary" onClick={()=>{updateComment(index)}}>
                                            Update
                                        </Button>
                                    </Modal.Footer>
                            </Modal>       
                    </div>
                </div>
            </div>
        </div>
        
                    // <div className="ca_comment_wrapper row m-2 px-0" style={{"columnGap" : "20px"}}>
                    //     <div className="col-3 row">
                    //         <div className="col-4 ca_padding">
                    //             <img src={c.userImage ? process.env.REACT_APP_BACKEND_URL + c.profilePicture : process.env.REACT_APP_BACKEND_URL + process.env.REACT_APP_ProfileAvathar_Url} className="userDetails"/>
                    //         </div>
                    //         <div className="col-8 ca_padding">
                    //             <div className="col-12 row ">
                    //                 <span>{c.username}</span>
                    //             </div>
                    //             <div className="col-12 row ">
                    //                 <span>{c.userJob}</span>
                    //             </div>
                    //         </div>
                    //         {/* <span>{c.username}</span> */}
                    //     </div>
                    //     <div className="col-9 row">                        
                    //         <div className="col-9">
                    //             {commentValue()}
                    //             {/* {c.comment.length >= 150 ? 
                    //                 <div>{isReadMore ? c.comment.slice(0, 150) : c.comment}
                    //                     <span  onClick={()=>toggleReadMore(index)} className="read-or-hide">
                    //                         {isReadMore ? "...read more" : " show less"}
                    //                     </span></div> : 
                    //             <span>{c.comment}</span> } */}
                    //         </div>
                    //         <div className="col-2">
                    //             <span style={{"fontWeight" : "300", "fontSize" : "0.7rem"}}>{format(c.createdAt)}</span>
                    //         </div>
                    //         <div className="col-1">
                            //     <IconButton
                            //         onClick={handleMenuClick}
                            //         size="small"
                            //         sx={{ ml: 2 }}
                            //         aria-controls={open ? 'account-menu' : undefined}
                            //         aria-haspopup="true"
                            //         aria-expanded={open ? 'true' : undefined}
                            //     >
                            //         <MoreHoriz />
                            //     </IconButton>
                            //     <Menu
                            //         anchorEl={anchorEl}
                            //         getContentAnchorEl={null}
                            //         id="account-menu"
                            //         open={open}
                            //         onClose={handleMenuClose}
                            //         onClick={handleMenuClose}
                            //         PaperProps={{
                            //             elevation: 0,
                            //             sx: {
                            //                 overflow: 'visible',
                            //                 filter: 'drop-shadow(0px 2px 8px rgba(0,0,0,0.32))',
                            //                 mt: 1.5,
                            //                 '& .MuiAvatar-root': {
                            //                     width: 32,
                            //                     height: 32,
                            //                     ml: -0.5,
                            //                     mr: 1,
                            //                 },
                            //                 '&:before': {
                            //                     content: '""',
                            //                     display: 'block',
                            //                     position: 'absolute',
                            //                     top: 0,
                            //                     right: 14,
                            //                     width: 10,
                            //                     height: 10,
                            //                     bgcolor: 'background.paper',
                            //                     transform: 'translateY(-50%) rotate(45deg)',
                            //                     zIndex: 0,
                            //                 },
                            //             },
                            //         }}
                            //         transformOrigin={{ horizontal: 'right', vertical: 'top' }}
                            //         anchorOrigin={{ horizontal: 'right', vertical: 'bottom' }}
                            //     >
                            //         {(c.userId === user._id) && (user.userType !== "Guest") ?
                            //             <MenuItem onClick={()=>setToggleEdit(!toggleEdit)}>
                            //                 <Edit /> Edit
                            //             </MenuItem> :
                            //             <div></div>
                            //         }
                            //         {(c.userId === user._id) && (user.userType !== "Guest") ?
                            //             <MenuItem onClick={()=>{deleteComment(index)}}>
                            //                 <Delete /> Delete
                            //             </MenuItem> :
                            //             <div></div>
                            //         }
                            //         <MenuItem>
                            //             <Report /> Report
                            //         </MenuItem>
                            //     </Menu>
                            // </div>
                            // <Modal
                            //         show={showEditModal}
                            //         onHide={handleEditModalClose}
                            //         size="md"
                            //         aria-labelledby="contained-modal-title-vcenter"
                            //         centered
                            //     >
                            //         <Modal.Header >
                            //             <Modal.Title>Edit</Modal.Title>
                            //         </Modal.Header>
                            //         <Modal.Body>
                            //             <textarea
                            //                 class="form-control"
                            //                 id="new_question"
                            //                 rows="2"
                            //                 value={editvalue===null?c.comment:editvalue}
                            //                 onChange={(e) => { setEditvalue(e.target.value);}}>
                            //             </textarea>
                            //         </Modal.Body>
                            //         <Modal.Footer>
                            //             <Button variant="secondary" onClick={handleEditModalClose}>
                            //                 Close
                            //             </Button>
                            //             <Button variant="primary" onClick={()=>{updateComment(index)}}>
                            //                 Update
                            //             </Button>
                            //         </Modal.Footer>
                            // </Modal>                        
                    //     </div>
                    // </div>
                );
            
}

export default Comments;