import { Comment, MoreVert, ThumbsUpDownRounded, ThumbUp } from "@material-ui/icons";
import React,{useState, useContext, useEffect} from "react";
import { format } from "timeago.js";
import { Link, useHistory } from "react-router-dom";
import { MoreHoriz, Delete, Share, Done } from "@material-ui/icons";
import { IconButton } from "@material-ui/core";
import MenuItem from '@material-ui/core/MenuItem';
import Menu from "@material-ui/core/Menu";
import { AuthContext } from "../../context/AuthContext";
import axios from "axios";

const SingleArticle = ({article, fetchData}) => {
    let { user } = useContext(AuthContext);
    var time = format(article.createdAt);
    const [userData, setUserData] = useState({});
    let history = useHistory();
    const [anchorEl, setAnchorEl] = useState(null);
    const open = Boolean(anchorEl);

    const getUserData = async () => {
        var resultUser = await axios.get(`${process.env.REACT_APP_BACKEND_URL}/api/users/` + user._id + '/oneUser');
        setUserData(resultUser.data);
    }

    useEffect(()=>{
        getUserData();
    },[]);

    const handleMenuClick = (event) => {
        setAnchorEl(event.currentTarget);
    };

    const handleMenuClose = () => {
        setAnchorEl(null);
    };

    const likeHandler = async () => {
        var likes = {
            userId : user._id,
            username : user.username,
            userImage : user.profilePicture 
        };     
        try {
            await axios.put(`${process.env.REACT_APP_BACKEND_URL}/api/newsandarticles/`+ article._id + `/likes`, likes);
            
        } catch (err) {
            console.log(err, "Error in updating upvotes")
        }
        fetchData();
    }

    const deleteArticle = async () => {
        try {
            var res = await axios.delete(`${process.env.REACT_APP_BACKEND_URL}/api/newsandarticles/` + article._id);
            console.log("--------->", res)
        } catch (err) {
            console.log("Error--->", err)
        }
        if(history.location.pathname === '/news'){
            fetchData();
        }else {
            history.push('/community');
        }
        
    }
    //-----------Sharing Article
    const shareArticle = () => {
        console.log("share-------->", `${process.env.REACT_APP_FRONTEND_URL}` + '/articles/' + article._id)
    }
    //-----------Like Icon Handler
    const likeIcon = () => {
        const articleLikeLength = article.likes.length;                
        for (var k = 0; k < articleLikeLength; k++) {
            if (article.likes[k].userId == user._id) {
                break;
            }
        }
        if (k == articleLikeLength) {
            return(
                <svg version="1.1" width="25px" onClick={likeHandler} id="Layer_1" xmlns="http://www.w3.org/2000/svg" xmlnsXlink="http://www.w3.org/1999/xlink" x="0px" y="0px"
                    viewBox="0 0 120 120" enable-background="new 0 0 120 120" xmlSpace="preserve">
                    <circle id="Ellipse_404" fill="#D1D8E3" cx="60" cy="60" r="56"/>
                    <g id="noun_like_986837" transform="translate(-11 -9.973)">
                        <g id="Group_1304" transform="translate(17.383 15.29)">
                            <path id="Path_195" fill="#FFFFFF" d="M81.8,45.8c-1.9-4.2-9.9-2.9-13.3-3s-3.7-1.4-2.7-3.2c2-3.3,3.7-6.8,5.1-10.4
                                c0.8-3.8-1.1-7.6-4.6-9.1c-3.2-0.6-3.5,4.5-3.5,4.5c-0.8,6.1-6.9,11.2-8.6,13c-1.6,2.5-3,5.2-4.2,8c-1.1,1.7-2.4,3.3-3.8,4.7h-2.8
                                v23.8c1.3,1.3,2.7,2.4,4.3,3.4h28c4.8-0.8,3.4-6.9,3.4-6.9c2.1-2,2.5-5.3,1-7.7c5.1-5,1.1-9,1.1-9C83.1,51.5,83.4,48.2,81.8,45.8z
                                "/>
                            <path id="Path_196" fill="#FFFFFF" d="M39,47.1h-14c-1.1,0-1.9,0.9-1.9,1.9v27.1c0,1.1,0.9,1.9,1.9,1.9h14c1.1,0,1.9-0.9,1.9-1.9
                                l0,0V49C41,47.9,40.1,47.1,39,47.1L39,47.1z M31.5,74.3c-1.4,0-2.6-1.2-2.6-2.6s1.2-2.6,2.6-2.6c1.4,0,2.6,1.2,2.6,2.6
                                S33,74.3,31.5,74.3L31.5,74.3z"/>
                        </g>
                    </g>
                </svg>
            );
        } else {
            return (
                <svg version="1.1" width="25px" onClick={likeHandler} id="Layer_1" xmlns="http://www.w3.org/2000/svg" xmlnsXlink="http://www.w3.org/1999/xlink" x="0px" y="0px"
                    viewBox="0 0 120 120" enable-background="new 0 0 120 120" xmlSpace="preserve">
                    <g>
                        <circle id="Ellipse_404" fill="#4099FF" cx="60" cy="60" r="56"/>
                        <g id="noun_like_986837" transform="translate(-11 -9.973)">
                            <g id="Group_1304" transform="translate(17.383 15.29)">
                                <path id="Path_195" fill="#FFFFFF" d="M81.8,45.8c-1.9-4.2-9.9-2.9-13.3-3s-3.7-1.4-2.7-3.2c2-3.3,3.7-6.8,5.1-10.4
                                    c0.8-3.8-1.1-7.6-4.6-9.1c-3.2-0.6-3.5,4.5-3.5,4.5c-0.8,6.1-6.9,11.2-8.6,13c-1.6,2.5-3,5.2-4.2,8c-1.1,1.7-2.4,3.3-3.8,4.7
                                    h-2.8v23.8c1.3,1.3,2.7,2.4,4.3,3.4h28c4.8-0.8,3.4-6.9,3.4-6.9c2.1-2,2.5-5.3,1-7.7c5.1-5,1.1-9,1.1-9
                                    C83.1,51.5,83.4,48.2,81.8,45.8z"/>
                                <path id="Path_196" fill="#FFFFFF" d="M39,47.1h-14c-1.1,0-1.9,0.9-1.9,1.9v27.1c0,1.1,0.9,1.9,1.9,1.9h14c1.1,0,1.9-0.9,1.9-1.9
                                    l0,0V49C41,47.9,40.1,47.1,39,47.1L39,47.1z M31.5,74.3c-1.4,0-2.6-1.2-2.6-2.6s1.2-2.6,2.6-2.6c1.4,0,2.6,1.2,2.6,2.6
                                    S33,74.3,31.5,74.3L31.5,74.3z"/>
                            </g>
                        </g>
                    </g>
                </svg>
            );
        }
    }

    const saveIcon = () => {
        if(Object.keys(userData).length > 0){
        const savedLength = userData.saved.news.length;                
        for (var l = 0; l < savedLength; l++) {
            if (userData.saved.news[l] == article._id) {
                break;
            }
        }
        if (l == savedLength) {
            return(
                <>
                <svg version="1.1" className="cursor" width="25px"  id="Layer_1" xmlns="http://www.w3.org/2000/svg" xmlnsXlink="http://www.w3.org/1999/xlink" x="0px" y="0px"
                    viewBox="0 0 120 120" enableBackground="new 0 0 120 120" xmlSpace="preserve">
                <path id="Icon_awesome-bookmark" fill="none" stroke="#7789AC" stroke-width="10.1678" stroke-miterlimit="10" d="M23.5,108.6V20.5
                    c0-5,4.1-9.1,9.1-9.1h54.7c5,0,9.1,4.1,9.1,9.1v88.1L60,87.3L23.5,108.6z"/>
                </svg> <span className="menuOptions">Save</span>
                </>
                
            );
        } else {
            return (
                <>
                <svg version="1.1" className="cursor"  id="Layer_1" width="25px" xmlns="http://www.w3.org/2000/svg" xmlnsXlink="http://www.w3.org/1999/xlink" x="0px" y="0px"
                    viewBox="0 0 120 120" enableBackground="new 0 0 120 120" xmlSpace="preserve">
                <path id="Icon_awesome-bookmark" stroke="#7789AC" strokeWidth="3" fill="#7789AC"  d="M17,117.4v-104c0-5.9,4.8-10.8,10.8-10.8h64.5c5.9,0,10.8,4.8,10.8,10.8v104
                    L60,92.3L17,117.4z"/>
                </svg> <span className="menuOptions">Saved</span>
                </>
            );
        }
        }
    }

    const saveHandler = async () => {
        saveIcon();
        var savedData = { 
            type : "news",
            id : article._id
        }
        const savedLength = userData.saved.news.length;                
        for (var m = 0; m < savedLength; m++) {
            if (userData.saved.news[m] == article._id) {
                break;
            }
        }
        // console.log("=-=-=-=-=-=-=-===------>",user.saved)
        if(m === savedLength){
            userData.saved.news.push(article._id);
            getUserData();
        }
        else {
            userData.saved.news.splice(1,m);
            getUserData();
        }
        try {
           var result = await axios.put(`${process.env.REACT_APP_BACKEND_URL}/api/users/` + user._id + `/putSavedData`, savedData);
            fetchData();
            getUserData();
        }catch (err) {
            console.log("Error in saving Question")
        }
    }

    return(
        <div style={{}} className="">
                <div style={{ display:"flex", alignItems: 'initial', width: '100%', justifyContent: 'space-between', textOverflow: 'ellipsis' }} 
                    className="col-12 mb-2  no-gutters px-0 ">
                    <div className="col-10  cursor" style={{textOverflow: 'ellipsis', alignSelf: 'flex-end', overflow: 'hidden', height:"auto"}} >
                        <Link to={{
                                        pathname: '/articles/' + article._id
                                        // state : question
                                    }} style={{color: '#3C4453',"fontFamily":"RobotoMedium"}}>{article.newsTitle}</Link>                        
                    </div>
                    <div className="col-2" style={{ marginRigth: '0px', marginLeft: 'auto', textAlign: 'end', paddingTop: '0px' }}>
                        <IconButton 
                            onClick={handleMenuClick}
                            size="small"
                            sx={{ ml: 2 }}
                            aria-controls={open ? 'account-menu' : undefined}
                            aria-haspopup="true"
                            aria-expanded={open ? 'true' : undefined}
                        >
                            <svg version="1.1" width="25px" id="Layer_1" xmlns="http://www.w3.org/2000/svg" xmlnsXlink="http://www.w3.org/1999/xlink" x="0px" y="0px"
                                viewBox="0 0 120 120" enable-background="new 0 0 120 120" xmlSpace="preserve">
                            <g id="Group_2017" transform="translate(-1291 -358)">
                                <g id="Ellipse_289" transform="translate(1291 358)">
                                    <circle fill="none" cx="60" cy="60" r="56"/>
                                    <circle fill="none" stroke="#BDC9DE" stroke-width="3.7333" cx="60" cy="60" r="54.1"/>
                                </g>
                                <g id="Group_2016" transform="translate(1504.627 -2256.78) rotate(90)">
                                    <g id="Ellipse_286" transform="translate(2627.646 188.627)">
                                        <circle fill="none" stroke="#CCD5E5" stroke-width="3.7333" cx="47.8" cy="-63.7" r="6.8"/>
                                    </g>
                                    <g id="Ellipse_287" transform="translate(2627.646 196.351)">
                                        <circle fill="none" stroke="#CCD5E5" stroke-width="3.7333" cx="47.8" cy="-42.6" r="6.8"/>
                                    </g>
                                    <g id="Ellipse_288" transform="translate(2627.646 204.075)">
                                        <circle fill="none" stroke="#CCD5E5" stroke-width="3.7333" cx="47.8" cy="-21.5" r="6.8"/>
                                    </g>
                                </g>
                            </g>
                            </svg>
                        </IconButton>
                        <Menu
                            anchorEl={anchorEl}
                            getContentAnchorEl={null}
                            id="account-menu"
                            open={open}
                            onClose={handleMenuClose}
                            onClick={handleMenuClose}
                            PaperProps={{
                                elevation: 0,
                                sx: {
                                    overflow: 'visible',
                                    filter: 'drop-shadow(0px 2px 8px rgba(0,0,0,6%))',
                                    mt: 1.5,
                                    '& .MuiAvatar-root': {
                                        width: 32,
                                        height: 32,
                                        ml: -0.5,
                                        mr: 1,
                                    },
                                    '&:before': {
                                        content: '""',
                                        display: 'block',
                                        position: 'absolute',
                                        top: 0,
                                        right: 14,
                                        width: 10,
                                        height: 10,
                                        bgcolor: 'background.paper',
                                        transform: 'translateY(-50%) rotate(45deg)',
                                        zIndex: 0,
                                        
                                    },
                                },
                            }}
                            transformOrigin={{ horizontal: 'right', vertical: 'top' }}
                            anchorOrigin={{ horizontal: 'right', vertical: 'bottom' }}

                            style={{"boxShadow" : "0 6px 18px rgb(0 0 0 / 5%)"}}
                        >
                            <MenuItem onClick={saveHandler}>
                                {saveIcon()} 
                            </MenuItem>
                            <MenuItem onClick={deleteArticle}>
                                <svg version="1.1" width="25px" id="Layer_1" xmlns="http://www.w3.org/2000/svg" xmlnsXlink="http://www.w3.org/1999/xlink" x="0px" y="0px"
                                    viewBox="0 0 120 120" enable-background="new 0 0 120 120" xmlSpace="preserve">
                                <g>
                                    <path fill="#6A7791" d="M65.4,41.6h8.1V86h-8.1V41.6z"/>
                                    <path fill="#6A7791" d="M46.5,41.6h8.1V86h-8.1V41.6z"/>
                                    <path fill="#6A7791" d="M69.1,3.7H50.9c-2.9,0-5.6,1.1-7.6,3.2c-2,2-3.2,4.8-3.2,7.6v6.6h-26c-1.4,0-2.8,0.8-3.5,2
                                        c-0.7,1.2-0.7,2.8,0,4c0.7,1.2,2.1,2,3.5,2h7.2l3.9,70.5h0c0.2,4.5,2.2,8.7,5.5,11.7c3.3,3.1,7.6,4.8,12,4.8h34.6
                                        c4.5,0,8.8-1.7,12-4.8c3.3-3.1,5.2-7.3,5.5-11.7l3.9-70.5h7.2h0c1.4,0,2.8-0.8,3.5-2c0.7-1.2,0.7-2.8,0-4c-0.7-1.2-2.1-2-3.5-2
                                        H79.8v-6.6c0-2.9-1.1-5.6-3.2-7.6C74.7,4.9,71.9,3.7,69.1,3.7L69.1,3.7z M48.2,14.5L48.2,14.5c0-1.5,1.2-2.7,2.7-2.7h18.2
                                        c0.7,0,1.4,0.3,1.9,0.8c0.5,0.5,0.8,1.2,0.8,1.9v6.6H48.2L48.2,14.5z M90.6,29.2l-3.9,70.1c-0.1,2.4-1.2,4.7-2.9,6.3
                                        c-1.8,1.7-4.1,2.6-6.5,2.6H42.6c-2.4,0-4.7-0.9-6.5-2.6c-1.8-1.7-2.8-3.9-2.9-6.3l-3.9-70.1H90.6z"/>
                                </g>
                                </svg><span className="menuOptions">Delete</span>
                            </MenuItem>                                        
                            <MenuItem onClick={shareArticle} >
                                <a  href={`https://api.whatsapp.com/send?phone=&text=${process.env.REACT_APP_FRONTEND_URL}` + '/articles/' + article._id} style={{"color" : "black"}}>
                                    <svg version="1.1"  width="25px" id="Layer_1" xmlns="http://www.w3.org/2000/svg" xmlnsXlink="http://www.w3.org/1999/xlink" x="0px" y="0px"
                                        viewBox="0 0 120 120" enable-background="new 0 0 120 120" xmlSpace="preserve">
                                        <g id="Icon_feather-share-2" transform="translate(-3.75 -2.25)">
                                            <path id="Path_121" fill="none" stroke="#7789AC" stroke-width="7.8" stroke-linecap="round" stroke-linejoin="round" d="
                                                M110.6,25.9c0,8.6-7,15.6-15.6,15.6s-15.6-7-15.6-15.6s7-15.6,15.6-15.6S110.6,17.2,110.6,25.9z"/>
                                            <path id="Path_122" fill="none" stroke="#7789AC" stroke-width="7.8" stroke-linecap="round" stroke-linejoin="round" d="
                                                M48.2,62.2c0,8.6-7,15.6-15.6,15.6S17,70.9,17,62.2s7-15.6,15.6-15.6S48.2,53.6,48.2,62.2z"/>
                                            <path id="Path_123" fill="none" stroke="#7789AC" stroke-width="7.8" stroke-linecap="round" stroke-linejoin="round" d="
                                                M110.6,98.7c0,8.6-7,15.6-15.6,15.6s-15.6-7-15.6-15.6s7-15.6,15.6-15.6S110.6,90,110.6,98.7z"/>
                                            <path id="Path_124" fill="none" stroke="#7789AC" stroke-width="7.8" stroke-linecap="round" stroke-linejoin="round" d="M46,70.1
                                                l35.5,20.7"/>
                                            <path id="Path_125" fill="none" stroke="#7789AC" stroke-width="7.8" stroke-linecap="round" stroke-linejoin="round" d="
                                                M81.5,33.7L46,54.4"/>
                                        </g>
                                    </svg><span className="menuOptions">Share</span>
                                </a>
                            </MenuItem>
                            <MenuItem  >
                                <a  href={`https://api.whatsapp.com/send?phone=&text=${process.env.REACT_APP_FRONTEND_URL}` + '/articles/' + article._id} style={{"color" : "black"}}>
                                    <svg version="1.1" width="25px" id="Layer_1" xmlns="http://www.w3.org/2000/svg" xmlnsXlink="http://www.w3.org/1999/xlink" x="0px" y="0px"
                                        viewBox="0 0 120 120" enable-background="new 0 0 120 120" xmlSpace="preserve">
                                    <g id="alert-circle" transform="translate(-1.599 -1.599)">
                                        
                                            <circle id="Ellipse_414" fill="none" stroke="#5D697E" stroke-width="9.7911" stroke-linecap="round" stroke-linejoin="round" cx="61.6" cy="61.6" r="50"/>
                                        
                                            <line id="Line_11" fill="none" stroke="#5D697E" stroke-width="9.7911" stroke-linecap="round" stroke-linejoin="round" x1="61.6" y1="36.6" x2="61.6" y2="61.6"/>
                                        
                                            <line id="Line_12" fill="none" stroke="#5D697E" stroke-width="9.7911" stroke-linecap="round" stroke-linejoin="round" x1="61.6" y1="82.2" x2="61.7" y2="82.2"/>
                                    </g>
                                    </svg><span className="menuOptions">Report</span>
                                </a>
                            </MenuItem>
                        </Menu>
                    </div>
                </div>
                {/* {history.location.pathname !== "/home" ? 
                <div className="description">
                    <div className="textdecorate">
                        <span style={{"fontSize" : "0.8rem", "fontFamily" : "RobotoRegular", "color" : "#6A7791",}}>{article.newsBrief}</span>
                    </div>
                </div> : <></>} */}
                <div className="description">
                    <div className="textdecorate">
                        <span style={{"fontSize" : "0.8rem", "fontFamily" : "RobotoRegular", "color" : "#6A7791",}}>{article.newsBrief}</span>
                    </div>
                </div>
                <div className="row article_actions_container">
                    <div className="col-8 article_actions">
                        <div className=" cursor" >
                            {likeIcon()}
                            <span className="like_count"> {article.likes.length}</span>
                        </div>
                        <div className="">
                            <Link to={{
                                pathname: '/articles/' + article._id
                                // state : question
                                }} style={{color: 'black'}}>
                                <svg version="1.1" id="Layer_1" width="25px" xmlns="http://www.w3.org/2000/svg" xmlnsXlink="http://www.w3.org/1999/xlink" x="0px" y="0px"
                                    viewBox="0 0 120 120" enable-background="new 0 0 120 120" xmlSpace="preserve">
                                    <path fill="#7789AC" stroke="#7789AC" strokeWidth="3" d="M112.4,114.7L81.6,83.9H17.4c-5.4,0-9.8-4.4-9.9-9.8v-59c0-5.4,4.4-9.9,9.9-9.9h85.2c5.4,0,9.9,4.4,9.9,9.9
                                        V114.7z M14.1,74.1c0,1.8,1.5,3.3,3.3,3.3h66.9l21.6,21.6V15.1c0-1.8-1.5-3.3-3.3-3.3H17.4c-1.8,0-3.3,1.5-3.3,3.3V74.1z"/>
                                </svg><span className="like_count"> {article.comments.length}</span>
                            </Link>
                        </div>                        
                    </div>
                    <div className="col-4">
                        <div className="timeData">{time}</div>
                    </div>
                </div>
            </div>
  
        // <>
        //     {history.location.pathname === "/home" ?
        //     <>
        //     {/* <div 
        //         className="col-5 px-0 ">
        //             <img className=" px-0" src={process.env.REACT_APP_BACKEND_URL + article.newsImage} style={{ flexShrink: 0, borderRadius: '10px',maxHeight : "150px", minWidth : "250px"}} />
        //     </div> */}
        //     <div style={{}} className="">
        //         <div style={{ display:"flex", alignItems: 'initial', width: '100%', justifyContent: 'space-between', textOverflow: 'ellipsis' }} 
        //             className="col-12 mb-2  no-gutters px-0 ">
        //             <div className="col-10  cursor" style={{textOverflow: 'ellipsis', alignSelf: 'flex-end', overflow: 'hidden', height:"auto"}} >
        //                 <Link to={{
        //                                 pathname: '/articles/' + article._id
        //                                 // state : question
        //                             }} style={{color: '#3C4453',"fontFamily":"RobotoMedium"}}>{article.newsTitle}</Link>                        
        //             </div>
        //             <div className="col-2" style={{ marginRigth: '0px', marginLeft: 'auto', textAlign: 'end', paddingTop: '0px' }}>
        //                 <IconButton 
        //                     onClick={handleMenuClick}
        //                     size="small"
        //                     sx={{ ml: 2 }}
        //                     aria-controls={open ? 'account-menu' : undefined}
        //                     aria-haspopup="true"
        //                     aria-expanded={open ? 'true' : undefined}
        //                 >
        //                     <svg version="1.1" width="25px" id="Layer_1" xmlns="http://www.w3.org/2000/svg" xmlnsXlink="http://www.w3.org/1999/xlink" x="0px" y="0px"
        //                         viewBox="0 0 120 120" enable-background="new 0 0 120 120" xmlSpace="preserve">
        //                     <g id="Group_2017" transform="translate(-1291 -358)">
        //                         <g id="Ellipse_289" transform="translate(1291 358)">
        //                             <circle fill="none" cx="60" cy="60" r="56"/>
        //                             <circle fill="none" stroke="#BDC9DE" stroke-width="3.7333" cx="60" cy="60" r="54.1"/>
        //                         </g>
        //                         <g id="Group_2016" transform="translate(1504.627 -2256.78) rotate(90)">
        //                             <g id="Ellipse_286" transform="translate(2627.646 188.627)">
        //                                 <circle fill="none" stroke="#CCD5E5" stroke-width="3.7333" cx="47.8" cy="-63.7" r="6.8"/>
        //                             </g>
        //                             <g id="Ellipse_287" transform="translate(2627.646 196.351)">
        //                                 <circle fill="none" stroke="#CCD5E5" stroke-width="3.7333" cx="47.8" cy="-42.6" r="6.8"/>
        //                             </g>
        //                             <g id="Ellipse_288" transform="translate(2627.646 204.075)">
        //                                 <circle fill="none" stroke="#CCD5E5" stroke-width="3.7333" cx="47.8" cy="-21.5" r="6.8"/>
        //                             </g>
        //                         </g>
        //                     </g>
        //                     </svg>
        //                 </IconButton>
        //                 <Menu
        //                     anchorEl={anchorEl}
        //                     getContentAnchorEl={null}
        //                     id="account-menu"
        //                     open={open}
        //                     onClose={handleMenuClose}
        //                     onClick={handleMenuClose}
        //                     PaperProps={{
        //                         elevation: 0,
        //                         sx: {
        //                             overflow: 'visible',
        //                             filter: 'drop-shadow(0px 2px 8px rgba(0,0,0,6%))',
        //                             mt: 1.5,
        //                             '& .MuiAvatar-root': {
        //                                 width: 32,
        //                                 height: 32,
        //                                 ml: -0.5,
        //                                 mr: 1,
        //                             },
        //                             '&:before': {
        //                                 content: '""',
        //                                 display: 'block',
        //                                 position: 'absolute',
        //                                 top: 0,
        //                                 right: 14,
        //                                 width: 10,
        //                                 height: 10,
        //                                 bgcolor: 'background.paper',
        //                                 transform: 'translateY(-50%) rotate(45deg)',
        //                                 zIndex: 0,
                                        
        //                             },
        //                         },
        //                     }}
        //                     transformOrigin={{ horizontal: 'right', vertical: 'top' }}
        //                     anchorOrigin={{ horizontal: 'right', vertical: 'bottom' }}

        //                     style={{"boxShadow" : "0 6px 18px rgb(0 0 0 / 5%)"}}
        //                 >
        //                     <MenuItem onClick={saveHandler}>
        //                         {saveIcon()} 
        //                     </MenuItem>
        //                     <MenuItem onClick={deleteArticle}>
        //                         <svg version="1.1" width="25px" id="Layer_1" xmlns="http://www.w3.org/2000/svg" xmlnsXlink="http://www.w3.org/1999/xlink" x="0px" y="0px"
        //                             viewBox="0 0 120 120" enable-background="new 0 0 120 120" xmlSpace="preserve">
        //                         <g>
        //                             <path fill="#6A7791" d="M65.4,41.6h8.1V86h-8.1V41.6z"/>
        //                             <path fill="#6A7791" d="M46.5,41.6h8.1V86h-8.1V41.6z"/>
        //                             <path fill="#6A7791" d="M69.1,3.7H50.9c-2.9,0-5.6,1.1-7.6,3.2c-2,2-3.2,4.8-3.2,7.6v6.6h-26c-1.4,0-2.8,0.8-3.5,2
        //                                 c-0.7,1.2-0.7,2.8,0,4c0.7,1.2,2.1,2,3.5,2h7.2l3.9,70.5h0c0.2,4.5,2.2,8.7,5.5,11.7c3.3,3.1,7.6,4.8,12,4.8h34.6
        //                                 c4.5,0,8.8-1.7,12-4.8c3.3-3.1,5.2-7.3,5.5-11.7l3.9-70.5h7.2h0c1.4,0,2.8-0.8,3.5-2c0.7-1.2,0.7-2.8,0-4c-0.7-1.2-2.1-2-3.5-2
        //                                 H79.8v-6.6c0-2.9-1.1-5.6-3.2-7.6C74.7,4.9,71.9,3.7,69.1,3.7L69.1,3.7z M48.2,14.5L48.2,14.5c0-1.5,1.2-2.7,2.7-2.7h18.2
        //                                 c0.7,0,1.4,0.3,1.9,0.8c0.5,0.5,0.8,1.2,0.8,1.9v6.6H48.2L48.2,14.5z M90.6,29.2l-3.9,70.1c-0.1,2.4-1.2,4.7-2.9,6.3
        //                                 c-1.8,1.7-4.1,2.6-6.5,2.6H42.6c-2.4,0-4.7-0.9-6.5-2.6c-1.8-1.7-2.8-3.9-2.9-6.3l-3.9-70.1H90.6z"/>
        //                         </g>
        //                         </svg><span className="menuOptions">Delete</span>
        //                     </MenuItem>                                        
        //                     <MenuItem onClick={shareArticle} >
        //                         <a  href={`https://api.whatsapp.com/send?phone=&text=${process.env.REACT_APP_FRONTEND_URL}` + '/articles/' + article._id} style={{"color" : "black"}}>
        //                             <svg version="1.1"  width="25px" id="Layer_1" xmlns="http://www.w3.org/2000/svg" xmlnsXlink="http://www.w3.org/1999/xlink" x="0px" y="0px"
        //                                 viewBox="0 0 120 120" enable-background="new 0 0 120 120" xmlSpace="preserve">
        //                                 <g id="Icon_feather-share-2" transform="translate(-3.75 -2.25)">
        //                                     <path id="Path_121" fill="none" stroke="#7789AC" stroke-width="7.8" stroke-linecap="round" stroke-linejoin="round" d="
        //                                         M110.6,25.9c0,8.6-7,15.6-15.6,15.6s-15.6-7-15.6-15.6s7-15.6,15.6-15.6S110.6,17.2,110.6,25.9z"/>
        //                                     <path id="Path_122" fill="none" stroke="#7789AC" stroke-width="7.8" stroke-linecap="round" stroke-linejoin="round" d="
        //                                         M48.2,62.2c0,8.6-7,15.6-15.6,15.6S17,70.9,17,62.2s7-15.6,15.6-15.6S48.2,53.6,48.2,62.2z"/>
        //                                     <path id="Path_123" fill="none" stroke="#7789AC" stroke-width="7.8" stroke-linecap="round" stroke-linejoin="round" d="
        //                                         M110.6,98.7c0,8.6-7,15.6-15.6,15.6s-15.6-7-15.6-15.6s7-15.6,15.6-15.6S110.6,90,110.6,98.7z"/>
        //                                     <path id="Path_124" fill="none" stroke="#7789AC" stroke-width="7.8" stroke-linecap="round" stroke-linejoin="round" d="M46,70.1
        //                                         l35.5,20.7"/>
        //                                     <path id="Path_125" fill="none" stroke="#7789AC" stroke-width="7.8" stroke-linecap="round" stroke-linejoin="round" d="
        //                                         M81.5,33.7L46,54.4"/>
        //                                 </g>
        //                             </svg><span className="menuOptions">Share</span>
        //                         </a>
        //                     </MenuItem>
        //                     <MenuItem  >
        //                         <a  href={`https://api.whatsapp.com/send?phone=&text=${process.env.REACT_APP_FRONTEND_URL}` + '/articles/' + article._id} style={{"color" : "black"}}>
        //                             <svg version="1.1" width="25px" id="Layer_1" xmlns="http://www.w3.org/2000/svg" xmlnsXlink="http://www.w3.org/1999/xlink" x="0px" y="0px"
        //                                 viewBox="0 0 120 120" enable-background="new 0 0 120 120" xmlSpace="preserve">
        //                             <g id="alert-circle" transform="translate(-1.599 -1.599)">
                                        
        //                                     <circle id="Ellipse_414" fill="none" stroke="#5D697E" stroke-width="9.7911" stroke-linecap="round" stroke-linejoin="round" cx="61.6" cy="61.6" r="50"/>
                                        
        //                                     <line id="Line_11" fill="none" stroke="#5D697E" stroke-width="9.7911" stroke-linecap="round" stroke-linejoin="round" x1="61.6" y1="36.6" x2="61.6" y2="61.6"/>
                                        
        //                                     <line id="Line_12" fill="none" stroke="#5D697E" stroke-width="9.7911" stroke-linecap="round" stroke-linejoin="round" x1="61.6" y1="82.2" x2="61.7" y2="82.2"/>
        //                             </g>
        //                             </svg><span className="menuOptions">Report</span>
        //                         </a>
        //                     </MenuItem>
        //                 </Menu>
        //             </div>
        //         </div>
        //         {/* {history.location.pathname !== "/home" ? 
        //         <div className="description">
        //             <div className="textdecorate">
        //                 <span style={{"fontSize" : "0.8rem", "fontFamily" : "RobotoRegular", "color" : "#6A7791",}}>{article.newsBrief}</span>
        //             </div>
        //         </div> : <></>} */}
        //         <div className="description">
        //             <div className="textdecorate">
        //                 <span style={{"fontSize" : "0.8rem", "fontFamily" : "RobotoRegular", "color" : "#6A7791",}}>{article.newsBrief}</span>
        //             </div>
        //         </div>
        //         <div className="row article_actions_container">
        //             <div className="col-8 article_actions">
        //                 <div className=" cursor" >
        //                     {likeIcon()}
        //                     <span className="like_count"> {article.likes.length}</span>
        //                 </div>
        //                 <div className="">
        //                     <Link to={{
        //                         pathname: '/articles/' + article._id
        //                         // state : question
        //                         }} style={{color: 'black'}}>
        //                         <svg version="1.1" id="Layer_1" width="25px" xmlns="http://www.w3.org/2000/svg" xmlnsXlink="http://www.w3.org/1999/xlink" x="0px" y="0px"
        //                             viewBox="0 0 120 120" enable-background="new 0 0 120 120" xmlSpace="preserve">
        //                             <path fill="#7789AC" stroke="#7789AC" strokeWidth="3" d="M112.4,114.7L81.6,83.9H17.4c-5.4,0-9.8-4.4-9.9-9.8v-59c0-5.4,4.4-9.9,9.9-9.9h85.2c5.4,0,9.9,4.4,9.9,9.9
        //                                 V114.7z M14.1,74.1c0,1.8,1.5,3.3,3.3,3.3h66.9l21.6,21.6V15.1c0-1.8-1.5-3.3-3.3-3.3H17.4c-1.8,0-3.3,1.5-3.3,3.3V74.1z"/>
        //                         </svg><span className="like_count"> {article.comments.length}</span>
        //                     </Link>
        //                 </div>                        
        //             </div>
        //             <div className="col-4">
        //                 <div className="timeData">{time}</div>
        //             </div>
        //         </div>
        //     </div>
        //     </> : 
        //     <>
        //     <div 
        //         className="col-5 px-0 " style={{"display":"flex","justifyContent":"center","alignItems":"center"}}>
        //             <img className=" px-0" src={process.env.REACT_APP_BACKEND_URL + article.newsImage} style={{ flexShrink: 0, borderRadius: '10px',maxHeight : "200px", width : "250px"}} />
        //     </div>
        //     <div style={{}} className="col-7">
        //         <div style={{ display:"flex", alignItems: 'initial', width: '100%', justifyContent: 'space-between', textOverflow: 'ellipsis' }} 
        //             className="col-12 mb-2  no-gutters px-0 ">
        //             <div className="col-10  cursor" style={{textOverflow: 'ellipsis', alignSelf: 'flex-end', overflow: 'hidden', height:"auto"}} >
        //                 <Link to={{
        //                                 pathname: '/articles/' + article._id
        //                                 // state : question
        //                             }} style={{color: '#3C4453',"fontFamily":"RobotoMedium"}}>{article.newsTitle}</Link>                        
        //             </div>
        //             <div className="col-2" style={{ marginRigth: '0px', marginLeft: 'auto', textAlign: 'end', paddingTop: '0px' }}>
        //                 <IconButton 
        //                     onClick={handleMenuClick}
        //                     size="small"
        //                     sx={{ ml: 2 }}
        //                     aria-controls={open ? 'account-menu' : undefined}
        //                     aria-haspopup="true"
        //                     aria-expanded={open ? 'true' : undefined}
        //                 >
        //                     <svg version="1.1" width="25px" id="Layer_1" xmlns="http://www.w3.org/2000/svg" xmlnsXlink="http://www.w3.org/1999/xlink" x="0px" y="0px"
        //                         viewBox="0 0 120 120" enable-background="new 0 0 120 120" xmlSpace="preserve">
        //                     <g id="Group_2017" transform="translate(-1291 -358)">
        //                         <g id="Ellipse_289" transform="translate(1291 358)">
        //                             <circle fill="none" cx="60" cy="60" r="56"/>
        //                             <circle fill="none" stroke="#BDC9DE" stroke-width="3.7333" cx="60" cy="60" r="54.1"/>
        //                         </g>
        //                         <g id="Group_2016" transform="translate(1504.627 -2256.78) rotate(90)">
        //                             <g id="Ellipse_286" transform="translate(2627.646 188.627)">
        //                                 <circle fill="none" stroke="#CCD5E5" stroke-width="3.7333" cx="47.8" cy="-63.7" r="6.8"/>
        //                             </g>
        //                             <g id="Ellipse_287" transform="translate(2627.646 196.351)">
        //                                 <circle fill="none" stroke="#CCD5E5" stroke-width="3.7333" cx="47.8" cy="-42.6" r="6.8"/>
        //                             </g>
        //                             <g id="Ellipse_288" transform="translate(2627.646 204.075)">
        //                                 <circle fill="none" stroke="#CCD5E5" stroke-width="3.7333" cx="47.8" cy="-21.5" r="6.8"/>
        //                             </g>
        //                         </g>
        //                     </g>
        //                     </svg>
        //                 </IconButton>
        //                 <Menu
        //                     anchorEl={anchorEl}
        //                     getContentAnchorEl={null}
        //                     id="account-menu"
        //                     open={open}
        //                     onClose={handleMenuClose}
        //                     onClick={handleMenuClose}
        //                     PaperProps={{
        //                         elevation: 0,
        //                         sx: {
        //                             overflow: 'visible',
        //                             filter: 'drop-shadow(0px 2px 8px rgba(0,0,0,6%))',
        //                             mt: 1.5,
        //                             '& .MuiAvatar-root': {
        //                                 width: 32,
        //                                 height: 32,
        //                                 ml: -0.5,
        //                                 mr: 1,
        //                             },
        //                             '&:before': {
        //                                 content: '""',
        //                                 display: 'block',
        //                                 position: 'absolute',
        //                                 top: 0,
        //                                 right: 14,
        //                                 width: 10,
        //                                 height: 10,
        //                                 bgcolor: 'background.paper',
        //                                 transform: 'translateY(-50%) rotate(45deg)',
        //                                 zIndex: 0,
                                        
        //                             },
        //                         },
        //                     }}
        //                     transformOrigin={{ horizontal: 'right', vertical: 'top' }}
        //                     anchorOrigin={{ horizontal: 'right', vertical: 'bottom' }}

        //                     style={{"boxShadow" : "0 6px 18px rgb(0 0 0 / 5%)"}}
        //                 >
        //                     <MenuItem onClick={saveHandler}>
        //                         {saveIcon()} 
        //                     </MenuItem>
        //                     <MenuItem onClick={deleteArticle}>
        //                         <svg version="1.1" width="25px" id="Layer_1" xmlns="http://www.w3.org/2000/svg" xmlnsXlink="http://www.w3.org/1999/xlink" x="0px" y="0px"
        //                             viewBox="0 0 120 120" enable-background="new 0 0 120 120" xmlSpace="preserve">
        //                         <g>
        //                             <path fill="#6A7791" d="M65.4,41.6h8.1V86h-8.1V41.6z"/>
        //                             <path fill="#6A7791" d="M46.5,41.6h8.1V86h-8.1V41.6z"/>
        //                             <path fill="#6A7791" d="M69.1,3.7H50.9c-2.9,0-5.6,1.1-7.6,3.2c-2,2-3.2,4.8-3.2,7.6v6.6h-26c-1.4,0-2.8,0.8-3.5,2
        //                                 c-0.7,1.2-0.7,2.8,0,4c0.7,1.2,2.1,2,3.5,2h7.2l3.9,70.5h0c0.2,4.5,2.2,8.7,5.5,11.7c3.3,3.1,7.6,4.8,12,4.8h34.6
        //                                 c4.5,0,8.8-1.7,12-4.8c3.3-3.1,5.2-7.3,5.5-11.7l3.9-70.5h7.2h0c1.4,0,2.8-0.8,3.5-2c0.7-1.2,0.7-2.8,0-4c-0.7-1.2-2.1-2-3.5-2
        //                                 H79.8v-6.6c0-2.9-1.1-5.6-3.2-7.6C74.7,4.9,71.9,3.7,69.1,3.7L69.1,3.7z M48.2,14.5L48.2,14.5c0-1.5,1.2-2.7,2.7-2.7h18.2
        //                                 c0.7,0,1.4,0.3,1.9,0.8c0.5,0.5,0.8,1.2,0.8,1.9v6.6H48.2L48.2,14.5z M90.6,29.2l-3.9,70.1c-0.1,2.4-1.2,4.7-2.9,6.3
        //                                 c-1.8,1.7-4.1,2.6-6.5,2.6H42.6c-2.4,0-4.7-0.9-6.5-2.6c-1.8-1.7-2.8-3.9-2.9-6.3l-3.9-70.1H90.6z"/>
        //                         </g>
        //                         </svg><span className="menuOptions">Delete</span>
        //                     </MenuItem>                                        
        //                     <MenuItem onClick={shareArticle} >
        //                         <a  href={`https://api.whatsapp.com/send?phone=&text=${process.env.REACT_APP_FRONTEND_URL}` + '/articles/' + article._id} style={{"color" : "black"}}>
        //                             <svg version="1.1"  width="25px" id="Layer_1" xmlns="http://www.w3.org/2000/svg" xmlnsXlink="http://www.w3.org/1999/xlink" x="0px" y="0px"
        //                                 viewBox="0 0 120 120" enable-background="new 0 0 120 120" xmlSpace="preserve">
        //                                 <g id="Icon_feather-share-2" transform="translate(-3.75 -2.25)">
        //                                     <path id="Path_121" fill="none" stroke="#7789AC" stroke-width="7.8" stroke-linecap="round" stroke-linejoin="round" d="
        //                                         M110.6,25.9c0,8.6-7,15.6-15.6,15.6s-15.6-7-15.6-15.6s7-15.6,15.6-15.6S110.6,17.2,110.6,25.9z"/>
        //                                     <path id="Path_122" fill="none" stroke="#7789AC" stroke-width="7.8" stroke-linecap="round" stroke-linejoin="round" d="
        //                                         M48.2,62.2c0,8.6-7,15.6-15.6,15.6S17,70.9,17,62.2s7-15.6,15.6-15.6S48.2,53.6,48.2,62.2z"/>
        //                                     <path id="Path_123" fill="none" stroke="#7789AC" stroke-width="7.8" stroke-linecap="round" stroke-linejoin="round" d="
        //                                         M110.6,98.7c0,8.6-7,15.6-15.6,15.6s-15.6-7-15.6-15.6s7-15.6,15.6-15.6S110.6,90,110.6,98.7z"/>
        //                                     <path id="Path_124" fill="none" stroke="#7789AC" stroke-width="7.8" stroke-linecap="round" stroke-linejoin="round" d="M46,70.1
        //                                         l35.5,20.7"/>
        //                                     <path id="Path_125" fill="none" stroke="#7789AC" stroke-width="7.8" stroke-linecap="round" stroke-linejoin="round" d="
        //                                         M81.5,33.7L46,54.4"/>
        //                                 </g>
        //                             </svg><span className="menuOptions">Share</span>
        //                         </a>
        //                     </MenuItem>
        //                     <MenuItem  >
        //                         <a  href={`https://api.whatsapp.com/send?phone=&text=${process.env.REACT_APP_FRONTEND_URL}` + '/articles/' + article._id} style={{"color" : "black"}}>
        //                             <svg version="1.1" width="25px" id="Layer_1" xmlns="http://www.w3.org/2000/svg" xmlnsXlink="http://www.w3.org/1999/xlink" x="0px" y="0px"
        //                                 viewBox="0 0 120 120" enable-background="new 0 0 120 120" xmlSpace="preserve">
        //                             <g id="alert-circle" transform="translate(-1.599 -1.599)">
                                        
        //                                     <circle id="Ellipse_414" fill="none" stroke="#5D697E" stroke-width="9.7911" stroke-linecap="round" stroke-linejoin="round" cx="61.6" cy="61.6" r="50"/>
                                        
        //                                     <line id="Line_11" fill="none" stroke="#5D697E" stroke-width="9.7911" stroke-linecap="round" stroke-linejoin="round" x1="61.6" y1="36.6" x2="61.6" y2="61.6"/>
                                        
        //                                     <line id="Line_12" fill="none" stroke="#5D697E" stroke-width="9.7911" stroke-linecap="round" stroke-linejoin="round" x1="61.6" y1="82.2" x2="61.7" y2="82.2"/>
        //                             </g>
        //                             </svg><span className="menuOptions">Report</span>
        //                         </a>
        //                     </MenuItem>
        //                 </Menu>
        //             </div>
        //         </div>
        //         {history.location.pathname !== "/home" ? 
        //         <div className="description">
        //             <div className="textdecorate">
        //                 <span style={{"fontSize" : "0.8rem", "fontFamily" : "RobotoRegular", "color" : "#6A7791",}}>{article.newsBrief}</span>
        //             </div>
        //         </div> : <></>}
        //         <div className="row article_actions_container">
        //             <div className="col-8 article_actions">
        //                 <div className=" cursor" >
        //                     {likeIcon()}
        //                     <span className="like_count"> {article.likes.length}</span>
        //                 </div>
        //                 <div className="">
        //                     <Link to={{
        //                         pathname: '/articles/' + article._id
        //                         // state : question
        //                         }} style={{color: 'black'}}>
        //                         <svg version="1.1" id="Layer_1" width="25px" xmlns="http://www.w3.org/2000/svg" xmlnsXlink="http://www.w3.org/1999/xlink" x="0px" y="0px"
        //                             viewBox="0 0 120 120" enable-background="new 0 0 120 120" xmlSpace="preserve">
        //                             <path fill="#7789AC" stroke="#7789AC" strokeWidth="3" d="M112.4,114.7L81.6,83.9H17.4c-5.4,0-9.8-4.4-9.9-9.8v-59c0-5.4,4.4-9.9,9.9-9.9h85.2c5.4,0,9.9,4.4,9.9,9.9
        //                                 V114.7z M14.1,74.1c0,1.8,1.5,3.3,3.3,3.3h66.9l21.6,21.6V15.1c0-1.8-1.5-3.3-3.3-3.3H17.4c-1.8,0-3.3,1.5-3.3,3.3V74.1z"/>
        //                         </svg><span className="like_count"> {article.comments.length}</span>
        //                     </Link>
        //                 </div>                        
        //             </div>
        //             <div className="col-4">
        //                 <div className="timeData">{time}</div>
        //             </div>
        //         </div>
        //     </div>
        //     </>}
            
        //     </>
      );
}

export default SingleArticle;