import React, { useState, useContext } from "react";
import { Edit, ThumbDownRounded, ThumbDownOutlined, ThumbUpRounded, ThumbUpOutlined, MoreHoriz } from "@material-ui/icons";
import { IconButton } from "@material-ui/core";
import { MoreVert, Delete, Share, Done, Undo, CheckCircle } from "@material-ui/icons";
import { Button, Modal } from "react-bootstrap";
import Menu from "@material-ui/core/Menu";
import MenuItem from '@material-ui/core/MenuItem';
import { AuthContext } from "../../context/AuthContext";
import { Link, useHistory } from "react-router-dom";
import { format } from "timeago.js";
import axios from "axios";

const SingleAnswer = ({ answer, fetchQuestion, question }) => {
    const history = useHistory();
    let { user } = useContext(AuthContext);
    const [showEditModal, setShowEditModal] = useState(false);
    const [editvalue, setEditvalue] = useState(null);
    var time = format(answer.createdAt);
    const [anchorEl, setAnchorEl] = useState(null);
    const open = Boolean(anchorEl);

    if (!user) {
        user = {
            userId: 123,
            username: "Guest",
            userType: "Guest"
        }
    }

    const handleMenuClick = (event) => {
        setAnchorEl(event.currentTarget);
    };
    const handleMenuClose = () => {
        setAnchorEl(null);
    };
    //-----------Deleting answer
    const deleteAnswer = async () => {
        try {
            await axios.put(`${process.env.REACT_APP_BACKEND_URL}/api/answer/delete/` + answer._id, { "questionId" : question._id});
        } catch (err) {
            console.log("Error--->", err)
        }
        fetchQuestion();
    }
    //-----------Sharing Answer
    const shareAnswer = () => {
        console.log("share-------->", `${process.env.REACT_APP_FRONTEND_URL}` + history.location.pathname + '/' + question._id)
    }
    //-----------Solving Answer
    const solveHandle = async () => {
        if (answer.solved) {
            for (let i = 0; i < question.solvedBy.length; i++) {
                if (question.solvedBy[i] === answer._id) {
                    question.solvedBy.splice(i, 1);
                }
            }
            try {
                await axios.put(`${process.env.REACT_APP_BACKEND_URL}/api/answer/` + answer._id, { "solved": !answer.solved });
                await axios.put(`${process.env.REACT_APP_BACKEND_URL}/api/question/` + question._id + `/solvedBy`, question);
                fetchQuestion();
            } catch (err) {
                console.log("Error--->", err)
            }
        } else {
            try {
                await axios.put(`${process.env.REACT_APP_BACKEND_URL}/api/answer/` + answer._id, { "solved": !answer.solved });
                question.solvedBy.push(answer._id);
                await axios.put(`${process.env.REACT_APP_BACKEND_URL}/api/question/` + question._id + `/solvedBy`, question);
                fetchQuestion();
            } catch (err) {
                console.log("Error--->", err)
            }
        }

    }

    const likeHandler = async () => {
        var likes = {
            userId: user._id,
            username: user.username,
            profilePicture: user.profilePicture
        };
        try {
            await axios.put(`${process.env.REACT_APP_BACKEND_URL}/api/answer/` + answer._id + `/likes`, likes);
            fetchQuestion();
        } catch (err) {
            console.log(err, "Error in updating likes")
        }
    }
    const dislikeHandler = async () => {
        var dislikes = {
            userId: user._id,
            username: user.username,
            profilePicture: user.profilePicture
        };
        try {
            await axios.put(`${process.env.REACT_APP_BACKEND_URL}/api/answer/` + answer._id + `/dislikes`, dislikes);
            fetchQuestion();
        } catch (err) {
            console.log(err, "Error in updating dislikes")
        }
    }
    //--------- Handling Edit Modal
    const handleEditModalOpen = () => {
        setShowEditModal(true)
    };
    const handleEditModalClose = () => {
        setEditvalue(null);
        setShowEditModal(false);
    };
    //--------- Updating Answer
    const updateAnswer = async () => {
        answer.message = editvalue;
        try {
            await axios.put(`${process.env.REACT_APP_BACKEND_URL}/api/answer/` + answer._id + `/updateAnswer`, answer)
        }catch(err){
            console.log("Error in updating question ",err);
        }
        handleEditModalClose();
    }
    //---------- Handling Like Icon
    const likeIcon = () => {
        const postLikeLength = answer.likes.length;                
        for (var k = 0; k < postLikeLength; k++) {
            if (answer.likes[k].userId == user._id) {
                break;
            }
        }
        if (k == postLikeLength) {
            return(
                <svg version="1.1" width="25px" onClick={likeHandler} id="Layer_1" xmlns="http://www.w3.org/2000/svg" xmlnsXlink="http://www.w3.org/1999/xlink" x="0px" y="0px"
                    viewBox="0 0 120 120" enableBackground="new 0 0 120 120" xmlSpace="preserve">
                <circle id="Ellipse_404" fill="#D1D8E3" cx="60" cy="60" r="56"/>
                <g id="noun_like_986837" transform="translate(-11 -9.973)">
                    <g id="Group_1304" transform="translate(17.383 15.29)">
                        <path id="Path_195" fill="#FFFFFF" d="M81.8,45.8c-1.9-4.2-9.9-2.9-13.3-3s-3.7-1.4-2.7-3.2c2-3.3,3.7-6.8,5.1-10.4
                            c0.8-3.8-1.1-7.6-4.6-9.1c-3.2-0.6-3.5,4.5-3.5,4.5c-0.8,6.1-6.9,11.2-8.6,13c-1.6,2.5-3,5.2-4.2,8c-1.1,1.7-2.4,3.3-3.8,4.7h-2.8
                            v23.8c1.3,1.3,2.7,2.4,4.3,3.4h28c4.8-0.8,3.4-6.9,3.4-6.9c2.1-2,2.5-5.3,1-7.7c5.1-5,1.1-9,1.1-9C83.1,51.5,83.4,48.2,81.8,45.8z
                            "/>
                        <path id="Path_196" fill="#FFFFFF" d="M39,47.1h-14c-1.1,0-1.9,0.9-1.9,1.9v27.1c0,1.1,0.9,1.9,1.9,1.9h14c1.1,0,1.9-0.9,1.9-1.9
                            l0,0V49C41,47.9,40.1,47.1,39,47.1L39,47.1z M31.5,74.3c-1.4,0-2.6-1.2-2.6-2.6s1.2-2.6,2.6-2.6c1.4,0,2.6,1.2,2.6,2.6
                            S33,74.3,31.5,74.3L31.5,74.3z"/>
                    </g>
                </g>
                </svg>
            );
        } else {
            return (
                <svg version="1.1" width="25px" onClick={likeHandler} id="Layer_1" xmlns="http://www.w3.org/2000/svg" xmlnsXlink="http://www.w3.org/1999/xlink" x="0px" y="0px"
                    viewBox="0 0 120 120" enableBackground="new 0 0 120 120" xmlSpace="preserve">
                <g>
                    <circle id="Ellipse_404" fill="#4099FF" cx="60" cy="60" r="56"/>
                    <g id="noun_like_986837" transform="translate(-11 -9.973)">
                        <g id="Group_1304" transform="translate(17.383 15.29)">
                            <path id="Path_195" fill="#FFFFFF" d="M81.8,45.8c-1.9-4.2-9.9-2.9-13.3-3s-3.7-1.4-2.7-3.2c2-3.3,3.7-6.8,5.1-10.4
                                c0.8-3.8-1.1-7.6-4.6-9.1c-3.2-0.6-3.5,4.5-3.5,4.5c-0.8,6.1-6.9,11.2-8.6,13c-1.6,2.5-3,5.2-4.2,8c-1.1,1.7-2.4,3.3-3.8,4.7
                                h-2.8v23.8c1.3,1.3,2.7,2.4,4.3,3.4h28c4.8-0.8,3.4-6.9,3.4-6.9c2.1-2,2.5-5.3,1-7.7c5.1-5,1.1-9,1.1-9
                                C83.1,51.5,83.4,48.2,81.8,45.8z"/>
                            <path id="Path_196" fill="#FFFFFF" d="M39,47.1h-14c-1.1,0-1.9,0.9-1.9,1.9v27.1c0,1.1,0.9,1.9,1.9,1.9h14c1.1,0,1.9-0.9,1.9-1.9
                                l0,0V49C41,47.9,40.1,47.1,39,47.1L39,47.1z M31.5,74.3c-1.4,0-2.6-1.2-2.6-2.6s1.2-2.6,2.6-2.6c1.4,0,2.6,1.2,2.6,2.6
                                S33,74.3,31.5,74.3L31.5,74.3z"/>
                        </g>
                    </g>
                </g>
                </svg>
            );
        }
    }
    //---------- Handling Dislike Icon
    const disLikeIcon = () => {
        const postLikeLength = answer.dislikes.length;                
        for (var l = 0; l < postLikeLength; l++) {
            if (answer.dislikes[l].userId == user._id) {
                break;
            }
        }
        if (l == postLikeLength) {
            return(
                <svg version="1.1" width="25px" onClick={dislikeHandler} id="Layer_1" xmlns="http://www.w3.org/2000/svg" xmlnsXlink="http://www.w3.org/1999/xlink" x="0px" y="0px"
                    viewBox="0 0 120 120" enableBackground="new 0 0 120 120" xmlSpace="preserve">
                <circle id="Ellipse_404" fill="#D1D8E3" cx="60" cy="60" r="56"/>
                <g id="noun_like_986837" transform="translate(-11 -9.973)">
                    <g id="Group_1304" transform="translate(17.383 15.29)">
                        <path id="Path_195" fill="#FFFFFF" d="M25.4,63.6c1.9,4.2,9.9,2.9,13.3,3s3.7,1.4,2.7,3.2c-2,3.3-3.7,6.8-5.1,10.4
                            c-0.8,3.8,1.1,7.6,4.6,9.1c3.2,0.6,3.5-4.5,3.5-4.5c0.8-6.1,6.9-11.2,8.6-13c1.6-2.6,3-5.2,4.2-8c1.1-1.7,2.4-3.3,3.8-4.7H64V35.5
                            c-1.3-1.3-2.7-2.4-4.3-3.4h-28c-4.8,0.8-3.4,6.9-3.4,6.9c-2.1,2-2.5,5.3-1,7.7c-5.1,5-1.1,9-1.1,9C24.2,57.8,23.8,61.1,25.4,63.6z
                            "/>
                        <path id="Path_196" fill="#FFFFFF" d="M68.2,62.3h14c1.1,0,1.9-0.9,1.9-1.9V33.2c0-1.1-0.9-1.9-1.9-1.9h-14
                            c-1.1,0-1.9,0.9-1.9,1.9l0,0v27.1C66.3,61.4,67.1,62.3,68.2,62.3L68.2,62.3z M75.7,35.1c1.4,0,2.6,1.2,2.6,2.6s-1.2,2.6-2.6,2.6
                            s-2.6-1.2-2.6-2.6S74.3,35.1,75.7,35.1L75.7,35.1z"/>
                    </g>
                </g>
                </svg>
                // <ThumbDownOutlined  onClick={dislikeHandler}/>
            );
        } else {
            return (
                <svg version="1.1" width="25px" onClick={dislikeHandler} id="Layer_1" xmlns="http://www.w3.org/2000/svg" xmlnsXlink="http://www.w3.org/1999/xlink" x="0px" y="0px"
                    viewBox="0 0 120 120" enableBackground="new 0 0 120 120" xmlSpace="preserve">
                <circle id="Ellipse_404" fill="#FB5773" cx="60" cy="60" r="56"/>
                <g id="noun_like_986837" transform="translate(-11 -9.973)">
                    <g id="Group_1304" transform="translate(17.383 15.29)">
                        <path id="Path_195" fill="#FFFFFF" d="M25.4,63.6c1.9,4.2,9.9,2.9,13.3,3s3.7,1.4,2.7,3.2c-2,3.3-3.7,6.8-5.1,10.4
                            c-0.8,3.8,1.1,7.6,4.6,9.1c3.2,0.6,3.5-4.5,3.5-4.5c0.8-6.1,6.9-11.2,8.6-13c1.6-2.6,3-5.2,4.2-8c1.1-1.7,2.4-3.3,3.8-4.7H64V35.5
                            c-1.3-1.3-2.7-2.4-4.3-3.4h-28c-4.8,0.8-3.4,6.9-3.4,6.9c-2.1,2-2.5,5.3-1,7.7c-5.1,5-1.1,9-1.1,9C24.2,57.8,23.8,61.1,25.4,63.6z
                            "/>
                        <path id="Path_196" fill="#FFFFFF" d="M68.2,62.3h14c1.1,0,1.9-0.9,1.9-1.9V33.2c0-1.1-0.9-1.9-1.9-1.9h-14
                            c-1.1,0-1.9,0.9-1.9,1.9l0,0v27.1C66.3,61.4,67.1,62.3,68.2,62.3L68.2,62.3z M75.7,35.1c1.4,0,2.6,1.2,2.6,2.6s-1.2,2.6-2.6,2.6
                            s-2.6-1.2-2.6-2.6S74.3,35.1,75.7,35.1L75.7,35.1z"/>
                    </g>
                </g>
                </svg>
                // <ThumbDownRounded onClick={dislikeHandler}/>
            );
        }
    }
    return (
        <div className="" >
            <div className="px-3 py-2">
                <div className="pb-3">
                    <div className="questionTopLeft">
                        <span className="answer_text">{answer.message}</span>
                    </div>                    
                </div>
                <div className="answerBottom row">
                    <div className="questionBottomLeft col-10 no-gutters">
                        <div className="col-4 d-flex no-gutters">
                            <div className="col-3" >
                                {answer.username === "Anonymous" ? 
                                <img
                                    className="questionProfileImg"
                                    src={answer.profilePicture ? process.env.REACT_APP_BACKEND_URL + answer.profilePicture : process.env.REACT_APP_BACKEND_URL + process.env.REACT_APP_ProfileAvathar_Url}
                                    alt=""
                                />:
                                <Link to={{
                                        pathname: '/myprofile/' + answer.userId
                                        // state : question
                                    }} style={{ color: 'black' }}>
                                    <img
                                        className="questionProfileImg"
                                        src={answer.profilePicture ? process.env.REACT_APP_BACKEND_URL + answer.profilePicture : process.env.REACT_APP_BACKEND_URL + process.env.REACT_APP_ProfileAvathar_Url}
                                        alt=""
                                    />
                                </Link>}
                            </div>
                        
                            <div className="col-9 question_user ml-2">
                                <div style={{"display": "flex"}}>
                                    <span className="questionUsername">{answer.username}</span>
                                    {/* <svg version="1.1" width="20px" id="Layer_1" xmlns="http://www.w3.org/2000/svg" xmlnsXlink="http://www.w3.org/1999/xlink" x="0px" y="0px"
                                        viewBox="0 0 120 120" enable-background="new 0 0 120 120" xmlSpace="preserve">
                                        <g id="Group_1561">                                        
                                            <linearGradient id="Path_197_1_" gradientUnits="userSpaceOnUse" x1="19.5121" y1="21.7125" x2="19.5121" y2="28.702" gradientTransform="matrix(16.024 0 0 16.024 -252.6618 -343.9209)">
                                                <stop  offset="0" style="stop-color:#06BDB7"/>
                                                <stop  offset="1" style="stop-color:#03EEE6"/>
                                            </linearGradient>
                                            <path id="Path_197" fill="url(#Path_197_1_)" d="M60,4c30.9,0,56,25.1,56,56s-25.1,56-56,56S4,90.9,4,60l0,0C4,29.1,29.1,4,60,4z"
                                                />
                                            <path id="Icon_open-check" fill="#FFFFFF" d="M80.5,37.7L75.4,43L52.5,65.9l-8.1-8.1l-5.3-5.3L31,60.6l5.3,5.3L47.4,77l5.1,5.3
                                                l5.3-5.3l25.9-25.9l5.3-5.3L80.5,37.7z"/>
                                        </g>
                                    </svg>                                */}
                                </div>                                    
                                <span className="questionJob">{question.userJob}Pharmacy Assistant</span>
                                {/* <div className="questionDate ml-0">{time}</div> */}
                            </div>
                        </div>                        
                        <div className="col-4 no-gutters " style={{"display" : "flex"}}>
                            <span className="answerActionsSpace cursor col-6 ">{likeIcon()} {"  " + answer.likes.length}</span>
                            <span className="answerActionsSpace cursor col-6 ">{disLikeIcon()}{"  " + answer.dislikes.length}</span>                            
                        </div>
                        <div className="col-1 questionTopRight">
                            <div>
                                <IconButton
                                    onClick={handleMenuClick}
                                    size="small"
                                    sx={{ ml: 2 }}
                                    aria-controls={open ? 'account-menu' : undefined}
                                    aria-haspopup="true"
                                    aria-expanded={open ? 'true' : undefined}
                                >
                                    <svg version="1.1" width="25px" id="Layer_1" xmlns="http://www.w3.org/2000/svg" xmlnsXlink="http://www.w3.org/1999/xlink" x="0px" y="0px"
                                        viewBox="0 0 120 120" enable-background="new 0 0 120 120" xmlSpace="preserve">
                                    <g id="Group_2017" transform="translate(-1291 -358)">
                                        <g id="Ellipse_289" transform="translate(1291 358)">
                                            <circle fill="none" cx="60" cy="60" r="56"/>
                                            <circle fill="none" stroke="#BDC9DE" stroke-width="3.7333" cx="60" cy="60" r="54.1"/>
                                        </g>
                                        <g id="Group_2016" transform="translate(1504.627 -2256.78) rotate(90)">
                                            <g id="Ellipse_286" transform="translate(2627.646 188.627)">
                                                <circle fill="none" stroke="#CCD5E5" stroke-width="3.7333" cx="47.8" cy="-63.7" r="6.8"/>
                                            </g>
                                            <g id="Ellipse_287" transform="translate(2627.646 196.351)">
                                                <circle fill="none" stroke="#CCD5E5" stroke-width="3.7333" cx="47.8" cy="-42.6" r="6.8"/>
                                            </g>
                                            <g id="Ellipse_288" transform="translate(2627.646 204.075)">
                                                <circle fill="none" stroke="#CCD5E5" stroke-width="3.7333" cx="47.8" cy="-21.5" r="6.8"/>
                                            </g>
                                        </g>
                                    </g>
                                    </svg>
                                </IconButton>
                                <Menu
                                    anchorEl={anchorEl}
                                    getContentAnchorEl={null}
                                    id="account-menu"
                                    open={open}
                                    onClose={handleMenuClose}
                                    onClick={handleMenuClose}
                                    PaperProps={{
                                        elevation: 0,
                                        sx: {
                                            overflow: 'visible',
                                            filter: 'drop-shadow(0px 2px 8px rgba(0,0,0,0.32))',
                                            mt: 1.5,
                                            '& .MuiAvatar-root': {
                                                width: 32,
                                                height: 32,
                                                ml: -0.5,
                                                mr: 1,
                                            },
                                            '&:before': {
                                                content: '""',
                                                display: 'block',
                                                position: 'absolute',
                                                top: 0,
                                                right: 14,
                                                width: 10,
                                                height: 10,
                                                bgcolor: 'background.paper',
                                                transform: 'translateY(-50%) rotate(45deg)',
                                                zIndex: 0,
                                            },
                                        },
                                    }}
                                    transformOrigin={{ horizontal: 'right', vertical: 'top' }}
                                    anchorOrigin={{ horizontal: 'right', vertical: 'bottom' }}
                                >
                                    {question.userId === user._id ?
                                        <MenuItem onClick={solveHandle}>
                                            {answer.solved ?
                                                <div>
                                                    <Undo/><span className="menuOptions">Unsolved</span>
                                                </div> :
                                                <div>
                                                    <Done /><span className="menuOptions">Solved</span>
                                                </div>}
                                        </MenuItem> : <></>
                                    }
                                    {(user._id === answer.userId) && (user.userType !== "Guest") ?
                                        <MenuItem onClick={handleEditModalOpen}>
                                            <svg version="1.1" id="Layer_1" width="25px" xmlns="http://www.w3.org/2000/svg" xmlnsXlink="http://www.w3.org/1999/xlink" x="0px" y="0px"
                                                    viewBox="0 0 120 120" enableBackground="new 0 0 120 120" xmlSpace="preserve">
                                                    <path id="Icon_material-edit" fill="#07BEB8" d="M5.1,92.7V116H28l67.4-68.8L72.5,23.8L5.1,92.7z M113.1,29.1c2.4-2.4,2.4-6.3,0-8.8
                                                        L98.8,5.8c-2.3-2.4-6.1-2.4-8.5-0.1c0,0-0.1,0.1-0.1,0.1L79.1,17.2L102,40.5L113.1,29.1L113.1,29.1z"/>
                                                </svg><span className="menuOptions">Edit</span>
                                        </MenuItem> : <div></div>
                                    }
                                    {user._id === answer.userId ?
                                        <MenuItem onClick={deleteAnswer}>
                                            <svg version="1.1" width="25px" id="Layer_1" xmlns="http://www.w3.org/2000/svg" xmlnsXlink="http://www.w3.org/1999/xlink" x="0px" y="0px"
                                                viewBox="0 0 120 120" enable-background="new 0 0 120 120" xmlSpace="preserve">
                                            <g>
                                                <path fill="#6A7791" d="M65.4,41.6h8.1V86h-8.1V41.6z"/>
                                                <path fill="#6A7791" d="M46.5,41.6h8.1V86h-8.1V41.6z"/>
                                                <path fill="#6A7791" d="M69.1,3.7H50.9c-2.9,0-5.6,1.1-7.6,3.2c-2,2-3.2,4.8-3.2,7.6v6.6h-26c-1.4,0-2.8,0.8-3.5,2
                                                    c-0.7,1.2-0.7,2.8,0,4c0.7,1.2,2.1,2,3.5,2h7.2l3.9,70.5h0c0.2,4.5,2.2,8.7,5.5,11.7c3.3,3.1,7.6,4.8,12,4.8h34.6
                                                    c4.5,0,8.8-1.7,12-4.8c3.3-3.1,5.2-7.3,5.5-11.7l3.9-70.5h7.2h0c1.4,0,2.8-0.8,3.5-2c0.7-1.2,0.7-2.8,0-4c-0.7-1.2-2.1-2-3.5-2
                                                    H79.8v-6.6c0-2.9-1.1-5.6-3.2-7.6C74.7,4.9,71.9,3.7,69.1,3.7L69.1,3.7z M48.2,14.5L48.2,14.5c0-1.5,1.2-2.7,2.7-2.7h18.2
                                                    c0.7,0,1.4,0.3,1.9,0.8c0.5,0.5,0.8,1.2,0.8,1.9v6.6H48.2L48.2,14.5z M90.6,29.2l-3.9,70.1c-0.1,2.4-1.2,4.7-2.9,6.3
                                                    c-1.8,1.7-4.1,2.6-6.5,2.6H42.6c-2.4,0-4.7-0.9-6.5-2.6c-1.8-1.7-2.8-3.9-2.9-6.3l-3.9-70.1H90.6z"/>
                                            </g>
                                            </svg><span className="menuOptions">Delete</span>
                                        </MenuItem> : <div></div>
                                    }
                                    <MenuItem>                                        
                                        <a  href={`https://api.whatsapp.com/send?phone=&text=${process.env.REACT_APP_FRONTEND_URL}` + history.location.pathname + '/' + question._id}>
                                            <svg version="1.1"  width="25px" id="Layer_1" xmlns="http://www.w3.org/2000/svg" xmlnsXlink="http://www.w3.org/1999/xlink" x="0px" y="0px"
                                                viewBox="0 0 120 120" enable-background="new 0 0 120 120" xmlSpace="preserve">
                                                <g id="Icon_feather-share-2" transform="translate(-3.75 -2.25)">
                                                    <path id="Path_121" fill="none" stroke="#7789AC" stroke-width="7.8" stroke-linecap="round" stroke-linejoin="round" d="
                                                        M110.6,25.9c0,8.6-7,15.6-15.6,15.6s-15.6-7-15.6-15.6s7-15.6,15.6-15.6S110.6,17.2,110.6,25.9z"/>
                                                    <path id="Path_122" fill="none" stroke="#7789AC" stroke-width="7.8" stroke-linecap="round" stroke-linejoin="round" d="
                                                        M48.2,62.2c0,8.6-7,15.6-15.6,15.6S17,70.9,17,62.2s7-15.6,15.6-15.6S48.2,53.6,48.2,62.2z"/>
                                                    <path id="Path_123" fill="none" stroke="#7789AC" stroke-width="7.8" stroke-linecap="round" stroke-linejoin="round" d="
                                                        M110.6,98.7c0,8.6-7,15.6-15.6,15.6s-15.6-7-15.6-15.6s7-15.6,15.6-15.6S110.6,90,110.6,98.7z"/>
                                                    <path id="Path_124" fill="none" stroke="#7789AC" stroke-width="7.8" stroke-linecap="round" stroke-linejoin="round" d="M46,70.1
                                                        l35.5,20.7"/>
                                                    <path id="Path_125" fill="none" stroke="#7789AC" stroke-width="7.8" stroke-linecap="round" stroke-linejoin="round" d="
                                                        M81.5,33.7L46,54.4"/>
                                                </g>
                                            </svg><span className="menuOptions">Share</span>
                                        </a> 
                                    </MenuItem>
                                </Menu>

                            </div>
                            <Modal
                                show={showEditModal}
                                onHide={handleEditModalClose}
                                size="md"
                                aria-labelledby="contained-modal-title-vcenter"
                                centered
                            >
                                <Modal.Header >
                                    <Modal.Title>Edit</Modal.Title>
                                </Modal.Header>
                                <Modal.Body>
                                    <textarea
                                        class="form-control"
                                        id="new_question"
                                        rows="2"
                                        value={editvalue===null?answer.message:editvalue}
                                        onChange={(e) => { setEditvalue(e.target.value);}}>
                                    </textarea>
                                </Modal.Body>
                                <Modal.Footer>
                                    <Button variant="secondary" onClick={handleEditModalClose}>
                                        Close
                                    </Button>
                                    <Button variant="primary" onClick={updateAnswer}>
                                        Update
                                    </Button>
                                </Modal.Footer>
                            </Modal>
                        </div>
                        <span className="col-3 questionDate " style={{"display" : "flex","justifyContent":"right"}}>{time}</span>                        
                    </div>
                    <div className="col-2 cursor" style={{"display" : "flex", "alignItems" : "center", "justifyContent" : "flex-end"}}>
                        {answer.solved ? 
                        <>
                            <button className="btn btn__outlined btn__primary">
                                <svg version="1.1" width="15px" id="Layer_1" xmlns="http://www.w3.org/2000/svg" xmlnsXlink="http://www.w3.org/1999/xlink" x="0px" y="0px"
                                    viewBox="0 0 120 120" enable-background="new 0 0 120 120" xmlSpace="preserve">
                                <path id="Path_542" fill="#51C8AF" d="M42.8,106l-40-41.3l16.1-14.9l23.9,25.8l59-61.5l15.3,13.5L42.8,106z"/>
                                </svg> Ans
                            </button>
                        </> : <></>}
                    </div>
                </div>
            </div>
        </div>
    );
}

export default SingleAnswer;