import React,{useState,useContext} from "react";
import { Cancel, Comment, Delete,Edit, MoreHoriz, Report, ThumbsUpDownRounded, ThumbUp } from "@material-ui/icons";
import Menu from "@material-ui/core/Menu";
import MenuItem from '@material-ui/core/MenuItem';
import { Button, Modal } from "react-bootstrap";
import IconButton from "@material-ui/core/IconButton";
import { AuthContext } from "../../context/AuthContext";
import axios from "axios";
import { format } from "timeago.js";

const Comments = ({c, post, fetchData, index}) => {
    let { user } = useContext(AuthContext);
    const [isReadMore, setIsReadMore] = useState(true);
    const [anchorEl, setAnchorEl] = useState(null);
    const open = Boolean(anchorEl);
    const [showEditModal, setShowEditModal] = useState(false);
    const [toggleEdit, setToggleEdit] = useState(false);
    const [editvalue, setEditvalue] = useState(null);

    if (!user) {
        user = {
            userId: 123,
            username: "Guest",
            userType: "Guest"
        }
    }
    
    const toggleReadMore = (index) => {
        setIsReadMore(!isReadMore);
    };

    function keyPressEnter(e){
        console.log(e.keyCode == 13 && e.shiftKey)
        if(e.keyCode == 13 && e.shiftKey)
        {}
        else if(e.key === "Enter")
        {
            updateComment(index)
        }
    }
    function commentValue () {
        if(!toggleEdit && c.comment){
            return(
                c.comment.length >= 150 ? 
                    <div>{isReadMore ? c.comment.slice(0, 150) : c.comment}
                        <span  onClick={()=>toggleReadMore(index)} className="read-or-hide">
                            {isReadMore ? "...read more" : " show less"}
                        </span>
                    </div> : 
                    <span>{c.comment}</span>
            );
        }
        else{
            return(
                <div className="d-flex">
                    <textarea 
                        className="form-control"
                        id="new_question"
                        rows="2"
                        value={editvalue===null?c.comment:editvalue}
                        onKeyDown={(e)=>keyPressEnter(e)}
                        onChange={(e) => { setEditvalue(e.target.value);}}>
                    </textarea>
                    <Cancel className="cursor" onClick={()=>{setToggleEdit(false); setEditvalue(null)}}/>
                </div>
                
            );
        }
    }
    //------- Handling Menu 
    const handleMenuClick = (event) => {
        setAnchorEl(event.currentTarget);
    };
    const handleMenuClose = () => {
        setAnchorEl(null);
    };

    //------- Handling Edit Modal
    const handleEditModalOpen = () => {
        setShowEditModal(true)
    };
    const handleEditModalClose = () => {
        setEditvalue(null);
        setShowEditModal(false);
    };
    const deleteComment = async (index) => {
        // console.log("-------------->>",index);
        post.comments.splice(index,1);
        try {
            await axios.put(`${process.env.REACT_APP_BACKEND_URL}/api/feed/` + post._id + `/comments`, post)
        }catch(err){
            console.log(err)
        }
        fetchData();
    }

    //-------- Update Comment
    const updateComment = async (index) => {
        post.comments[index].comment = editvalue;
        try{
            await axios.put(`${process.env.REACT_APP_BACKEND_URL}/api/feed/` + post._id + `/comments`, post)
        }catch(err){
            console.log("Error in deleting comment ", err);
        }
        setToggleEdit(false);
        // handleEditModalClose();
    }
    return (
        <div className="row no-gutters m-2 py-3">
            <div className="col-1">
                <img src={c.userImage ? process.env.REACT_APP_BACKEND_URL + c.profilePicture : process.env.REACT_APP_BACKEND_URL + process.env.REACT_APP_ProfileAvathar_Url} className="userPostDetails"/>
            </div>
            <div className="col-11">
                <div className="row">
                    <div className="col-2">
                        <span style={{"fontSize" : "1.1rem", "fontWeight" : "600"}}>{c.username}</span>
                    </div>
                    <div className="col-10">
                        <span style={{"fontWeight" : "300", "fontSize" : "0.8rem", "float" : "right"}}>{format(c.createdAt)}</span>
                    </div>
                </div>
                <div className="row">
                    <div className="col-10" style={{"color" : "#7b7b7b", "fontSize" : "0.95rem", "fontWeight" : "400"}}>
                        {commentValue()}
                    </div>
                    <div className="col-2">
                        <IconButton
                                    onClick={handleMenuClick}
                                    size="small"
                                    sx={{ ml: 2 }}
                                    aria-controls={open ? 'account-menu' : undefined}
                                    aria-haspopup="true"
                                    aria-expanded={open ? 'true' : undefined}
                                    style={{"float" : "right"}}
                                >
                                    <MoreHoriz />
                                </IconButton>
                                <Menu
                                    anchorEl={anchorEl}
                                    getContentAnchorEl={null}
                                    id="account-menu"
                                    open={open}
                                    onClose={handleMenuClose}
                                    onClick={handleMenuClose}
                                    PaperProps={{
                                        elevation: 0,
                                        sx: {
                                            overflow: 'visible',
                                            filter: 'drop-shadow(0px 2px 8px rgba(0,0,0,0.32))',
                                            mt: 1.5,
                                            '& .MuiAvatar-root': {
                                                width: 32,
                                                height: 32,
                                                ml: -0.5,
                                                mr: 1,
                                            },
                                            '&:before': {
                                                content: '""',
                                                display: 'block',
                                                position: 'absolute',
                                                top: 0,
                                                right: 14,
                                                width: 10,
                                                height: 10,
                                                bgcolor: 'background.paper',
                                                transform: 'translateY(-50%) rotate(45deg)',
                                                zIndex: 0,
                                            },
                                        },
                                    }}
                                    transformOrigin={{ horizontal: 'right', vertical: 'top' }}
                                    anchorOrigin={{ horizontal: 'right', vertical: 'bottom' }}
                                >
                                    {(c.userId === user._id) && (user.userType !== "Guest") ?
                                        <MenuItem onClick={()=>setToggleEdit(!toggleEdit)}>
                                            <svg version="1.1" id="Layer_1" width="25px" xmlns="http://www.w3.org/2000/svg" xmlnsXlink="http://www.w3.org/1999/xlink" x="0px" y="0px"
                                                viewBox="0 0 120 120" enableBackground="new 0 0 120 120" xmlSpace="preserve">
                                                <path id="Icon_material-edit" fill="#07BEB8" d="M5.1,92.7V116H28l67.4-68.8L72.5,23.8L5.1,92.7z M113.1,29.1c2.4-2.4,2.4-6.3,0-8.8
                                                    L98.8,5.8c-2.3-2.4-6.1-2.4-8.5-0.1c0,0-0.1,0.1-0.1,0.1L79.1,17.2L102,40.5L113.1,29.1L113.1,29.1z"/>
                                            </svg><span className="menuOptions">Edit</span>
                                        </MenuItem> :
                                        <></>
                                    }
                                    {(c.userId === user._id) && (user.userType !== "Guest") ?
                                        <MenuItem onClick={()=>{deleteComment(index)}}>
                                            <svg version="1.1" width="25px" id="Layer_1" xmlns="http://www.w3.org/2000/svg" xmlnsXlink="http://www.w3.org/1999/xlink" x="0px" y="0px"
                                                viewBox="0 0 120 120" enable-background="new 0 0 120 120" xmlSpace="preserve">
                                            <g>
                                                <path fill="#6A7791" d="M65.4,41.6h8.1V86h-8.1V41.6z"/>
                                                <path fill="#6A7791" d="M46.5,41.6h8.1V86h-8.1V41.6z"/>
                                                <path fill="#6A7791" d="M69.1,3.7H50.9c-2.9,0-5.6,1.1-7.6,3.2c-2,2-3.2,4.8-3.2,7.6v6.6h-26c-1.4,0-2.8,0.8-3.5,2
                                                    c-0.7,1.2-0.7,2.8,0,4c0.7,1.2,2.1,2,3.5,2h7.2l3.9,70.5h0c0.2,4.5,2.2,8.7,5.5,11.7c3.3,3.1,7.6,4.8,12,4.8h34.6
                                                    c4.5,0,8.8-1.7,12-4.8c3.3-3.1,5.2-7.3,5.5-11.7l3.9-70.5h7.2h0c1.4,0,2.8-0.8,3.5-2c0.7-1.2,0.7-2.8,0-4c-0.7-1.2-2.1-2-3.5-2
                                                    H79.8v-6.6c0-2.9-1.1-5.6-3.2-7.6C74.7,4.9,71.9,3.7,69.1,3.7L69.1,3.7z M48.2,14.5L48.2,14.5c0-1.5,1.2-2.7,2.7-2.7h18.2
                                                    c0.7,0,1.4,0.3,1.9,0.8c0.5,0.5,0.8,1.2,0.8,1.9v6.6H48.2L48.2,14.5z M90.6,29.2l-3.9,70.1c-0.1,2.4-1.2,4.7-2.9,6.3
                                                    c-1.8,1.7-4.1,2.6-6.5,2.6H42.6c-2.4,0-4.7-0.9-6.5-2.6c-1.8-1.7-2.8-3.9-2.9-6.3l-3.9-70.1H90.6z"/>
                                            </g>
                                            </svg><span className="menuOptions">Delete</span>
                                        </MenuItem> :
                                        <></>
                                    }
                                    <MenuItem>
                                        <svg version="1.1" width="25px" id="Layer_1" xmlns="http://www.w3.org/2000/svg" xmlnsXlink="http://www.w3.org/1999/xlink" x="0px" y="0px"
                                            viewBox="0 0 120 120" enable-background="new 0 0 120 120" xmlSpace="preserve">
                                        <g id="alert-circle" transform="translate(-1.599 -1.599)">
                                            
                                                <circle id="Ellipse_414" fill="none" stroke="#5D697E" stroke-width="9.7911" stroke-linecap="round" stroke-linejoin="round" cx="61.6" cy="61.6" r="50"/>
                                            
                                                <line id="Line_11" fill="none" stroke="#5D697E" stroke-width="9.7911" stroke-linecap="round" stroke-linejoin="round" x1="61.6" y1="36.6" x2="61.6" y2="61.6"/>
                                            
                                                <line id="Line_12" fill="none" stroke="#5D697E" stroke-width="9.7911" stroke-linecap="round" stroke-linejoin="round" x1="61.6" y1="82.2" x2="61.7" y2="82.2"/>
                                        </g>
                                        </svg><span className="menuOptions">Report</span>
                                    </MenuItem>
                                </Menu>
                            
                            <Modal
                                    show={showEditModal}
                                    onHide={handleEditModalClose}
                                    size="md"
                                    aria-labelledby="contained-modal-title-vcenter"
                                    centered
                                >
                                    <Modal.Header >
                                        <Modal.Title>Edit</Modal.Title>
                                    </Modal.Header>
                                    <Modal.Body>
                                        <textarea
                                            class="form-control"
                                            id="new_question"
                                            rows="2"
                                            value={editvalue===null?c.comment:editvalue}
                                            onChange={(e) => { setEditvalue(e.target.value);}}>
                                        </textarea>
                                    </Modal.Body>
                                    <Modal.Footer>
                                        <Button variant="secondary" onClick={handleEditModalClose}>
                                            Close
                                        </Button>
                                        <Button variant="primary" onClick={()=>{updateComment(index)}}>
                                            Update
                                        </Button>
                                    </Modal.Footer>
                            </Modal>       
                    </div>
                </div>
            </div>
        </div>
                );
            
}

export default Comments;