import React, { useState, useEffect, useContext } from "react";
import { AuthContext } from "../../context/AuthContext";
import axios from "axios";



const areaOfInterest = ["Finance", "Human Resource", "Pharmacy", "Accounts", "Administration"];
const time = ["Oldest", "Newest"];
const others = ["Solved", "Unsolved"];

const Filter = (props) => {
  let { user } = useContext(AuthContext);
  const [settingsData, setSettingsData] = useState({});
  const [Skip, setSkip] = useState(0);
  const [Limit, setLimit] = useState(8);
  const [Filters, setFilters] = useState({
    sharedTo: [],
    price: []
  })

  //filter dragdown list
  const [aoi_toggle, setAoi_toggle] = useState(true);
  const [time_toggle, setTime_toggle] = useState(false);
  const [others_toggle, setOthers_toggle] = useState(false);

  //filter values

  const [Checked, setChecked] = useState([]);

  const aoiToggleFunction = (value) => {

    const currentIndex = Checked.indexOf(value);
    const newChecked = [...Checked];

    if (currentIndex === -1) {
      newChecked.push(value)
    } else {
      newChecked.splice(currentIndex, 1)
    }
    setChecked(newChecked)
    handleFilters(newChecked, "sharedTo")
  }

  //handle Filters
  const handleFilters = (filters, category) => {

    const newFilters = { ...Filters }

    newFilters[category] = filters;

    showFilteredResults(newFilters)
    setFilters(newFilters)
  }

  const showFilteredResults = (filters) => {

    if (filters.sharedTo.length > 0) {
      const variables = {
        skip: 0,
        limit: Limit,
        filters: filters

      }
      props.getQuestions(variables)
      setSkip(0)
    }else{
      props.fetchData();
    }

  }


  const fetchSettings = async () => {
    var res = await axios.get(`${process.env.REACT_APP_BACKEND_URL}/api/settings`);
    (res.data).forEach((dashboards) => {
      if (dashboards.pageType === "forum" && dashboards.nameType === "Filter Data") {
        setSettingsData(dashboards);
      }
    })
  }

  useEffect(() => {
    fetchSettings();
  }, []);

  if (!user) {
    user = {
      userId: 123,
      username: "Guest",
      userType: "Guest"
    }
  }

  const displayAOIOptions = () => {
    return (
      <table>
        <thead>
          <tr>
            <th style={{ "width": "10%" }}></th>
            <th style={{ "width": "90%" }}></th>
          </tr>
        </thead>
        <tbody>
          {areaOfInterest.map((area, idx) => {
            return (
              <tr key={idx}>
                <td>
                  <input onChange={() => aoiToggleFunction(area)}
                    type="checkbox"
                    checked={Checked.indexOf(area) === -1 ? false : true} />
                </td>
                <td>
                  {area}
                </td>
              </tr>
            );
          })}
        </tbody>
      </table>
    )
  }
  const displayTimeOptions = () => {
    return (
      <table>
        <thead>
          <tr>
            <th style={{ "width": "10%" }}></th>
            <th style={{ "width": "90%" }}></th>
          </tr>
        </thead>
        <tbody>
          {time.map((t, idx) => {
            return (
              <tr key={idx}>
                <td>
                  <input type={"radio"} />
                </td>
                <td>
                  {t}
                </td>
              </tr>
            );
          })}
        </tbody>
      </table>
    )
  }
  const displayOthersOptions = () => {
    return (
      <table>
        <thead>
          <tr>
            <th style={{ "width": "10%" }}></th>
            <th style={{ "width": "90%" }}></th>
          </tr>
        </thead>
        <tbody>
          {others.map((o, idx) => {
            return (
              <tr key={idx}>
                <td>
                  <input type={"checkbox"} />
                </td>
                <td>
                  {o}
                </td>
              </tr>
            );
          })}
        </tbody>
      </table>
    )
  }

  function filterData() {
    return (
      <div className="stickLeft container_wrapper" 
      // style={{"width" : "185px"}}
      >
        <table>
          <tbody>
            <tr className="cursor" >
              <td>
                {/* <div className="popular_heading d-flex">
                  <p>Categories</p>
                </div> */}
                <span onClick={() => setAoi_toggle(!aoi_toggle)} className="fontHeader p-2">Categories</span>
                {aoi_toggle ? <div>{displayAOIOptions()}</div> : <div></div>}
              </td>
            </tr>

            {/* <tr className="cursor">
              <td>
                <span onClick={() => setTime_toggle(!time_toggle)}>Time Preferences</span>
                {time_toggle ? <div>{displayTimeOptions()}</div> : <div></div>}
              </td>
            </tr>

            <tr className="cursor" >
              <td>
                <span onClick={() => setOthers_toggle(!others_toggle)}>Others</span>
                {others_toggle ? <div>{displayOthersOptions()}</div> : <div></div>}
              </td>
            </tr> */}
          </tbody>
        </table>
      </div>
    );
  }

  return (
    <div className="">
      {/* <button className="checking">hello</button> */}
      {user.userType === "Guest" && settingsData.guest && filterData()}
      {user.userType === "free" && (settingsData.free && user.expert === false)&& filterData() }
      {user.userType === "paid" && (settingsData.paid && !settingsData.paidExpert)&& filterData()}
      {user.userType === "free" && (user.expert === true && settingsData.freeExpert) && filterData()}
      {user.userType === "paid" && (user.expert && settingsData.paidExpert) && filterData()}
      {user.userType === "consultant" && settingsData.consultant && filterData()}
    </div>
  );
};

export default Filter;