import PropTypes from "prop-types";
import { Link } from "react-router-dom";
import Particle from "../particles/Particle";
import Tab from "react-bootstrap/Tab";
import Nav from "react-bootstrap/Nav";
import Login from "../login-register/login";
import Register from "../login-register/register";
import Filter from "../filter/Filter";
import QuestionsContainer from "../../containers/questions/QuestionsContainer";
import PopularQuestions from "../popularActivity/PopularQuestions";
import React, { useState, useEffect } from "react";
import axios from "axios";
import TablePagination from '@mui/material/TablePagination';
import Ads from "../popularActivity/Ads";
import FilterPart from "../filter/FilterPart";

const ForumQuestions = ({ data }) => {
  const [questions, setQuestions] = useState([]);
  const [QuestionSize, setQuestionSize] = useState()

  const [paginationQuestion, setPaginationQuestion] = useState([]);
  const [page, setPage] = useState(0);
  const [rowsPerPage, setRowsPerPage] = useState(10);

  const handleChangePage = (event, newPage) => {
    setPage(newPage);
    var startPage = newPage * rowsPerPage;
    var endPage = (newPage + 1) * rowsPerPage;
    setQuestionSize(questions.length);
    setPaginationQuestion(questions.slice(startPage, endPage));
  };

  const handleChangeRowsPerPage = (event) => {
    setRowsPerPage(parseInt(event.target.value, 10));
    setPage(0);
    var startPage = page * event.target.value;
    var endPage = (page + 1) * event.target.value;
    setQuestionSize(questions.length);
    setPaginationQuestion(questions.slice(startPage, endPage));
  };


  // this function is used only for search
  const getQuestions = async (variables) => {
    var userData = await axios.get(`${process.env.REACT_APP_BACKEND_URL}/api/users/users`);
    axios.post(`${process.env.REACT_APP_BACKEND_URL}/api/question/getquestions`, variables)
      .then(response => {
        if (response.data.success) {
          for (var i = 0; i < response.data.questions.length; i++) {
            for (var j = 0; j < userData.data.length; j++) {
               if(userData.data[j]._id==response.data.questions[i].userId ){
                 if(response.data.questions[i].username == 'Anonymous'){
                  response.data.questions[i].profilePicture=response.data.questions[i].userImage;
                  break;
                 }else{
                  response.data.questions[i].profilePicture=userData.data[j].profilePicture;
                  break;
                 }
               }
            }
          }
          if (variables.loadMore) {
            setQuestions([...questions, ...response.data.questions]);
            var startPage = page * rowsPerPage;
            var endPage = (page + 1) * rowsPerPage;
            setQuestionSize((response.data.questions).length);
            setPaginationQuestion((response.data.questions).slice(startPage, endPage));
          } else {
            setQuestions(response.data.questions);
            var startPage = page * rowsPerPage;
            var endPage = (page + 1) * rowsPerPage;
            setQuestionSize((response.data.questions).length);
            setPaginationQuestion((response.data.questions).slice(startPage, endPage));
          }
        } else {
          alert('Failed to fectch product datas');
        }
      })
  }

  const fetchData = async () => {
    try {
      var res = await axios.get(`${process.env.REACT_APP_BACKEND_URL}/api/question`);
      var userData = await axios.get(`${process.env.REACT_APP_BACKEND_URL}/api/users/users`);

      for (var i = 0; i < res.data.length; i++) {
        for (var j = 0; j < userData.data.length; j++) {
           if(userData.data[j]._id==res.data[i].userId ){
             if(res.data[i].username == 'Anonymous'){
              res.data[i].profilePicture=res.data[i].userImage;
              break;
             }else{
              res.data[i].profilePicture=userData.data[j].profilePicture;
              break;
             }
           }
        }
      }
    
      var sortedList = await res.data.sort((p1, p2) => {
        return new Date(p2.createdAt) - new Date(p1.createdAt);
      })
      setQuestions(sortedList);
      var startPage =page*rowsPerPage;
      var endPage= (page+1)*rowsPerPage;
      setPage(0);
      setQuestionSize(sortedList.length);
      setPaginationQuestion(sortedList.slice(startPage,endPage));
    } catch (err) {
      console.log(err)
    }
  }

  useEffect(() => {
    fetchData();
  }, []);

  return (
    <div className="row articles_page_container ">
      <div className="filterPart col-3" style={{"paddingTop" : "15px", "maxWidth" : "315px"}}>
        <div className="stickLeft">
        {/* <Filter fetchData={fetchData} getQuestions={getQuestions} /> */}
        <FilterPart fetchData={fetchData} getQuestions={getQuestions}/>
        </div>
        
      </div>
      <div className="col-6 questionPart" style={{ "maxWidth" : "700px"}}>
        <QuestionsContainer fetchData={fetchData} getQuestions={getQuestions} questions={paginationQuestion} />
        <TablePagination
          component="div"
          count={QuestionSize}
          page={page}
          onPageChange={handleChangePage}
          rowsPerPage={rowsPerPage}
          onRowsPerPageChange={handleChangeRowsPerPage}
        />
      </div>
      <div className=" popularPart col-3" style={{"maxWidth" : "315px"}}>
        {/* <span className="forum_title">Popular Activity</span> */}
        <div className="stickLeft">
          <PopularQuestions />
          {/* <Ads /> */}
        </div>
      </div>
    </div>
  );
};

ForumQuestions.propTypes = {
  data: PropTypes.object
};

export default ForumQuestions;
