import { Link, useHistory } from "react-router-dom";
import { AuthContext } from "../../context/AuthContext";
import React, { useContext, useState } from "react";
import { Nav, Navbar, Modal,Button, NavDropdown } from 'react-bootstrap';
import axios from "axios";

const Navigation = () => {
  let { user } = useContext(AuthContext);
  const history = useHistory();
  const [SearchText, setSearchText] = useState("");
  const [questions, setQuestions] = useState([]);
  const [news, setNews] = useState([]);
  const [users, setUsers] = useState([]);
  const [QuestionSize, setQuestionSize] = useState();
  const [paginationQuestion, setPaginationQuestion] = useState([]);
  const [Skip, setSkip] = useState(0);
  const [Limit, setLimit] = useState(8);
  const [page, setPage] = useState(0);
  const [rowsPerPage, setRowsPerPage] = useState(10);
  const [Filters, setFilters] = useState({
    continents: [],
    price: []
  });

  if (!user) {
    user = {
      userId: 123,
      username: "Guest",
      userType: "Guest"
    }
  }

  const onChangeSearch = (event) => {
    // debugger;
    // if(history.location.pathname === '/community')
    setSearchText(event.currentTarget.value)
    if ((event.currentTarget.value.length) > 0) {
      updateSearchTerms(event.currentTarget.value)
    } 
  }

  const updateSearchTerms = (newSearchTerm) => {
    const variables = {
      skip: Skip,
      limit: Limit,
      filters: Filters,
      searchQuestion: newSearchTerm,
      searchNewsAndArticles: newSearchTerm,
      searchUsers: newSearchTerm
    }
    setSkip(0)
    getQuestions(variables);
    getNews(variables);
    getUsers(variables);
  }
  const getQuestions = async (variables) => {
    var userData = await axios.get(`${process.env.REACT_APP_BACKEND_URL}/api/users/users`);
    axios.post(`${process.env.REACT_APP_BACKEND_URL}/api/question/getquestions`, variables)
      .then(response => {
        if (response.data.success) {
          for (var i = 0; i < response.data.questions.length; i++) {
            for (var j = 0; j < userData.data.length; j++) {
               if(userData.data[j]._id==response.data.questions[i].userId ){
                 if(response.data.questions[i].username == 'Anonymous'){
                  response.data.questions[i].profilePicture=response.data.questions[i].userImage;
                  break;
                 }else{
                  response.data.questions[i].profilePicture=userData.data[j].profilePicture;
                  break;
                 }
               }
            }
          }
          if (variables.loadMore) {
            setQuestions([...questions, ...response.data.questions]);
            var startPage = page * rowsPerPage;
            var endPage = (page + 1) * rowsPerPage;
            setQuestionSize((response.data.questions).length);
            setPaginationQuestion((response.data.questions).slice(startPage, endPage));
          } else {
            setQuestions(response.data.questions);
            var startPage = page * rowsPerPage;
            var endPage = (page + 1) * rowsPerPage;
            setQuestionSize((response.data.questions).length);
            setPaginationQuestion((response.data.questions).slice(startPage, endPage));
          }
        } else {
          alert('Failed to fectch product datas');
        }
      });

  }
  const getNews = async (variables) => {
    var userData = await axios.get(`${process.env.REACT_APP_BACKEND_URL}/api/users/users`);
    axios.post(`${process.env.REACT_APP_BACKEND_URL}/api/newsandarticles/getnewsandarticles`, variables)
      .then(response => {
        if (response.data.success) {
          for (var i = 0; i < response.data.newsAndArtices.length; i++) {
            for (var j = 0; j < userData.data.length; j++) {
               if(userData.data[j]._id==response.data.newsAndArtices[i].userId ){
                 if(response.data.newsAndArtices[i].username == 'Anonymous'){
                  response.data.newsAndArtices[i].profilePicture=response.data.newsAndArtices[i].userImage;
                  break;
                 }else{
                  response.data.newsAndArtices[i].profilePicture=userData.data[j].profilePicture;
                  break;
                 }
               }
            }
          }
          setNews(response.data.newsAndArtices);
        } else {
          alert('Failed to fectch product datas');
        }
      });

  }
  const getUsers = async (variables) => {
    var searchedUsers =[];
    // var userData = await axios.get(`${process.env.REACT_APP_BACKEND_URL}/api/users/users`);
    axios.post(`${process.env.REACT_APP_BACKEND_URL}/api/users/getUsersByText`, variables)
    .then(res => {
      for(var i=0;i<res.data.users.length;i++){
        if(res.data.users[i].username.includes(variables.searchUsers)){
          searchedUsers.push(res.data.users[i]);
          console.log("Users----->>>>>>",res.data.users[i].username)
        }      
      }
      setUsers([...searchedUsers]);
    });    
  }

  return (
    <nav className="mainmenu__nav">
      <ul className="mainmenu">

      {user.userType === "Guest" ?<li className="drop">
          <Link to={process.env.PUBLIC_URL + "/home"}>
            {history.location.pathname === '/home' ? <span style={{"color" : "#212529"}}>Home</span> : <span style={{"color" : "#5D697E","opacity" : "1"}}>Home</span>}            
          </Link>
        </li>: <li className="drop">
          <Link to={process.env.PUBLIC_URL + "/home"}>
            {history.location.pathname === '/home' ? <span style={{"color" : "#212529"}}>Home</span> : <span style={{"color" : "#5D697E","opacity" : "1"}}>Home</span>}
          </Link>
        </li>}
       
        <li className="drop">
          <Link to={process.env.PUBLIC_URL + "/community"}>
            {history.location.pathname === '/community' ? <span style={{"color" : "#212529" }}>Community</span> : <span style={{"color" : "#5D697E","opacity" : "1"}}>Community</span>}
          </Link>
        </li>
         <li className="drop">
          <Link to={process.env.PUBLIC_URL + "/news"}>
            {history.location.pathname === '/news' ? <span style={{"color" : "#212529"}}>News</span> : <span style={{"color" : "#5D697E","opacity" : "1"}}>News</span>}
          </Link>
        </li>
        <li className="drop">
          <Link to={process.env.PUBLIC_URL + "/experts"}>
            {history.location.pathname === '/experts' ? <span style={{"color" : "#212529"}}>Experts</span> : <span style={{"color" : "#5D697E","opacity" : "1"}}>Experts</span>}
          </Link>
        </li>
        <li className="drop">
          <Navbar className="navprofile" variant="dark" expand="lg">
              <Navbar.Toggle aria-controls="navbar-dark-example" />
              <Navbar.Collapse id="navbar-dark-example">
                <Nav>  
                {/* <p className="cursor drop logout"> {user.profilePicture? <img className="headerImageProfile" src={process.env.REACT_APP_BACKEND_URL + user.profilePicture} alt="chart images"></img>:<img style={{height:"37px",width:"41px",borderRadius:"50%"}} src={process.env.PUBLIC_URL + "/images/profile/avatar.jpg"} alt="chart images"></img>}</p> */}
                  <NavDropdown 
                  eventKey={1} 
                  title={
                    <div >
                      <input className=" form-control search_bar" type="text" value={SearchText} onChange={onChangeSearch} placeholder="Search" />
                    </div>
                  }                
                    id="nav-dropdown-dark-example"
                    // title="My profile"
                    alignRight
                  >
                    {questions.length === 0 ? <></> : 
                    <NavDropdown.Item>
                      <p>Questions</p>                      
                    </NavDropdown.Item>}
                    {questions.length === 0 ? <></> : questions.map((q,idx)=>{
                      return (
                        <NavDropdown.Item onClick={()=>{history.push('/answers/'+ q._id)}} key={idx}>{q.question}</NavDropdown.Item>
                      )
                    })
                    }
                    {news.length === 0 ? <></> : <NavDropdown.Divider/>}
                    {news.length === 0 ? <></> :
                    <NavDropdown.Item>
                      <p>News</p>                      
                    </NavDropdown.Item>}
                    {news.length === 0 ? <></> : news.map((n,idx)=>{
                      return (
                        <NavDropdown.Item onClick={()=>{history.push('/articles/'+ n._id)}} key={idx}>{n.newsTitle}</NavDropdown.Item>
                      )
                    })
                    }
                    {users.length === 0 ? <></> : <NavDropdown.Divider/>}
                    {users.length === 0 ? <></> :
                    <NavDropdown.Item>
                      <p>Users</p>                      
                    </NavDropdown.Item>}
                    {users.length === 0 ? <></> : users.map((u,idx)=>{
                      return (
                        <NavDropdown.Item onClick={()=>{history.push('/myprofile/'+ u._id)}} key={idx}>{u.username}</NavDropdown.Item>
                      )
                    })
                    }
                  </NavDropdown>
                </Nav>
              </Navbar.Collapse>
            </Navbar>
          {/* <div className="" style={{"padding": "5px"}}>
            <input className="textgreyarea form-control search_bar" type="text" value={SearchText} onChange={onChangeSearch} placeholder="Search" />
          </div> */}
        </li>
        {/* <li className="drop">
          <Link to={process.env.PUBLIC_URL + "/notifications"}>
            <svg version="1.1" width="25px" id="Layer_1" xmlns="http://www.w3.org/2000/svg" xmlnsXlink="http://www.w3.org/1999/xlink" x="0px" y="0px"
              viewBox="0 0 120 120" enableBackground="new 0 0 120 120" xmlSpace="preserve">
              <g id="Icon_ionic-ios-notifications" transform="translate(-6.761 -3.93)">
                <path id="Path_107" fill="#3d504d" d="M66.7,120.3c6.9,0.2,12.7-5.3,12.9-12.2c0-0.6,0-1.3-0.1-1.9H53.8c-0.9,6.9,4,13.2,10.9,14
                  C65.4,120.3,66,120.3,66.7,120.3z"/>
                <path id="Path_108" fill="#3d504d" d="M110.7,92c-4.3-5.8-12.9-9.2-12.9-35.1c0-26.6-11.6-37.3-22.4-39.8c-1-0.3-1.7-0.6-1.7-1.7
                  v-0.9c0.1-3.8-2.9-7-6.7-7.1c-3.8-0.1-7,2.9-7.1,6.7c0,0.1,0,0.3,0,0.4v0.8c0,1.1-0.7,1.4-1.7,1.7C47.3,19.7,35.7,30.4,35.7,57
                  c0,25.9-8.5,29.2-12.9,35.1c-1.9,2.5-1.4,6,1.1,7.9c1,0.7,2.1,1.1,3.4,1.1h78.9c3.1,0,5.6-2.6,5.6-5.7
                  C111.8,94.1,111.4,93,110.7,92z"/>
              </g>
            </svg>
          </Link>
        </li> */}
      </ul>
    </nav>
  );
};

export default Navigation;
