import React, { useEffect, useState, useContext } from "react";
import { AuthContext } from "../../context/AuthContext";
import PropTypes from "prop-types";
import PopularQuestions from "../popularActivity/PopularQuestions";
import axios from "axios";
import { ArrowBackRounded, ArrowRightRounded, Cancel, Comment, Delete,Edit, MoreHoriz, NavigateNext, NavigateNextOutlined, Report, ThumbsUpDownRounded, ThumbUp } from "@material-ui/icons";
import { Button, Modal } from "react-bootstrap";
import {  useHistory } from "react-router-dom";
import CloseIcon from '@mui/icons-material/Close';
import DoneIcon from '@mui/icons-material/Done';
import { useParams } from "react-router-dom";
import Select from "react-select";
import Ads from "../popularActivity/Ads";
import SingleQuestion from "../questions/SingleQuestion";
import SingleArticle from "../NewsAndArticles/SingleArticle";
import SinglePost from "../feed/SinglePost";
import MyQueries from "./MyQueries";
import SavedData from "./SavedData";
import ExpertsList from "./ExpertsList";

const options = [
    { value: "finance", label: "Finance" },
    { value: "pharmacy", label: "Pharmacy" },
    { value: "administration", label: "Administration" },
    { value: "accounts", label: "Accounts" },
    { value: "hr", label: "Human Resource" },
];
const languagesOptions = ["Assamese", "Bengali", "Bodo", "Dogri", "English", "Gujarati", "Hindi", "Kannada", "Kashmiri", "Konkani", "Maithili", "Malayalam", "Marathi",
                         "Meitei", "Nepali", "Odia", "Punjabi", "Sanskrit", "Santali", "Sindhi", "Tamil", "Telugu", "Urdu"];
const areaOfInterest = ["Finance", "Pharmacy", "Accounts", "Administration","Human Resources","Sales & Marketing","OperationsFinance",
                        "Entry level guidance","Soft skill development","Digital transformation","Revenue cycle management","CRM","L&D","Legal and Statutory Audit",
                        "Materials and Procurement","Dealing with the new normal","Promoter management","Leadership and entrepreneurial skills","Change management",
                        "Strategy and business development","Innovation and Ideation","Dealing with workplace politics","Image building","Healthcare Market study",
                        "Innovation and Entreupernership","Hospital Design And Planning","M&A - Healthcare","Investment Opportunities","Research Guidance","Medical Services and Administration"];
var colorIndex = 0;
var colorVariants = {
    textColor : ["#22b8c2","#04a0f1","#6a4ac2","#ff9932","#0069ff","#f04a4a"],
    background : ["#d5f1f3","#dbf3ff","#e8dfff","#fbe1c7","#a0c6ff","#ffe3e3"]
}
var defaultArea = [];
var defaultLanguages = [];

const MyProfileComponent = ({ }) => {
    let { user, dispatch } = useContext(AuthContext);
    const [dataToggle, setDataToggle] = useState('Complete Profile');
    const history = useHistory(); 
    const [fileName, setFileName] = useState('');
    const [uname, setUName] = useState(null);
    const [designation, setDesignation] = useState(null);
    const [qualification, setQualification] = useState(null);
    const [SearchText, setSearchText] = useState("");
    const [userData, setUserData] = useState({});
    const [userList, setUserList] = useState([]);
    const [userQueries, setUserQueries] = useState([]);
    const [savedQueries, setSavedQueries] = useState([]);
    const [sArticles, setSArticles] = useState([]);
    const [savedPosts, setSavedPosts] = useState([]);
    const [saved, setSaved] = useState([]);
    const [favoriteExpert, setFavoriteExpert] = useState([]);
    const [open, setOpen] = useState(false);
    const [openList, setOpenList] = useState(false);
    const [openInfo, setOpenInfo] = useState(false);
    const [modalTitle, setModalTitle] = useState('');
    const [selectedOptions, setSelectedOptions] = useState([]);
    const [selectedLanguages, setSelectedLanguages] = useState([]);
    const [experienceYears, setExperienceYears] = useState(0);
    const [experienceCompany, setExperienceCompany] = useState(null);
    const [location, setLocation] = useState(null);
    const [descToggle, setDescToggle] = useState(false);
    const [experienceToggle, setExperienceToggle] = useState(false);
    const [editvalue, setEditvalue] = useState(null);
    var dv = [];
    let {id} = useParams();

    if (!user) {
        user = {
            userId: 123,
            username: "Guest",
            userType: "Guest"
        }
    }

    const getUserDetails = async () => {
       var res = await axios.get(`${process.env.REACT_APP_BACKEND_URL}/api/users/`+ id + '/oneUser');
        setUserData(res.data);
    }

    const getUserQueries = async () => {
        var res = await axios.get(`${process.env.REACT_APP_BACKEND_URL}/api/question/`+ id + '/getUserQueries');
        var userQueryData = await axios.get(`${process.env.REACT_APP_BACKEND_URL}/api/users/users`);

        for (var i = 0; i < res.data.length; i++) {
            for (var j = 0; j < userQueryData.data.length; j++) {
            if(userQueryData.data[j]._id==res.data[i].userId ){
                if(res.data[i].username == 'Anonymous'){
                res.data[i].profilePicture=res.data[i].userImage;
                break;
                }else{
                res.data[i].profilePicture=userQueryData.data[j].profilePicture;
                break;
                }
            }
            }
        }
         setUserQueries(res.data);
    }
    

    const getSavedData = async () => {
        try{
            var res = await axios.get(`${process.env.REACT_APP_BACKEND_URL}/api/users/`+ id + '/getSavedData');
            var userQueryData = await axios.get(`${process.env.REACT_APP_BACKEND_URL}/api/users/users`);
            for (var i = 0; i < res.data.feed.length; i++) {
                for (var j = 0; j < userQueryData.data.length; j++) {
                    if(userQueryData.data[j]._id==res.data.feed[i].userId ){
                        if(res.data.feed[i].username == 'Anonymous'){
                        res.data.feed[i].profilePicture=res.data.feed[i].userImage;
                        break;
                        }else{
                        res.data.feed[i].profilePicture=userQueryData.data[j].profilePicture;
                        break;
                        }
                    }
                }
            }
            var sort = await res.data.feed.sort((p1, p2) => {
                return new Date(p2.createdAt) - new Date(p1.createdAt);
            });
            setSaved(sort);
            setFavoriteExpert(res.data.experts);
        }catch(err){
            console.log("Error in getting saved data",err);
        }
    }

    

    useEffect(() => {
        getUserDetails();
        getUserQueries();        
        getSavedData();
    }, []);

    const fileInputOnChange = (e) => {
        const file = e.target.files[0];
        setFileName(file);

    };

    function keyPressEnter(e){
        console.log(e.keyCode == 13 && e.shiftKey)
        if(e.keyCode == 13 && e.shiftKey)
        {}
        else if(e.key === "Enter")
        {
            userData.desc = editvalue;
            updateData();
            setDescToggle(false);
        }
    }

    const updateData = async() => {
        try{
            await axios.put(`${process.env.REACT_APP_BACKEND_URL}/api/users/`+ id + '/updates', userData);
            dispatch({ type: "UPDATE", payload: userData })
        }catch(err){
            console.log("Error in updating user data ")
        }
    }
    
    async function submitImage() {
        try {
            const data = new FormData();
            const imageFileName = Date.now() + fileName.name;
            var extension = imageFileName.split('.').pop();
            var imageName= user._id+"."+extension;
            data.append("email", user.email);
            data.append("name", imageName);
            data.append("file", fileName);
            const res = await axios.post(`${process.env.REACT_APP_BACKEND_URL}/api/users/updateprofileimage`, data);
            if (res.data.profilePicture) {
                alert("profile Pic changed!");
                user.profilePicture = res.data.profilePicture;
                window.localStorage.setItem("user", JSON.stringify(user))
                setFileName("");
                window.location.reload()
            } else {
                alert(res.data.message)
            }
        } catch (err) {
            alert("err-->", err)
        };
    }

    const clearfileSelection = () => {
        setFileName('');
    };

    const userCheck = () =>{
        return user._id === userData._id;
    }

    const handleClose = () => {
        defaultArea = [];
        setOpen(false);
    };
    
    const handleListClose = () => {
        setOpenList(false);
    };
    const handleInfoClose = () => {
        setOpenInfo(false);
    };
    const handleSelectAreaInfo = (e) => {
        setExperienceYears(e.value)
    }

    const handleSelectArea = (e) => {
        setSelectedOptions(e)
    }

    const handleOpen = () => {
        for(let m=0;m<userData.interests.length;m++){
            for(let j=0;j<options.length;j++){
                if(userData.interests[m] === options[j].label){
                    dv.push(j);
                }
            }
        }
        setDefaultArea();
        setOpen(true);
    }

    const handleListOpen = (title) => {
        setModalTitle(title);
        setOpenList(true);        
    }

    const handleInfoOpen = () => {        
        setOpenInfo(true);        
    }

    //--------- Submit Area of Interest
    const submitAOI = async () => {
        uname === null ? userData.username= userData.username : userData.username = uname;
        designation === null ? userData.designation= userData.designation : userData.designation = designation;
        experienceCompany === null ? userData.company= userData.company : userData.username = experienceCompany;
        location === null ? userData.city= userData.city : userData.city = location;
        experienceYears === 0 ? userData.yearsOfExperience= userData.yearsOfExperience : userData.yearsOfExperience = experienceYears;
        editvalue === null ? userData.desc= userData.desc : userData.desc = editvalue;  
        qualification === null ? userData.qualification= userData.qualification : userData.qualification = qualification;        
        let body =[],lang=[];
        for(var i= 0; i<selectedOptions.length; i++){
            body.push(selectedOptions[i].label);
        }
        for(var j= 0; j<selectedLanguages.length; j++){
            lang.push(selectedLanguages[j].label);
        }
        {console.log("AOI__BODY---->",body)}
        userData.interests = body;
        userData.languages = lang;
        // var res = await axios.put(`${process.env.REACT_APP_BACKEND_URL}/api/users/`+user._id + `/updateAOI`, body);
        updateData();
        dispatch({type : "INTEREST", payload : body});
        handleClose();
        
    }

    //--------- Submit Basic Information
    const submitBasicInfo = async () => {
        let basicInfo = {
            city : location  === null ? userData.city : location,
            yearsOfExperience : experienceYears === 0 ? userData.yearsOfExperience : experienceYears,
            company : experienceCompany === null ? userData.company : experienceCompany
        }
        var res = await axios.put(`${process.env.REACT_APP_BACKEND_URL}/api/users/` + user._id + "/updateBasicInfo", basicInfo);
        getUserDetails();
        handleInfoClose();
        console.log("Basic Info updated : ", res.data);
    }

    //--------- Edit or Follow Icon
    const editAndFollowIcon = () =>{
        if(user._id === userData._id){
            return (
                <>
                <Button className="primary rounded-pill" onClick={handleOpen}>
                    <svg version="1.1" id="Layer_1" className="cursor" width="12px" xmlns="http://www.w3.org/2000/svg" xmlnsXlink="http://www.w3.org/1999/xlink" x="0px" y="0px"
                        viewBox="0 0 120 120" enableBackground="new 0 0 120 120" xmlSpace="preserve">
                        <path id="Icon_material-edit" fill="#FFFFFF" d="M5.1,92.7V116H28l67.4-68.8L72.5,23.8L5.1,92.7z M113.1,29.1c2.4-2.4,2.4-6.3,0-8.8
                            L98.8,5.8c-2.3-2.4-6.1-2.4-8.5-0.1c0,0-0.1,0.1-0.1,0.1L79.1,17.2L102,40.5L113.1,29.1L113.1,29.1z"/>
                    </svg>
                    <span style={{"fontSize" : "0.7rem"}}>Edit Profile</span>
                </Button>
                </>
            )
        }else {
            if(userData.followers.includes(user._id)){
                return(
                    <button onClick={()=>{followHandler("unfollow")}} className="btn btn__secondary btn__outlined rounded-pill mr-30">
                        Unfollow
                    </button> 
                )
            }
            else {
                return(
                    <button onClick={()=>{followHandler("follow")}} className="btn btn__primary btn__outlined rounded-pill mr-30">Follow</button> 
                )
            }
            
        }
    }

    //-------- Follow and unfollow Handler
    const followHandler = async (type) => {
        // setFollowToggle(!followToggle);
        var followRes;
        if(type === "follow"){
            console.log("Follow---->")
            followRes = await axios.put(`${process.env.REACT_APP_BACKEND_URL}/api/users/`+user._id + `/follow`, {"userId" : userData._id});
            dispatch({ type: "FOLLOW", payload: userData._id })
        }
        else {
            console.log("Unfollow---->")
            dispatch({ type: "UNFOLLOW", payload: userData._id });        
            followRes = await axios.put(`${process.env.REACT_APP_BACKEND_URL}/api/users/`+user._id + `/unfollow`, {"userId" : userData._id});
        }
        
    }

    //-------- User List display Handler
    const userListShow = async (list,title) => {
        console.log("--------------------------------lists-->>",list)
        if(list.length !== 0){
            handleListOpen(title);
            var listRes = await axios.post(`${process.env.REACT_APP_BACKEND_URL}/api/users/getUserList`, {list : list});
            setUserList(listRes.data);
        }
    }

    //-------- Go to profile view
    function ViewProfileModule(id){
        history.push('/myprofile/' + id);
        window.location.reload();
    }

    function setDefaultArea (){
        
        for(var i=0;i<userData.interests.length;i++){
            for(var j=0;j<options.length;j++){
                if(userData.interests[i]===options[j].label){
                    defaultArea.push(options[j]);
                    break;
                }
            }            
        }
        for(var k=0;k<userData.languages.length;k++){
            for(var l=0;l<languagesOptions.length;l++){
                if(userData.languages[i]===languagesOptions[j]){
                    defaultLanguages.push(languagesOptions[j]);
                    break;
                }
            }            
        }
    }
    function myProfileCard() {
        var years =[],op=[],lk=[],dl=[];
        for(let y=0;y<50;y++){
            years.push(
                {
                    value : y,
                    label : y
                }
            )
        }
        for(let a=0;a<areaOfInterest.length;a++){
            op.push(
                {
                    value : areaOfInterest[a],
                    label : areaOfInterest[a]
                }
            )
        }
        for(let l=0;l<languagesOptions.length;l++){
            lk.push(
                {
                    value : languagesOptions[l],
                    label : languagesOptions[l]
                }
            )
        }
        for(let k=0;k<defaultLanguages.length;k++){
            dl.push(
                {
                    value : defaultLanguages[k],
                    label : defaultLanguages[k]
                }
            )
        }
        return (<>
            {userCheck() ? <span className="fontHeader p-3"> My Profile <span>{'| ' +dataToggle}</span></span> : <span className="forum_title">{userData.username}'s Profile</span>}
            {Object.keys(userData).length > 0 ?
            <div className="myProfileCard">
                <div className="row " style={{"display" : "flex", "flexWrap" : "wrap", "alignContent": "center","alignItems": "center"}}>
                    <div className="col-md-3 ">
                        <div>
                            <div className="">
                                {userData.profilePicture ? <img className="imageProfile" src={process.env.REACT_APP_BACKEND_URL + userData.profilePicture} alt="chart images"></img> : <img className="imageProfile" src={process.env.PUBLIC_URL + "/images/profile/avatar.jpg"} alt="chart images"></img>}
                            </div>
                            {userData._id === user._id ? 
                            <div className="" style={{"display":"flex","flexWrap":"wrap","flexDirection" :"column-reverse", "alignContent": "flex-end","position" : "absolute","left":"120px","top":"110px"}}>
                                <label for="file-input">                                        
                                    <svg version="1.1" id="Layer_1" width="35px" xmlns="http://www.w3.org/2000/svg" xmlnsXlink="http://www.w3.org/1999/xlink" x="0px" y="0px"
                                        viewBox="0 0 120 120" enable-background="new 0 0 120 120" xmlSpace="preserve">
                                    <g>
                                        <circle id="Ellipse_8" fill="#464443" cx="60" cy="60" r="56"/>
                                        <path id="Icon_awesome-camera" fill="#FFFFFF" d="M87.2,47.8v29.8c0,2.8-2.2,5-5,5l0,0H39.1c-2.8,0-5-2.2-5-5l0,0V47.8
                                            c0-2.8,2.2-5,5-5h9.1l1.3-3.4c0.7-1.9,2.6-3.2,4.7-3.2h13c2.1,0,3.9,1.3,4.7,3.2l1.3,3.4h9.1C84.9,42.9,87.2,45.1,87.2,47.8z
                                            M73.1,62.8c0-6.8-5.6-12.4-12.4-12.4s-12.4,5.6-12.4,12.4s5.6,12.4,12.4,12.4l0,0C67.5,75.1,73.1,69.6,73.1,62.8z M69.8,62.8
                                            c0,5-4.1,9.1-9.1,9.1c-5,0-9.1-4.1-9.1-9.1s4.1-9.1,9.1-9.1h0C65.7,53.7,69.8,57.7,69.8,62.8z"/>
                                    </g>
                                    </svg>
                                </label>
                                <input id="file-input" onChange={fileInputOnChange} type="file" style={{"display": "none"}} />                                
                            </div>:<></>}
                            {fileName && (<>
                                    <div className="editProfileImage"><CloseIcon  style={{cursor:"pointer"}} onClick={clearfileSelection} /> <DoneIcon  style={{cursor:"pointer"}} onClick={submitImage} />
                                     </div>                            
                                </>
                                )}
                        </div>
                    </div>
                    <div className="col-md-9 " style={{ padding: "44px 0px" }}>
                        <div className="row no-gutters">
                            <div className="col-md-5" >
                                <span className="col-12" style={{"fontWeight" : "bold", "fontSize" : "1.2rem","color": "#3C4453","fontFamily":"RobotoRegular"}}>{userData.username}</span>
                                <span className="col-12" style={{ "fontSize" : "0.9rem", "display" : "block","color":"#7789AC","fontFamily":"RobotoRegular"}}>{userData.designation ? userData.designation : <></>}</span>
                            </div>
                            <div className="col-md-6 ">
                                {dataToggle !== "Complete Profile" ?                                    
                                    <div className="cursor" style={{"float" : "right", "display":"flex","color":"#6A7791","fontFamily":"RobotoRegular"}} onClick={()=>{setDataToggle("Complete Profile")}}>
                                    <svg version="1.1" width="15px" id="Layer_1" xmlns="http://www.w3.org/2000/svg" xmlnsXlink="http://www.w3.org/1999/xlink" x="0px" y="0px"
                                            viewBox="0 0 120 120" enable-background="new 0 0 120 120" xmlSpace="preserve">
                                    <path id="Path_589" fill="none" stroke="#7789AC" stroke-width="21.5301" stroke-linecap="round" stroke-linejoin="round" d="
                                        M82.8,14.4L37.2,60l45.6,45.6"/>
                                    </svg>
                                    <span>Back to profile</span>
                                    </div> :
                                    <></> }                                
                            </div>
                        </div>
                        <div className="row no-gutters" style={{"display" : "flex"}}>
                            <div className="col-md-3 cursor followStyle" onClick={()=>{userListShow(userData.followers,"Followers")}}>
                                <span className="followProfile col-12" style={{"color" :"#3C4453","fontSize" : "1rem"}}>{userData.followers.length}</span> 
                                <span className="col-12 followProfile" style={{"color":"#7789AC","fontFamily" : "RobotoRegular","fontSize":"0.9rem"}}>followers</span>
                            </div>
                            <div className="col-md-3 no-gutters cursor followStyle" onClick={()=>{userListShow(userData.followings, "Followings")}}>
                                <span className="followProfile col-12" style={{"color" :"#3C4453","fontSize":"1rem"}}> {userData.followings.length}</span>
                                <span className="col-12 followProfile" style={{"color":"#7789AC","fontFamily" : "RobotoRegular","fontSize":"0.9rem"}}>followings</span>
                            </div>
                            <Modal
                                show={openList}
                                onHide={handleListClose}
                                size="md"
                                aria-labelledby="contained-modal-title-vcenter"
                                centered
                            >
                                <Modal.Header >
                                    <Modal.Title>{modalTitle}</Modal.Title>
                                </Modal.Header>
                                <Modal.Body>
                                    { userList.length === 0 ? <></> : userList.map((c) => {
                                        return (
                                            <div className="row m-2" onClick={()=>{ViewProfileModule(c._id)}}>
                                                <div className="col-2 cursor">
                                                    <img src={ process.env.REACT_APP_BACKEND_URL + c.profilePicture} className="userPostDetails"/>
                                                </div>
                                                <div className="col-10 no-gutters">
                                                    
                                                        <div className="col-12 cursor">
                                                            <span style={{"fontSize" : "1.1rem", "fontWeight" : "600"}}>{c.username}</span>
                                                        </div>
                                                        <div className="col-12">
                                                            <span style={{"fontWeight" : "300", "fontSize" : "0.8rem"}}>{c.designation}</span>
                                                        </div>
                                                    
                                                </div>
                                            </div>
                                        )
                                    })                                        
                                    }                                
                                </Modal.Body>
                                <Modal.Footer>                        
                                    <Button variant="secondary" onClick={handleListClose}>
                                        Close
                                    </Button>
                                </Modal.Footer>
                            </Modal>
                            <div className="col-md-5" style={{"display" : "flex", "justifyContent" : "flex-end", "alignItems" : "center"}}>

                                <div class="image-upload">
                                    {editAndFollowIcon()}                                    
                                </div>
                                
                            </div>
                        </div>
                    </div>
                </div>
                {dataToggle === "Complete Profile" ? 
                <div>
                    <br></br>
                <div className="row">
                    <div className="col-md-10">
                        <span style={{"fontWeight" : "lighter", "fontSize": "1.1rem","color":"#7789AC","fontFamily":"RobotoRegular"}}>About</span>
                    </div>                    
                </div>
                <div className="row">
                    <div className="col-md-12">
                        <span className="detailInfoProfile">{userData.desc}</span>                       
                    </div>
                </div>
                <br></br>
                <br></br>
                {userCheck ? <span style={{"fontWeight" : "lighter", "fontSize": "1.1rem","color":"#7789AC","fontFamily":"RobotoRegular"}}> Basic Information</span> : <span style={{"fontWeight" : "lighter", "fontSize": "1.1rem","color":"#7789AC","fontFamily":"RobotoRegular"}}>{userData.username}'s Basic Information</span>}
                <div className="mt-2">
                    
                    <div className="" style={{"alignItems" : "center"}}>
                        <div className="my-3">
                            <div className="row" style={{"display" : "flex","alignItems" : "center","flexWrap" : "wrap"}}>
                                <div className="col-1">
                                    <svg version="1.1" width="35px" id="Layer_1" xmlns="http://www.w3.org/2000/svg" xmlnsXlink="http://www.w3.org/1999/xlink" x="0px" y="0px"
                                        viewBox="0 0 120 120" enable-background="new 0 0 120 120" xmlSpace="preserve">
                                    <path fill="#DBFCF9" d="M96.1,2.5H23.9C12,2.5,2.3,11.8,2.3,23.4v73.2c0,11.6,9.7,20.9,21.6,20.9h72.1c11.9,0,21.6-9.4,21.6-20.9
                                        V23.4C117.7,11.8,108,2.5,96.1,2.5z"/>
                                    <g>
                                        <path fill="#07BEB8" d="M87.6,65.4l-5.2-8c-0.3-0.5-0.4-1-0.5-1.6C81,46,73.3,38.2,63.5,37.2c0.2,2.1-0.6,4.1-2.2,5.5l-3.5,2.9
                                            l1.1,4.4c0.5,1.9,0,3.9-1.2,5.5c-1.2,1.5-3.1,2.4-5,2.5c-1.2,0-2.3-0.3-3.3-0.9l-3.9-2.4l-3.8,2.4c-0.2,0.1-0.3,0.2-0.5,0.3v0.3
                                            c0.1,6.8,3.1,13.2,8.2,17.6c0.6,0.5,1,1.3,1,2V89c0,0.9,0.7,1.7,1.6,1.8l17.7,1.5c1,0.1,1.9-0.6,2-1.6c0,0,0-0.1,0-0.1v-8.3
                                            c0-0.5,0.4-0.9,1-1h6.1c1.9,0,3.4-1.5,3.4-3.4v-8.3c0-0.4,0.3-0.7,0.7-0.7h3c1.2,0,2.2-1,2.3-2.2C88,66.2,87.9,65.8,87.6,65.4z"/>
                                        <path fill="#07BEB8" d="M46.6,50.1l5.2,3.1c0.9,0.6,2.1,0.3,2.6-0.6c0.3-0.4,0.3-0.9,0.2-1.4l-1.4-5.9c-0.1-0.7,0.1-1.4,0.6-1.9
                                            l4.6-4c0.8-0.7,0.9-1.9,0.2-2.7c-0.3-0.4-0.8-0.6-1.3-0.7l-6.1-0.5c-0.7-0.1-1.3-0.5-1.6-1.2l-2.3-5.6c-0.4-1-1.5-1.4-2.5-1
                                            c-0.5,0.2-0.8,0.6-1,1l-2.3,5.6c-0.3,0.7-0.9,1.1-1.6,1.2l-6.1,0.5c-1,0-1.8,0.9-1.8,1.9c0,0.5,0.3,1,0.7,1.3l4.6,4
                                            c0.5,0.5,0.8,1.2,0.6,1.9l-1.4,5.9c-0.2,1,0.4,2,1.4,2.3c0.5,0.1,1,0,1.4-0.2l5.2-3.1C45.2,49.7,45.9,49.7,46.6,50.1z"/>
                                    </g>
                                    </svg>
                                </div>
                                <div className="col-8">
                                    <div className="col-12">
                                        {/* {userData.company ? <span>{userData.company}</span> : experienceCompany === null ? <span className="basicInfoDefault">Company's name.</span> : <span>{experienceCompany}</span>} */}
                                        <span style={{"color":"#7789AC","fontFamily" : "RobotoRegular","fontSize":"0.9rem"}}>Experience</span>
                                    </div>                            
                                    <div className="col-12">
                                        {userData.yearsOfExperience ? 
                                        userData.yearsOfExperience === 1 ? 
                                            <span className="detailInfoProfile">{userData.yearsOfExperience + " "} Year</span> : 
                                            <span className="detailInfoProfile">{userData.yearsOfExperience + " "} Years</span> : 
                                        <span>{experienceYears === 0 ? 
                                            <span className="basicInfoDefault">Years of experience.</span> : 
                                            <span className="detailInfoProfile">{experienceYears + " "} Years</span>}
                                        </span>}
                                    </div>
                                    
                                </div>
                            </div>                        
                        </div>
                        {userData.qualification ? <div className="my-3" >
                            <div className="row" style={{"display" : "flex","alignItems" : "center","flexWrap" : "wrap"}}>
                                <div className="col-1">
                                    <svg version="1.1" width="35px" id="Layer_1" xmlns="http://www.w3.org/2000/svg" xmlnsXlink="http://www.w3.org/1999/xlink" x="0px" y="0px"
                                        viewBox="0 0 120 120" enable-background="new 0 0 120 120" xmlSpace="preserve">
                                    <path opacity="0.12" fill="#07BEB8" d="M95.6,1.2H24.4C12.6,1.2,3,10.8,3,22.6v74.8c0,11.8,9.6,21.4,21.4,21.4h71.2
                                        c11.8,0,21.4-9.6,21.4-21.4V22.6C117,10.8,107.4,1.2,95.6,1.2z"/>
                                    <g id="Group_2365" transform="translate(-4596.732 -2305.656)">
                                        <path id="Path_682" fill="#07BEB8" d="M4655,2367c-0.4,0-0.8-0.1-1.2-0.2l-16.2-5.6v17c0,0.5,0.3,0.9,0.7,1.1
                                            c5.2,2.5,10.9,3.7,16.7,3.7c5.8,0,11.5-1.3,16.7-3.8c0.4-0.2,0.7-0.6,0.7-1.1v-17l-16.2,5.6C4655.8,2366.9,4655.4,2367,4655,2367
                                            L4655,2367z"/>
                                        <path id="Path_683" fill="#07BEB8" d="M4676.1,2383.4v16.5c0,1,0.8,1.8,1.9,1.9h3.7c1,0,1.8-0.8,1.9-1.9v-16.5
                                            C4681.3,2384.8,4678.4,2384.8,4676.1,2383.4L4676.1,2383.4z"/>
                                        <path id="Path_684" fill="#07BEB8" d="M4681.1,2372.1v-16.5l2.8-1c0.6-0.2,1-0.8,0.8-1.4c-0.1-0.4-0.4-0.7-0.8-0.8l-28.6-9.9
                                            c-0.3-0.1-0.6-0.1-0.9,0l-28.6,9.9c-0.4,0-0.7,0.5-0.7,1c0,0.5,0.4,1,0.9,1.1l28.6,10c0.1,0,0.2,0.1,0.4,0.1c0.1,0,0.3,0,0.4-0.1
                                            l23.3-8.1v15.8c-2.7,0.7-4.3,3.4-3.6,6.1c0.7,2.7,3.4,4.3,6.1,3.6c2.2-0.6,3.7-2.5,3.8-4.8
                                            C4684.8,2374.7,4683.2,2372.7,4681.1,2372.1L4681.1,2372.1z"/>
                                    </g>
                                    </svg>
                                </div>
                                <div className="col-8">                            
                                    <div className="col-12">
                                        {/* {userData.company ? <span>{userData.company}</span> : experienceCompany === null ? <span className="basicInfoDefault">Company's name.</span> : <span>{experienceCompany}</span>} */}
                                        <span style={{"color":"#7789AC","fontFamily" : "RobotoRegular","fontSize":"0.9rem"}}>Educational Qualifications</span>
                                    </div>                            
                                    <div className="col-12">
                                        {userData.qualification ? <span className="detailInfoProfile">{userData.qualification}</span> : qualification === null ? <span className="basicInfoDefault">Educational Qualification.</span> : <span className="detailInfoProfile">{qualification}</span>}                            
                                    </div>
                                </div>
                            </div>                        
                        </div>:<></>}
                        <div className="my-3" >
                            <div className="row" style={{"display" : "flex","alignItems" : "center","flexWrap" : "wrap"}}>
                                <div className="col-1">
                                    <svg version="1.1" width="35px" id="Layer_1" xmlns="http://www.w3.org/2000/svg" xmlnsXlink="http://www.w3.org/1999/xlink" x="0px" y="0px"
                                        viewBox="0 0 120 120" enable-background="new 0 0 120 120" xmlSpace="preserve">
                                    <path fill="#DBFCF9" d="M96.1,2.5H23.9C12,2.5,2.3,11.8,2.3,23.4v73.2c0,11.6,9.7,20.9,21.6,20.9h72.1c11.9,0,21.6-9.4,21.6-20.9
                                        V23.4C117.7,11.8,108,2.5,96.1,2.5z"/>
                                    <path id="Icon_material-location-on" fill="#07BEB8" d="M60,29c-12,0-21.7,9.7-21.7,21.7c0,0,0,0,0,0C38.3,67,60,91,60,91
                                        s21.7-24,21.7-40.4C81.7,38.7,72,29,60,29C60,29,60,29,60,29z M60,58.4c-4.3,0-7.8-3.5-7.8-7.8c0-4.3,3.5-7.8,7.8-7.8
                                        s7.8,3.5,7.8,7.8C67.8,55,64.3,58.4,60,58.4z"/>
                                    </svg>
                                </div>
                                <div className="col-8">                            
                                    <div className="col-12">
                                        {/* {userData.company ? <span>{userData.company}</span> : experienceCompany === null ? <span className="basicInfoDefault">Company's name.</span> : <span>{experienceCompany}</span>} */}
                                        <span style={{"color":"#7789AC","fontFamily" : "RobotoRegular","fontSize":"0.9rem"}}>Location</span>
                                    </div>                            
                                    <div className="col-12">
                                        {userData.city ? <span className="detailInfoProfile">{userData.city}</span> : location === null ? <span className="basicInfoDefault">Location Details.</span> : <span className="detailInfoProfile">{location}</span>}                            
                                    </div>
                                </div>
                            </div>                        
                        </div>
                        
                    </div>                    
                    <br></br>
                    {/* <div className="row" style={{"alignItems" : "center"}}>
                        
                    </div> */}
                </div>
                <br></br>
                
                {userData.languages.length === 0 ? <></>: 
                <div>
                    <span style={{"fontWeight" : "lighter", "fontSize": "1.1rem","color":"#7789AC","fontFamily":"RobotoRegular","display":"block"}}>Language Proficiency</span>                    
                    <div className="my-2">
                    {userData.languages.map((l,idx)=>{
                        return (
                            <>
                            <span className="my-1" style={{"fontFamily":"RobotoRegular"}}>{l}</span>{idx !== userData.languages.length -1 ? <span>, </span> : <></>}
                            </>
                        )
                    })}  
                    </div>                  
                </div>}
                <br></br>
                <div className="row">
                    <div className="col-md-12">
                        <span style={{"fontWeight" : "lighter", "fontSize": "1.1rem","color":"#7789AC","fontFamily":"RobotoRegular"}}>Area Of Sepcialization</span>
                    </div>                    
                    <Modal
                        show={open}
                        onHide={handleClose}
                        size="md"
                        aria-labelledby="contained-modal-title-vcenter"
                        centered
                    >                            
                        <Modal.Body> 
                            <div>
                                <span>Username :</span>
                                <textarea
                                    className="form-control"
                                    id="new_title"
                                    rows="1"
                                    placeholder="Your name."
                                    value={ uname===null ? userData.username: uname}
                                    onKeyDown={(e)=>keyPressEnter(e)}
                                    onChange={(e) => { setUName(e.target.value);}}                                        
                                    >
                                </textarea>
                            </div>
                            <div>
                                <span>Designation :</span>
                                <textarea
                                    className="form-control"
                                    id="new_title"
                                    rows="1"
                                    placeholder="Your designation."
                                    value={designation === null? userData.desgnation: designation}
                                    onKeyDown={(e)=>keyPressEnter(e)}
                                    onChange={(e) => { setDesignation(e.target.value);}}                                        
                                    >
                                </textarea>
                            </div>
                            <div>
                                <span>About me :</span>
                                <textarea
                                    className="form-control"
                                    id="new_title"
                                    rows="3"
                                    placeholder="Tell others about yourself."
                                    value={ editvalue===null ? userData.desc: editvalue}
                                    onKeyDown={(e)=>keyPressEnter(e)}
                                    onChange={(e) => { setEditvalue(e.target.value);}}                                        
                                    >
                                </textarea>
                            </div>
                            <div>
                                <span>Educational Qualifications :</span>
                                <textarea
                                    className="form-control"
                                    id="new_title"
                                    rows="1"
                                    placeholder="Enter your qualification."
                                    value={qualification === null ? userData.qualification : qualification}
                                    onChange={(e) => { setQualification(e.target.value) }}>
                                </textarea>
                            </div>
                            <div>
                                <span>Location :</span>
                                <textarea
                                    className="form-control"
                                    id="new_title"
                                    rows="1"
                                    placeholder="Enter your location here."
                                    value={location === null ? userData.city : location}
                                    onChange={(e) => { setLocation(e.target.value) }}>
                                </textarea>
                            </div>
                            <div className="row">
                                <div className="col-6">
                                    <span>Years Of Experience :</span>                                                      
                                    <Select options={years} onChange={(e) => handleSelectAreaInfo(e)} style={{"zIndex" : "2", "borderBottom" : "1px solid black"}} menuPlacement="auto"></Select>
                                </div>
                                <div className="col-6">
                                    <span>Languages Known :</span>                                                              
                                    <Select options={lk} onChange={(e)=>setSelectedLanguages(e)} defaultValue={dl} isMulti style={{ "borderBottom" : "1px solid black"}} closeMenuOnSelect={false}></Select>
                                </div> 
                            </div>
                            <div>
                                <span>Area of Specialization :</span>                                                              
                                <Select options={op} onChange={handleSelectArea} defaultValue={defaultArea} closeMenuOnSelect={false} isMulti style={{"zIndex" : "-1", "borderBottom" : "1px solid black"}}></Select>
                            </div>
                                                            
                        </Modal.Body>
                        <Modal.Footer>                        
                            <Button variant="secondary" onClick={handleClose}>
                                Close
                            </Button>
                            <Button variant="primary" onClick={submitAOI}>
                                Submit
                            </Button>
                        </Modal.Footer>
                    </Modal>
                </div>
                <div className="row">
                    <div className="aoi_list">  
                        {/* {userData.interests.length === 0 ? <></> : userData.interests.map((interest,idx) => {
                            return (
                                <div key={idx} className="" style={{"display": "flex","alignItems" : "center"}}>
                                    <div className=" iconCard"></div>
                                    <span className="mx-2" style={{"color" : colorVariants.textColor[colorIndex], "fontSize" : "0.8rem"}}>{interest}</span>
                                </div>
                            )
                        })}                   */}
                        {userData.interests.length === 0 ? <></> : userData.interests.map((interest, index) => {
                            if(index < colorVariants.textColor.length){
                                colorIndex = index;
                            }
                            else{
                                // colorIndex--;
                                colorIndex < 0 ? colorIndex++ : colorIndex--;
                            }
                            return (
                                <div key={index} className="my-2" style={{"display": "flex","alignItems" : "center"}}>
                                    <div className=" iconCard"></div>
                                    <span className="mx-2" style={{"color" : colorVariants.textColor[colorIndex], "fontSize" : "0.87rem"}}>{interest}</span>
                                </div>
                            );
                        })}
                    </div>                    
                </div>
                <br></br>                
                </div> : <></>}                
            </div>: <></>}
        </>);
    }

    function savedCard() {
        return (<>
            {/* <span className="fontHeader p-3">My Saved List</span> */}
            <div className="mySavedQueryCard">
                <div className="row mx-2">
                    <div className="col-md-4 item_card p-3 cursor" onClick={()=>{setDataToggle("My Queries")}}>
                        <div className="row" style={{"justifyContent": "space-around", "alignItems" : "center"}}>
                            <div className="row" style={{"display" : "flex", "alignItems" : "center"}}>
                                <div className="col-3 ">
                                <svg version="1.1" width="35px" id="Layer_1" xmlns="http://www.w3.org/2000/svg" xmlnsXlink="http://www.w3.org/1999/xlink" x="0px" y="0px"
                                    viewBox="0 0 120 120" enable-background="new 0 0 120 120" xmlSpace="preserve">
                                <path fill="#FEB770" d="M101.5,2.5H18.5c-8.7,0-15.7,7-15.7,15.7v83.7c0,8.7,7,15.7,15.7,15.7h83.1c8.7,0,15.7-7,15.7-15.7V18.2
                                    C117.2,9.5,110.2,2.5,101.5,2.5z"/>
                                <path id="Path_614" fill="#FFFFFF" d="M78.4,35.3H41.5c-3.9,0-7.1,3.1-7.1,7.1v25.2c0,3.9,3.2,7.1,7.1,7.1c0,0,0,0,0,0H53l4.2,8.4
                                    c0.8,1.5,2.7,2.1,4.2,1.3c0.6-0.3,1.1-0.8,1.4-1.4l4.2-8.4h11.5c3.9,0,7.1-3.2,7.1-7.1c0,0,0,0,0,0V42.3
                                    C85.5,38.4,82.3,35.3,78.4,35.3z M49.9,66.5c-1.3,0-2.3-1-2.3-2.3c0-1.3,1-2.3,2.3-2.3c1.3,0,2.3,1,2.3,2.3
                                    C52.2,65.5,51.1,66.5,49.9,66.5z M55.6,53.9c-0.7,1-1.6,1.8-2.6,2.4c-0.8,0.4-1.3,1.3-1.3,2.2c-0.1,0.5-0.5,0.9-1,0.9H49
                                    c-0.3,0-0.6-0.1-0.8-0.3c-0.2-0.2-0.3-0.5-0.3-0.8c0-2.1,1.1-4,2.9-5.1c0.7-0.4,1.2-1,1.7-1.6c0.6-0.8,0.6-2,0.2-2.9
                                    c-0.6-1.2-1.9-1.8-3.2-1.7c-1.8-0.2-3.5,1.1-3.7,3c-0.1,0.5-0.5,0.8-1,0.8h-1.8c-0.3,0-0.6-0.1-0.8-0.3c-0.2-0.2-0.3-0.5-0.2-0.8
                                    c0.4-3.8,3.6-6.6,7.4-6.4c2.7-0.1,5.3,1.4,6.5,3.8C57.3,49.3,57.1,51.9,55.6,53.9L55.6,53.9z M75.1,66.1H63.8c-1,0-1.8-0.8-1.8-1.8
                                    c0-1,0.8-1.8,1.8-1.8h11.4c1,0,1.8,0.8,1.8,1.8c0,0,0,0,0,0C77,65.3,76.1,66.1,75.1,66.1L75.1,66.1z M75.1,56.8H63.8
                                    c-1,0-1.8-0.8-1.8-1.8c0-1,0.8-1.8,1.8-1.8h11.4c1,0,1.8,0.8,1.8,1.8c0,0,0,0,0,0C77,55.9,76.1,56.8,75.1,56.8L75.1,56.8z
                                    M75.1,47.4H63.8c-1,0-1.8-0.8-1.8-1.8s0.8-1.8,1.8-1.8h11.4c1,0,1.8,0.8,1.8,1.8c0,0,0,0,0,0C77,46.6,76.1,47.5,75.1,47.4
                                    L75.1,47.4z"/>
                                </svg>
                                </div>
                                <div className="col-8">
                                    {userCheck() ? <span style={{"fontSize" : "0.8rem","fontFamily":"RobotoRegular"}}>My Queries</span> : <span style={{"fontSize" : "0.8rem","fontFamily":"RobotoRegular"}}>{userData.username}'s Queries</span> }                    
                                    {userQueries.length === 0 ? <span style={{"display" : "block", "fontSize" : "1rem","color" : "#3C4453"}}>No Queries</span> : <> { userQueries.length === 1 ? <span style={{"display" : "block", "fontSize" : "1rem","color" : "#3C4453"}}> {userQueries.length + " "} Query</span> : <span style={{"display" : "block", "fontSize" : "1rem","color" : "#3C4453"}}>{userQueries.length + " "} Queries</span>}</>}
                                </div>
                                <div className="col-1">
                                <div className="rightArrow">
                                    <svg version="1.1" width="25px" id="Layer_1" xmlns="http://www.w3.org/2000/svg" xmlnsXlink="http://www.w3.org/1999/xlink" x="0px" y="0px"
                                        viewBox="0 0 120 120" enableBackground="new 0 0 120 120" xmlSpace="preserve">
                                        <g id="Group_2232" transform="translate(-298.325 -210.325)">
                                            <g id="Ellipse_284" transform="translate(298.325 210.325)">
                                                <circle fill="#FFFFFF" cx="60" cy="60" r="56.4"/>
                                                <path fill="#DBDBDB" d="M60,116.4C28.9,116.4,3.6,91.1,3.6,60C3.6,28.9,28.9,3.6,60,3.6c31.1,0,56.4,25.3,56.4,56.4
                                                    C116.4,91.1,91.1,116.4,60,116.4z M60,12.1c-26.4,0-47.9,21.5-47.9,47.9c0,26.4,21.5,47.9,47.9,47.9c26.4,0,47.9-21.5,47.9-47.9
                                                    C107.9,33.6,86.4,12.1,60,12.1z"/>
                                            </g>
                                            <path fill="#DBDBDB" d="M347.2,297.4c-1.2,0-2.5-0.5-3.4-1.4c-1.9-1.9-1.9-4.9,0-6.8l18.9-18.9l-18.9-18.9c-1.9-1.9-1.9-4.9,0-6.8
                                                c1.9-1.9,4.9-1.9,6.8,0l22.2,22.2c1.9,1.9,1.9,4.9,0,6.8L350.6,296C349.7,296.9,348.4,297.4,347.2,297.4z"/>
                                        </g>
                                    </svg>
                                </div>
                                </div>
                            </div>
                            {/* <div className="col-2">                               
                                <div className="rightArrow">
                                    <svg version="1.1" width="25px" id="Layer_1" xmlns="http://www.w3.org/2000/svg" xmlnsXlink="http://www.w3.org/1999/xlink" x="0px" y="0px"
                                        viewBox="0 0 120 120" enableBackground="new 0 0 120 120" xmlSpace="preserve">
                                        <g id="Group_2232" transform="translate(-298.325 -210.325)">
                                            <g id="Ellipse_284" transform="translate(298.325 210.325)">
                                                <circle fill="#FFFFFF" cx="60" cy="60" r="56.4"/>
                                                <path fill="#DBDBDB" d="M60,116.4C28.9,116.4,3.6,91.1,3.6,60C3.6,28.9,28.9,3.6,60,3.6c31.1,0,56.4,25.3,56.4,56.4
                                                    C116.4,91.1,91.1,116.4,60,116.4z M60,12.1c-26.4,0-47.9,21.5-47.9,47.9c0,26.4,21.5,47.9,47.9,47.9c26.4,0,47.9-21.5,47.9-47.9
                                                    C107.9,33.6,86.4,12.1,60,12.1z"/>
                                            </g>
                                            <path fill="#DBDBDB" d="M347.2,297.4c-1.2,0-2.5-0.5-3.4-1.4c-1.9-1.9-1.9-4.9,0-6.8l18.9-18.9l-18.9-18.9c-1.9-1.9-1.9-4.9,0-6.8
                                                c1.9-1.9,4.9-1.9,6.8,0l22.2,22.2c1.9,1.9,1.9,4.9,0,6.8L350.6,296C349.7,296.9,348.4,297.4,347.2,297.4z"/>
                                        </g>
                                    </svg>
                                </div> 
                            </div> */}
                        </div>
                    </div>
                    <div className="col-md-4 item_card p-3 cursor" onClick={()=>{setDataToggle("Saved")}}>
                        <div className="row" style={{"justifyContent": "space-around", "alignItems" : "center"}}>
                            <div className="row" style={{"display" : "flex", "alignItems" : "center"}}>
                                <div className="col-3 ">
                                    <svg version="1.1" id="Layer_1" width="35px" xmlns="http://www.w3.org/2000/svg" xmlnsXlink="http://www.w3.org/1999/xlink" x="0px" y="0px"
                                        viewBox="0 0 120 120" enable-background="new 0 0 120 120" xmlSpace="preserve">
                                    <path fill="#6E5FAF" d="M101.5,2.5h-83c-8.7,0-15.7,7-15.7,15.7v83.7c0,8.7,7,15.7,15.7,15.7h83.1c8.7,0,15.7-7,15.7-15.7V18.2
                                        C117.2,9.5,110.2,2.5,101.5,2.5z"/>
                                    <g transform="matrix(1, 0, 0, 1, 0, 0)">
                                        <path id="Path_580-2" fill-rule="evenodd" clip-rule="evenodd" fill="#DFD8FF" d="M58.3,35.9c1.9-0.1,3.5,1.3,3.6,3.2
                                            c0,0,0,0.1,0,0.1v0.5h-3.6v4.2H73c1,0.1,1.7,0.9,1.6,1.8v32.1c0.1,1-0.7,1.8-1.6,1.8c0,0,0,0,0,0H40.5c-1-0.1-1.7-0.9-1.6-1.8V45.8
                                            c-0.1-1,0.7-1.8,1.6-1.8h10.1v8.7c0.2,4.3,3.8,7.6,8,7.4c4-0.2,7.2-3.4,7.4-7.4v-2.3c0-1.1-0.9-2.1-2.1-2.1s-2.1,0.9-2.1,2.1v2.3
                                            c-0.1,2-1.9,3.5-3.9,3.3c-1.8-0.1-3.2-1.5-3.3-3.3V39.2C54.8,37.3,56.3,35.9,58.3,35.9C58.2,35.9,58.3,35.9,58.3,35.9z M58.3,31.8
                                            c-4.2-0.1-7.6,3.2-7.7,7.4v0.5H36.7c-1.2,0.1-2.1,1.1-2,2.3v39.6c-0.1,1.2,0.8,2.2,2,2.3h4.5v2c-0.1,1.2,0.8,2.2,2,2.3h40.2
                                            c1.2-0.1,2.1-1.1,2-2.3V46.3c0.1-1.2-0.8-2.2-2-2.3h-4.5v-2c0.1-1.2-0.8-2.2-2-2.3H66v-0.5C65.9,35,62.5,31.7,58.3,31.8z"/>
                                    </g>
                                    </svg>
                                </div>
                                <div className="col-8">
                                    {userCheck() ? <span style={{"fontSize" : "0.8rem","fontFamily":"RobotoRegular"}}>Saved Items</span> : <span style={{"fontSize" : "0.8rem","fontFamily":"RobotoRegular"}}>{userData.username}'s Queries</span> }                    
                                    {saved.length === 0 ? <span style={{"display" : "block", "fontSize" : "1rem","color" : "#3C4453"}}>No Items</span> : <> { saved.length === 1 ? <span style={{"display" : "block", "fontSize" : "1rem","color" : "#3C4453"}}> {saved.length + " "} Item</span> : <span style={{"display" : "block", "fontSize" : "1rem","color" : "#3C4453"}}>{saved.length + " "} Items</span>}</>}
                                </div>
                                <div className="col-1">
                                <div className="rightArrow">
                                    <svg version="1.1" width="25px" id="Layer_1" xmlns="http://www.w3.org/2000/svg" xmlnsXlink="http://www.w3.org/1999/xlink" x="0px" y="0px"
                                        viewBox="0 0 120 120" enableBackground="new 0 0 120 120" xmlSpace="preserve">
                                        <g id="Group_2232" transform="translate(-298.325 -210.325)">
                                            <g id="Ellipse_284" transform="translate(298.325 210.325)">
                                                <circle fill="#FFFFFF" cx="60" cy="60" r="56.4"/>
                                                <path fill="#DBDBDB" d="M60,116.4C28.9,116.4,3.6,91.1,3.6,60C3.6,28.9,28.9,3.6,60,3.6c31.1,0,56.4,25.3,56.4,56.4
                                                    C116.4,91.1,91.1,116.4,60,116.4z M60,12.1c-26.4,0-47.9,21.5-47.9,47.9c0,26.4,21.5,47.9,47.9,47.9c26.4,0,47.9-21.5,47.9-47.9
                                                    C107.9,33.6,86.4,12.1,60,12.1z"/>
                                            </g>
                                            <path fill="#DBDBDB" d="M347.2,297.4c-1.2,0-2.5-0.5-3.4-1.4c-1.9-1.9-1.9-4.9,0-6.8l18.9-18.9l-18.9-18.9c-1.9-1.9-1.9-4.9,0-6.8
                                                c1.9-1.9,4.9-1.9,6.8,0l22.2,22.2c1.9,1.9,1.9,4.9,0,6.8L350.6,296C349.7,296.9,348.4,297.4,347.2,297.4z"/>
                                        </g>
                                    </svg>
                                </div>
                                </div>
                            </div>
                            {/* <div className="col-2">                               
                                <div className="rightArrow">
                                    <svg version="1.1" width="25px" id="Layer_1" xmlns="http://www.w3.org/2000/svg" xmlnsXlink="http://www.w3.org/1999/xlink" x="0px" y="0px"
                                        viewBox="0 0 120 120" enableBackground="new 0 0 120 120" xmlSpace="preserve">
                                        <g id="Group_2232" transform="translate(-298.325 -210.325)">
                                            <g id="Ellipse_284" transform="translate(298.325 210.325)">
                                                <circle fill="#FFFFFF" cx="60" cy="60" r="56.4"/>
                                                <path fill="#DBDBDB" d="M60,116.4C28.9,116.4,3.6,91.1,3.6,60C3.6,28.9,28.9,3.6,60,3.6c31.1,0,56.4,25.3,56.4,56.4
                                                    C116.4,91.1,91.1,116.4,60,116.4z M60,12.1c-26.4,0-47.9,21.5-47.9,47.9c0,26.4,21.5,47.9,47.9,47.9c26.4,0,47.9-21.5,47.9-47.9
                                                    C107.9,33.6,86.4,12.1,60,12.1z"/>
                                            </g>
                                            <path fill="#DBDBDB" d="M347.2,297.4c-1.2,0-2.5-0.5-3.4-1.4c-1.9-1.9-1.9-4.9,0-6.8l18.9-18.9l-18.9-18.9c-1.9-1.9-1.9-4.9,0-6.8
                                                c1.9-1.9,4.9-1.9,6.8,0l22.2,22.2c1.9,1.9,1.9,4.9,0,6.8L350.6,296C349.7,296.9,348.4,297.4,347.2,297.4z"/>
                                        </g>
                                    </svg>
                                </div> 
                            </div> */}
                        </div>
                    </div>
                    <div className="col-md-4 item_card p-3 cursor" onClick={()=>{setDataToggle("Experts")}}>
                        <div className="row" style={{"justifyContent": "space-around", "alignItems" : "center"}}>
                            <div className="row" style={{"display" : "flex", "alignItems" : "center"}}>
                                <div className="col-3 ">
                                    <svg version="1.1" width="35px" id="Layer_1" xmlns="http://www.w3.org/2000/svg" xmlnsXlink="http://www.w3.org/1999/xlink" x="0px" y="0px"
                                        viewBox="0 0 120 120" enable-background="new 0 0 120 120" xmlSpace="preserve">
                                    <path fill="#FF7898" d="M101.5,2.5h-83c-8.7,0-15.7,7-15.7,15.7v83.7c0,8.7,7,15.7,15.7,15.7h83.1c8.7,0,15.7-7,15.7-15.7V18.2
                                        C117.2,9.5,110.2,2.5,101.5,2.5z"/>
                                    <g transform="matrix(1, 0, 0, 1, 0, 0)">
                                        <path id="Icon_material-favorite-border-2" fill="#FFF9FB" d="M72.8,35.4c-4.9,0-9.6,2.2-12.8,5.9c-3.2-3.7-7.8-5.9-12.8-5.9
                                            c-8.5-0.1-15.5,6.8-15.6,15.3c0,0.1,0,0.2,0,0.3c0,10.7,9.6,19.5,24.2,32.7l4.1,3.7l4.1-3.7c14.6-13.2,24.2-22,24.2-32.7
                                            c0.1-8.5-6.7-15.5-15.3-15.6C73,35.4,72.9,35.4,72.8,35.4z"/>
                                    </g>
                                    </svg>
                                </div>
                                <div className="col-8">
                                    {userCheck() ? <span style={{"fontSize" : "0.8rem","fontFamily":"RobotoRegular"}}>Favourite Experts</span> : <span style={{"fontSize" : "0.8rem","fontFamily":"RobotoRegular"}}>{userData.username}'s Queries</span> }                    
                                    {favoriteExpert.length === 0 ? <span style={{"display" : "block", "fontSize" : "1rem","color" : "#3C4453"}}>No Experts</span> : <> { favoriteExpert.length === 1 ? <span style={{"display" : "block", "fontSize" : "1rem","color" : "#3C4453"}}> {favoriteExpert.length + " "} Expert</span> : <span style={{"display" : "block", "fontSize" : "1rem","color" : "#3C4453"}}>{favoriteExpert.length + " "} Experts</span>}</>}
                                </div>
                                <div className="col-1">
                                <div className="rightArrow">
                                    <svg version="1.1" width="25px" id="Layer_1" xmlns="http://www.w3.org/2000/svg" xmlnsXlink="http://www.w3.org/1999/xlink" x="0px" y="0px"
                                        viewBox="0 0 120 120" enableBackground="new 0 0 120 120" xmlSpace="preserve">
                                        <g id="Group_2232" transform="translate(-298.325 -210.325)">
                                            <g id="Ellipse_284" transform="translate(298.325 210.325)">
                                                <circle fill="#FFFFFF" cx="60" cy="60" r="56.4"/>
                                                <path fill="#DBDBDB" d="M60,116.4C28.9,116.4,3.6,91.1,3.6,60C3.6,28.9,28.9,3.6,60,3.6c31.1,0,56.4,25.3,56.4,56.4
                                                    C116.4,91.1,91.1,116.4,60,116.4z M60,12.1c-26.4,0-47.9,21.5-47.9,47.9c0,26.4,21.5,47.9,47.9,47.9c26.4,0,47.9-21.5,47.9-47.9
                                                    C107.9,33.6,86.4,12.1,60,12.1z"/>
                                            </g>
                                            <path fill="#DBDBDB" d="M347.2,297.4c-1.2,0-2.5-0.5-3.4-1.4c-1.9-1.9-1.9-4.9,0-6.8l18.9-18.9l-18.9-18.9c-1.9-1.9-1.9-4.9,0-6.8
                                                c1.9-1.9,4.9-1.9,6.8,0l22.2,22.2c1.9,1.9,1.9,4.9,0,6.8L350.6,296C349.7,296.9,348.4,297.4,347.2,297.4z"/>
                                        </g>
                                    </svg>
                                </div>
                                </div>
                            </div>
                            {/* <div className="col-2">                               
                                <div className="rightArrow">
                                    <svg version="1.1" width="25px" id="Layer_1" xmlns="http://www.w3.org/2000/svg" xmlnsXlink="http://www.w3.org/1999/xlink" x="0px" y="0px"
                                        viewBox="0 0 120 120" enableBackground="new 0 0 120 120" xmlSpace="preserve">
                                        <g id="Group_2232" transform="translate(-298.325 -210.325)">
                                            <g id="Ellipse_284" transform="translate(298.325 210.325)">
                                                <circle fill="#FFFFFF" cx="60" cy="60" r="56.4"/>
                                                <path fill="#DBDBDB" d="M60,116.4C28.9,116.4,3.6,91.1,3.6,60C3.6,28.9,28.9,3.6,60,3.6c31.1,0,56.4,25.3,56.4,56.4
                                                    C116.4,91.1,91.1,116.4,60,116.4z M60,12.1c-26.4,0-47.9,21.5-47.9,47.9c0,26.4,21.5,47.9,47.9,47.9c26.4,0,47.9-21.5,47.9-47.9
                                                    C107.9,33.6,86.4,12.1,60,12.1z"/>
                                            </g>
                                            <path fill="#DBDBDB" d="M347.2,297.4c-1.2,0-2.5-0.5-3.4-1.4c-1.9-1.9-1.9-4.9,0-6.8l18.9-18.9l-18.9-18.9c-1.9-1.9-1.9-4.9,0-6.8
                                                c1.9-1.9,4.9-1.9,6.8,0l22.2,22.2c1.9,1.9,1.9,4.9,0,6.8L350.6,296C349.7,296.9,348.4,297.4,347.2,297.4z"/>
                                        </g>
                                    </svg>
                                </div> 
                            </div> */}
                        </div>
                    </div>                    
                </div>
            </div>
        </>);
    }

    function MyBasicInformationCard() {
        var years =[];
        for(let y=0;y<50;y++){
            years.push(
                {
                    value : y,
                    label : y
                }
            )
        }
        return (<>
            {userCheck ? <span className="fontHeader p-3"> Basic Information</span> : <span className="forum_title">{userData.username}'s Basic Information</span>}
            <div className="myBasicInformationCard">
                <div className="row">
                    <div className="col-md-10">
                        Experience
                    </div>
                    <div className="col-md-2">
                        { userCheck() ?
                        <div style={{"float" : "right"}}>
                        <svg version="1.1" className="cursor" onClick={handleInfoOpen} id="Layer_1" width="20px" xmlns="http://www.w3.org/2000/svg" xmlnsXlink="http://www.w3.org/1999/xlink" x="0px" y="0px"
                            viewBox="0 0 120 120" enableBackground="new 0 0 120 120" xmlSpace="preserve">
                            <path id="Icon_material-edit" fill="#07BEB8" d="M5.1,92.7V116H28l67.4-68.8L72.5,23.8L5.1,92.7z M113.1,29.1c2.4-2.4,2.4-6.3,0-8.8
                                L98.8,5.8c-2.3-2.4-6.1-2.4-8.5-0.1c0,0-0.1,0.1-0.1,0.1L79.1,17.2L102,40.5L113.1,29.1L113.1,29.1z"/>
                        </svg> {"  "}Edit</div> : <></>}
                    </div>
                </div>
                <br></br>
                <div className="row" style={{"alignItems" : "center"}}>
                    <div className="col-md-1">
                        <svg version="1.1" width="25px" id="Layer_1" xmlns="http://www.w3.org/2000/svg" xmlnsXlink="http://www.w3.org/1999/xlink" x="0px" y="0px"
                            viewBox="0 0 120 120" enableBackground="new 0 0 120 120" xmlSpace="preserve">
                            <g id="Group_1571" transform="translate(-8.91 -2.675)">
                                <path id="Path_206" fill="#07BEB8" d="M116.2,71.9l-9-13.7c-0.4-0.8-0.7-1.7-0.8-2.7c-1.5-16.8-14.7-30.2-31.5-31.9
                                    c0.3,3.5-1,7-3.7,9.3l-6,5l1.9,7.6c0.8,3.3,0,6.7-2.1,9.3c-2.1,2.6-5.3,4.2-8.6,4.2c-2,0-4-0.5-5.7-1.5L44,53.6l-6.5,4.1
                                    c-0.3,0.2-0.6,0.4-0.9,0.5v0.6c0.1,11.6,5.3,22.6,14.1,30.1c1,0.9,1.6,2.1,1.6,3.5v20.1c0,1.6,1.2,2.9,2.8,3l30.3,2.6
                                    c1.7,0.2,3.2-1.1,3.4-2.8c0-0.1,0-0.2,0-0.3v-14.2c0-0.9,0.7-1.6,1.6-1.6h10.5c3.2,0,5.8-2.6,5.8-5.8V79c0-0.6,0.5-1.2,1.2-1.2h5.1
                                    c2.1,0,3.8-1.6,3.9-3.7C116.9,73.3,116.7,72.6,116.2,71.9z"/>
                                <path id="Path_207" fill="#07BEB8" d="M45.9,45.6l8.9,5.4c1.5,0.9,3.5,0.5,4.5-1.1c0.5-0.7,0.6-1.6,0.4-2.4l-2.5-10
                                    c-0.3-1.2,0.1-2.4,1.1-3.3l7.9-6.8c1.4-1.2,1.5-3.2,0.4-4.6c-0.6-0.7-1.4-1.1-2.2-1.1L54,20.9c-1.2-0.1-2.3-0.9-2.8-2l-4-9.6
                                    c-0.7-1.7-2.6-2.5-4.3-1.8c-0.8,0.3-1.4,1-1.8,1.8l-4,9.6c-0.5,1.1-1.6,1.9-2.8,2L24,21.7c-1.7,0.1-3.1,1.6-3,3.3
                                    c0,0.9,0.5,1.7,1.2,2.3l7.9,6.8c0.9,0.8,1.3,2.1,1.1,3.3l-2.5,10.2c-0.4,1.8,0.7,3.5,2.5,3.9c0.8,0.2,1.7,0,2.4-0.4l8.9-5.4
                                    C43.5,45,44.8,45,45.9,45.6z"/>
                            </g>
                        </svg>
                    </div>
                    <div className="col-md-10">
                        <div className="row">
                            <div className="col-md-12">
                                {userData.company ? <span>{userData.company}</span> : experienceCompany === null ? <span className="basicInfoDefault">Company's name.</span> : <span>{experienceCompany}</span>}
                            </div>
                        </div>
                        <div className="row">
                            <div className="col-md-12">
                                {userData.yearsOfExperience ? 
                                userData.yearsOfExperience === 1 ? 
                                    <span>{userData.yearsOfExperience + " "} Year</span> : 
                                    <span>{userData.yearsOfExperience + " "} Years</span> : 
                                <span>{experienceYears === 0 ? 
                                    <span className="basicInfoDefault">Years of experience.</span> : 
                                    <span>{experienceYears + " "} Years</span>}
                                </span>}
                            </div>
                        </div>
                    </div>
                </div>
                    <Modal
                        show={openInfo}
                        onHide={handleInfoClose}
                        size="md"
                        aria-labelledby="contained-modal-title-vcenter"
                        centered
                    >
                        <Modal.Header >
                            <Modal.Title>Edit Basic Information</Modal.Title>
                        </Modal.Header>
                        <Modal.Body>
                            <span>Edit Company Name :</span>
                            <textarea
                                className="form-control"
                                id="new_title"
                                rows="1"
                                placeholder="Enter your company name here."
                                value={experienceCompany === null ? userData.company : experienceCompany}
                                onChange={(e) => { setExperienceCompany(e.target.value) }}>
                            </textarea>     
                            <span>Years Of Experience :</span>                                                      
                            <Select options={years} onChange={(e) => handleSelectAreaInfo(e)} style={{"zIndex" : "2", "borderBottom" : "1px solid black"}}></Select>
                            <span>Location :</span>
                            <textarea
                                className="form-control"
                                id="new_title"
                                rows="1"
                                placeholder="Enter your location here."
                                value={location === null ? userData.city : location}
                                onChange={(e) => { setLocation(e.target.value) }}>
                            </textarea>
                        </Modal.Body>
                        <Modal.Footer>                        
                            <Button variant="secondary" onClick={handleInfoClose}>
                                Close
                            </Button>
                            <Button variant="primary" onClick={submitBasicInfo}>
                                Submit
                            </Button>
                        </Modal.Footer>
                    </Modal>
                <br></br>
                <div className="row" style={{"alignItems" : "center"}}>
                    <div className="col-md-1">
                    <svg version="1.1" id="Layer_1" width="25px" xmlns="http://www.w3.org/2000/svg" xmlnsXlink="http://www.w3.org/1999/xlink" x="0px" y="0px"
                        viewBox="0 0 120 120" enableBackground="new 0 0 120 120" xmlSpace="preserve">
                        <path id="Icon_material-location-on" fill="#07BEB8" d="M60,3.9c-21.7,0-39.3,17.5-39.3,39.2c0,0,0,0,0,0.1c0,29.5,39.3,73,39.3,73
                            s39.3-43.5,39.3-73C99.3,21.5,81.7,3.9,60,3.9C60,3.9,60,3.9,60,3.9z M60,57.2c-7.8,0-14-6.3-14-14c0-7.8,6.3-14,14-14s14,6.3,14,14
                            C74,50.9,67.8,57.2,60,57.2z"/>
                    </svg>
                    </div>
                    <div className="col-md-10">
                        {userData.city ? <span>{userData.city}</span> : location === null ? <span className="basicInfoDefault">Location Details.</span> : <span>{location}</span>}                            
                    </div>
                </div>
            </div>
        </>);
    }

    const myQueriesCard =  () =>{
        console.log("----->>--User Queries---->>",userQueries)
        
        return(
            <div className="question">
                <div >
                    <input className=" form-control search_bar" type="text"  placeholder="Search" />
                </div>
                {userQueries.length === 0 ? <></> : userQueries.map((q,idx) => {
                    return(
                        <div>
                            <SingleQuestion question = {q} key={idx} fetchQuestion = {getUserQueries}/>
                            {idx === userQueries.length-1 ? <></> : <hr className="mx-3" style={{"opacity":"0.1"}}/>}
                        </div>
                    )
                })}
            </div>
        )
    }
    const savedData = () => {
        console.log("----->>---Saved Data---->>>", saved);
        return(
            <div className="question">
            {saved.length === 0 ? <>No Saved Items</> : <SavedData data = {saved} getSavedData={getSavedData}/> }
            </div>
        )
    }
    const savedExpertsCard = () => {
        console.log("Experts---->>",favoriteExpert)
        return(
            favoriteExpert.length === 0 ? <span>No favorite experts</span> : favoriteExpert.map((e,idx) => {
                return (
                    <ExpertsList e = {e} fetchExperts = {getSavedData} />
                )
            })
        )
    }
    function profileDataControl(){
        switch (dataToggle) {
            case "Complete Profile":
                return (
                    user._id===userData._id ? 
                    <>
                    {savedCard()}
                    {/* {MyBasicInformationCard()} */}
                    </> : <></>
                );
            case "My Queries":
                return (
                    <MyQueries queries = {userQueries} getUserQueries= {getUserQueries}/>
                );
            case "Saved":
                return (
                    savedData()
                )            
            case "Experts":
                return (
                    savedExpertsCard()
                )        
            default:
                break;
        }
        
    }

    return (
        <div className="row forum_contents">
            <div className="col-sm-1">
            </div>
            <div className="col-sm-7">
                {myProfileCard()}
                {profileDataControl()}
                {/* {user._id===userData._id ? savedQueryCard() : <></>}*/}                
            </div>
            <div className="col-md-3">
                {/* <span className="forum_title">Popular Activity</span> */}
                <div className="mr-3">
                    <PopularQuestions />
                    {/* <Ads /> */}
                </div>
            </div>


        </div>
    );
};

MyProfileComponent.propTypes = {
    data: PropTypes.object
};

export default MyProfileComponent;
