import React, { useEffect, useState, useContext } from "react";
import Select from "react-select";
import { Button, Modal } from 'react-bootstrap';
import axios from "axios";
import { AuthContext } from "../../context/AuthContext";
import { useHistory } from "react-router";
import { FormGroup } from "@material-ui/core";
import { FormControlLabel } from "@material-ui/core";
import { Switch } from "@material-ui/core";
// import Switch from "react-bootstrap/esm/Switch";

const options = [
    { value: "finance", label: "Finance" },
    { value: "pharmacy", label: "Pharmacy" },
    { value: "administration", label: "Administration" },
    { value: "accounts", label: "Accounts" },
    { value: "hr", label: "Human Resource" },
    // { value: "entryLevelGuidance", label: "Entry Level Guidance" },
    // { value: "digitalTransformation", label: "Digital Transformation" },
    // { value: "crm", label: "CRM" },
    // { value: "imageBuilding", label: "Image Bulding" },
];
const areaOfInterest = ["Finance", "Pharmacy", "Accounts", "Administration","Human Resources","Sales & Marketing","OperationsFinance",
                        "Entry level guidance","Soft skill development","Digital transformation","Revenue cycle management","CRM","L&D","Legal and Statutory Audit",
                        "Materials and Procurement","Dealing with the new normal","Promoter management","Leadership and entrepreneurial skills","Change management",
                        "Strategy and business development","Innovation and Ideation","Dealing with workplace politics","Image building","Healthcare Market study",
                        "Innovation and Entreupernership","Hospital Design And Planning","M&A - Healthcare","Investment Opportunities","Research Guidance","Medical Services and Administration"];

const NewQuestion = ({ fetchData }) => {
    let { user } = useContext(AuthContext);
    const [settingsData, setSettingsData] = useState({});
    const [open, setOpen] = useState(false);
    const [selectedOptions, setSelectedOptions] = useState([]);
    const [question, setQuestion] = useState('');
    const [checkAnonymous, setCheckAnonymous] = useState(false);
    const history = useHistory();

    const fetchSettings = async () => {
        var res = await axios.get(`${process.env.REACT_APP_BACKEND_URL}/api/settings`);
        (res.data).forEach((dashboards) => {
            if (dashboards.pageType === "forum" && dashboards.nameType == "New Question") {
                setSettingsData(dashboards);
            }
        })
    }

    useEffect(() => {
        fetchSettings();
    }, []);

    if (!user) {
        user = {
            userId: 123,
            username: "Guest",
            userType: "Guest"
        }
    }

    const handleOpen = () => {
        user.username === "Guest" ? history.push('/') : setOpen(true);

        // setOpen(true)
    };
    const handleClose = () => {
        setOpen(false);
    };
    const handleSelectArea = (e) => {
        setSelectedOptions(e)
    }
    const anonymousHandle = () => {
        setCheckAnonymous(!checkAnonymous);
    }
    const submitQuestion = async () => {
        if(question !== ""){
        var q;
        if(checkAnonymous){
            q= {
                username: "Anonymous",
                userId: user._id,
                question: question,
                profilePicture: process.env.REACT_APP_AnonymousAvathar_Url,
                userJob: "",
                solvedBy: [],
                answers:0,
                sharedTo: selectedOptions
            }
        }else {
            q = {
                username: user.username,
                userId: user._id,
                question: question,
                profilePicture:  user.profilePicture,
                userJob: user.designation,
                solvedBy: [],
                answers: 0,
                sharedTo: selectedOptions
            }
        }
         
        try {
            await axios.post(`${process.env.REACT_APP_BACKEND_URL}/api/question`, q);
        } catch (err) {
            console.log("err while post", err)
        }
        // console.log("---->", selectedOptions, "-------->", question, "---->", q);
        handleClose();
        fetchData();
    }
    else{
        alert("Please enter question")
    }
    }

    function newQuestion() {
        var op=[];        
        for(let a=0;a<areaOfInterest.length;a++){
            op.push(
                {
                    value : areaOfInterest[a],
                    label : areaOfInterest[a]
                }
            )
        }
        return (
            <div className="new_question">
                <input className="form-control textgreyarea" type="text" placeholder="Ask your question here." onClick={handleOpen} />
                <Modal
                    show={open}
                    onHide={handleClose}
                    size="md"
                    aria-labelledby="contained-modal-title-vcenter"
                    centered
                >
                    <Modal.Header >
                        <Modal.Title>Ask me</Modal.Title>
                    </Modal.Header>
                    <Modal.Body>
                        <textarea
                            className="form-control"
                            id="new_question"
                            rows="2"
                            placeholder="Enter Your Question here."
                            onChange={(e) => { setQuestion(e.target.value) }}>
                        </textarea>
                        <span>Select Categories</span>
                        <Select options={op} onChange={handleSelectArea} isMulti style={{"zIndex" : "2", "borderBottom" : "1px solid black"}} closeMenuOnSelect={false}></Select>                        
                        <FormGroup>
                            <FormControlLabel control={<Switch onChange={anonymousHandle}/>} label="Anonymous" />
                        </FormGroup>                                               
                        {/* <Switch onChange={anonymousHandle} /> Anonymous */}
                    </Modal.Body>
                    <Modal.Footer>                        
                        <Button variant="secondary" onClick={handleClose}>
                            Close
                        </Button>
                        <Button variant="primary" onClick={submitQuestion}>
                            Submit
                        </Button>
                    </Modal.Footer>
                </Modal>
            </div>
        );
    }

    return (
        <>
            {user.userType === "Guest" && settingsData.guest ? newQuestion() : <span></span>}
            {user.userType === "free" && (settingsData.free && user.expert === false) ? newQuestion() : <span></span>}
            {user.userType === "paid" && (settingsData.paid && !settingsData.paidExpert) ? newQuestion() : <span></span>}
            {user.userType === "free" && (user.expert === true && settingsData.freeExpert) ? newQuestion() : <span></span>}
            {user.userType === "paid" && (user.expert && settingsData.paidExpert) ? newQuestion() : <span></span>}
            {user.userType === "consultant" && settingsData.consultant ? newQuestion() : <span></span>}
        </>
    );
}

export default NewQuestion;