import React, { useState, useContext, useEffect } from "react";
import { Link, useHistory } from "react-router-dom";
import IconButton from "@material-ui/core/IconButton";
import { MoreHoriz, Delete, Share, Done,DoneAllRounded, Edit } from "@material-ui/icons";
import { Reply } from "@material-ui/icons";
import Menu from "@material-ui/core/Menu";
import { Button, Modal } from "react-bootstrap";
import { format } from "timeago.js";
import questionData from "../../data/questions/question-icons.json";
import MenuItem from '@material-ui/core/MenuItem';
import axios from "axios";
import { AuthContext } from "../../context/AuthContext";
import { FormGroup } from "@material-ui/core";
import { FormControlLabel } from "@material-ui/core";
import { Switch } from "@material-ui/core";

const SingleQuestion = ({ question, fetchData, fetchQuestion, getQuestions }) => {
    const history = useHistory();
    let { user } = useContext(AuthContext);
    const [answer, setAnswer] = useState('');
    const [showModal, setShowModal] = useState(false);
    const [showEditModal, setShowEditModal] = useState(false);
    const [checkAnonymous, setCheckAnonymous] = useState(false);
    const [userData, setUserData] = useState({});
    const [editvalue, setEditvalue] = useState(null);

    var time = format(question.createdAt);
    const [anchorEl, setAnchorEl] = useState(null);
    const open = Boolean(anchorEl);
    var colorIndex = 0;
    var colorVariants = {
        textColor : ["#22b8c2","#04a0f1","#6a4ac2","#ff9932","#0069ff","#f04a4a"],
        background : ["#d5f1f3","#dbf3ff","#e8dfff","#fbe1c7","#a0c6ff","#ffe3e3"]
    }

    if (!user) {
        user = {
            userId: 123,
            username: "Guest",
            userType: "Guest",
            saved: {},
        }
    }

    const getUserData = async () => {
        var resultUser = await axios.get(`${process.env.REACT_APP_BACKEND_URL}/api/users/` + user._id + '/oneUser');
        setUserData(resultUser.data);
    }
    useEffect(()=>{
        getUserData();
    },[])
    const handleMenuClick = (event) => {
        setAnchorEl(event.currentTarget);
    };
    const handleMenuClose = () => {
        setAnchorEl(null);
    };

    //--------- Handling Reply Modal
    const handleModalOpen = () => {
        if(user.username === "Guest"){
            history.push('/home-one')
        }
        else {
            setShowModal(true)
        }
    };
    const handleModalClose = () => {
        setShowModal(false);
    };
    //--------- Handling Edit Modal
    const handleEditModalOpen = () => {
        setShowEditModal(true)
    };
    const handleEditModalClose = () => {
        setEditvalue(null);
        setShowEditModal(false);
    };
    const anonymousHandle = () => {
        setCheckAnonymous(!checkAnonymous);
    }

    const showFilteredResults = (filters) => {
        if(history.location.pathname !== '/community')
        history.push('/community');
        var Obj = { sharedTo: [], price: [] }
        Obj.sharedTo.push(filters);
        const variables = {
            skip: 0,
            limit: 8,
            filters: Obj
        }
        getQuestions(variables);
    }

    const upVoteHandler = async () => {
        if(user.username === "Guest"){
            history.push('/home-one')
        }
        else {
            var upvotes = {
                userId: user._id,
                username: user.username,
                userImage: user.profilePicture
            };
            try {
                await axios.put(`${process.env.REACT_APP_BACKEND_URL}/api/question/` + question._id + `/upvotes`, upvotes);
                history.location.pathname === '/answers/' + question._id ? fetchQuestion() : fetchData();
            } catch (err) {
                console.log(err, "Error in updating upvotes")
            }
        }
    }
    //--------- Submitting Answer
    const submitAnswer = async () => {

        var a;
        if (checkAnonymous) {
            a = {
                questionId: question._id,
                username: "Anonymous",
                userId: user._id,
                userImage: process.env.REACT_APP_AnonymousAvathar_Url,
                userJob: "",
                message: answer,
                solved: false
            }
        } else {
            a = {
                questionId: question._id,
                username: user.username,
                userId: user._id,
                userImage: user.profilePicture,
                userJob: "",
                message: answer,
                solved: false
            }
        }

        var count = parseInt(question.answers) + 1;
        try {
            await axios.post(`${process.env.REACT_APP_BACKEND_URL}/api/answer`, a);
            // console.log("B---->", question);
            if (history.location.pathname === '/community') {
                history.push('/answers/' + question._id);
                fetchData();
            } else {
                handleModalClose();
                fetchQuestion();
            }
        } catch (err) {
            console.log("Error in submitting Answer: ", err)
        }
        setCheckAnonymous(false);

    }
    //----------Deleting Question
    const deleteQuestion = async () => {
        try {
            var res = await axios.delete(`${process.env.REACT_APP_BACKEND_URL}/api/question/` + question._id);
            // console.log("--------->", res)
        } catch (err) {
            console.log("Error--->", err)
        }
        if (history.location.pathname === '/community') {
            fetchData();
        } else {
            history.push('/community');
        }

    }
    //----------Updating Question
    const updateQuestion = async () => {
        question.question = editvalue;
        try {
            await axios.put(`${process.env.REACT_APP_BACKEND_URL}/api/question/` + question._id + `/updateQuestion`, question)
        }catch(err){
            console.log("Error in updating question ",err);
        }
        handleEditModalClose();
    }
    //----------Handling Upvote Icon
    const upvoteIconHandler = () => {
        const upvotesLength = question.upvotes.length;                
        for (var k = 0; k < upvotesLength; k++) {
            if (question.upvotes[k].userId == user._id) {
                break;
            }
        }
        if (k == upvotesLength) {
            return(
                <svg version="1.1" onClick={upVoteHandler} width="25px" id="Layer_1" xmlns="http://www.w3.org/2000/svg" xmlnsXlink="http://www.w3.org/1999/xlink" x="0px" y="0px"
                    viewBox="0 0 120 120" enable-background="new 0 0 120 120" xmlSpace="preserve">
                    <g id="noun_touch_3329909" transform="matrix(0.966, 0.259, -0.259, 0.966, -14.824, -32.273)">
                        <path fill="#7789AC" stroke="#7789AC" strokeWidth="3" d="M121.8,123.2c-9.6,2.6-19.9,1-28.3-4.3c-2.8-1.7-5.3-3.9-7.6-6.3L53.9,85.9c-4.6-3.9-5.2-10.7-1.3-15.3
                            c3.8-4.6,10.7-5.2,15.3-1.3l3,2.5L59.7,30.4c-1.6-5.8,1.9-11.7,7.6-13.3c0,0,0,0,0,0c5.8-1.5,11.7,1.9,13.3,7.6L85.5,43
                            c1.4-1.5,3.2-2.7,5.3-3.2c4.8-1.3,9.8,0.9,12.2,5.1c1.3-1.5,3-2.7,5-3.4c2.7-0.9,5.7-0.7,8.3,0.6c1.5,0.8,2.8,1.8,3.8,3.1
                            c1.6-2.1,3.9-3.6,6.7-4.1c5.9-1.1,11.5,2.8,12.6,8.7l8,29.5c4.8,17.9-4.7,36.4-22.1,42.9C124.1,122.5,122.9,122.9,121.8,123.2z
                            M59.4,71.9c-1.1,0.3-2.2,0.9-3,1.9c-2.1,2.5-1.8,6.2,0.7,8.4l32.2,26.9c2.2,2.4,4.3,4.2,6.8,5.7c7.3,4.6,16.2,5.9,24.5,3.7
                            c0.8-0.2,2-0.6,2.9-0.9c15-5.6,23.2-21.5,19.1-37l-8-29.7c-0.6-3.4-3.7-5.5-6.9-4.9c-3.2,0.6-5.3,3.6-4.8,6.8l0.3,1.2l-4.7,1.4
                            c-0.2-0.5-0.3-1-0.4-1.6l-1.1-4c-0.5-1.4-1.5-2.6-2.9-3.3c-1.4-0.7-3-0.9-4.5-0.3c-2.9,0.9-4.6,3.9-3.9,6.8l-4.8,1.2l-1.5-5.4
                            c-0.8-3.2-4.1-5-7.3-4.2c-3.2,0.8-5,4.1-4.2,7.3L83.2,53l-7.3-27c-0.9-3.2-4.1-5-7.3-4.2c0,0,0,0,0,0c-3.2,0.9-5,4.1-4.2,7.3
                            l15.2,56.4L64.7,73.1C63.2,71.8,61.2,71.4,59.4,71.9z"/>
                    </g>
                </svg>
                
            );
        } else {
            return (
                <svg version="1.1" width="25px" onClick={upVoteHandler} id="Layer_1" xmlns="http://www.w3.org/2000/svg" xmlnsXlink="http://www.w3.org/1999/xlink" x="0px" y="0px"
                    viewBox="0 0 120 120" enableBackground="new 0 0 120 120" xmlSpace="preserve">
                    <g id="noun_touch_3329909" transform="matrix(0.966, 0.259, -0.259, 0.966, -14.824, -32.273)">
                        <path id="Path_551" stroke="#07BEB8" strokeWidth="3" fill="#07BEB8" d="M145.9,80.1l-4.4-16.5l-3-11l-0.7-2.8c-0.9-4.6-5.3-7.7-10-6.8s-7.7,5.3-6.8,10
                            c0.1,0.4,0.2,0.9,0.4,1.3l-1.5-5.5c-1.5-4.5-6.3-6.9-10.8-5.5c-4.1,1.4-6.6,5.6-5.7,9.9l-1.5-5.5c-1.2-4.6-5.9-7.3-10.5-6.1
                            c-4.6,1.2-7.3,5.9-6.1,10.5l-7.4-27.6c-1.2-4.6-5.9-7.3-10.5-6c-4.6,1.2-7.3,5.9-6,10.5l11.1,41.3l2.3,8.6l-9.1-7.6
                            c-3.6-3-9-2.6-12.1,1c-3,3.6-2.6,9,1,12.1l0,0l32.9,27.5c2.1,2.3,4.5,4.4,7.2,6c8.1,5.1,17.9,6.5,27,4.1c1.1-0.3,2.1-0.6,3.2-1
                            C141.4,114.7,150.5,97.1,145.9,80.1z"/>
                    </g>
                </svg>
            );
        }
    }

    const saveIcon = () => {
        
        if(Object.keys(userData).length > 0){
        const savedLength = userData.saved.questions.length;                        
        for (var l = 0; l < savedLength; l++) {
            if (userData.saved.questions[l] == question._id) {
                break;
            }
        }
        if (l == savedLength) {
            return(
                <>
                <svg version="1.1" className="cursor" width="25px" id="Layer_1" xmlns="http://www.w3.org/2000/svg" xmlnsXlink="http://www.w3.org/1999/xlink" x="0px" y="0px"
                    viewBox="0 0 120 120" enableBackground="new 0 0 120 120" xmlSpace="preserve">
                <path id="Icon_awesome-bookmark" fill="none" stroke="#535252" strokeWidth="10.1678" strokeMiterlimit="10" d="M23.5,108.6V20.5
                    c0-5,4.1-9.1,9.1-9.1h54.7c5,0,9.1,4.1,9.1,9.1v88.1L60,87.3L23.5,108.6z"/>
                </svg>
                <span className="menuOptions">Save</span>
                </>
                
            );
        } else {
            return (
                <>
                <svg version="1.1" className="cursor" id="Layer_1" width="20px" xmlns="http://www.w3.org/2000/svg" xmlnsXlink="http://www.w3.org/1999/xlink" x="0px" y="0px"
                    viewBox="0 0 120 120" enableBackground="new 0 0 120 120" xmlSpace="preserve">
                <path id="Icon_awesome-bookmark" stroke="black" strokeWidth="3" fill="#000000"  d="M17,117.4v-104c0-5.9,4.8-10.8,10.8-10.8h64.5c5.9,0,10.8,4.8,10.8,10.8v104
                    L60,92.3L17,117.4z"/>
                </svg>
                <span className="menuOptions">Saved</span>
                </>
            );
        }
        }
    }

    const saveHandler = async () => { 
        if(user.username === "Guest"){
            history.push('/home-one')
        }
        else {
            saveIcon();
            var savedData = {
                type : "questions",
                id : question._id
            }       
            console.log("=-=-=-=-=-=-=-===------>",userData.saved)
            const savedLength = userData.saved.questions.length;                
            for (var m = 0; m < savedLength; m++) {
                if (userData.saved.questions[m] == question._id) {
                    break;
                }
            }        
            if(m === savedLength){
                userData.saved.questions.push(question._id);
                // history.location.pathname !== '/community' ? fetchQuestion() : fetchData();
                getUserData();
            }
            else {
                userData.saved.questions.splice(1,m);
                // history.location.pathname !== '/community' ? fetchQuestion() : fetchData();
                getUserData();
            }
            try {
            var result = await axios.put(`${process.env.REACT_APP_BACKEND_URL}/api/users/` + user._id + `/putSavedData`, savedData);
                history.location.pathname !== '/community' && history.location.pathname !== '/home' ? fetchQuestion() : fetchData();
                getUserData();
            }catch (err) {
                console.log("Error in saving Question")
            }
        }
    }

    function cvalue () {
        if(question.answers === 1) {
            <span className="space_left">{question.answers + " "} Answer</span> 
        }
        else {
            <span className="space_left">{question.answers + " "} Answers</span>
        }
    }
    return (
        <>
            {Object.keys(question).length > 0 ?
                <div className="">
                    <div className=" justify-content-between">
                        <div className="row question_actions my-3">
                            <div className=" col-10 d-flex no-gutters">
                                <div className="col-2" style={{"display": "contents"}}>
                                    {question.username === "Anonymous" ? 
                                    <img
                                        className="questionProfileImg"
                                        src={question.profilePicture ? process.env.REACT_APP_BACKEND_URL + question.profilePicture : process.env.REACT_APP_BACKEND_URL + process.env.REACT_APP_ProfileAvathar_Url}
                                        alt=""
                                    />:
                                    <Link to={{
                                            pathname: '/myprofile/' + question.userId
                                            // state : question
                                        }} style={{ color: 'black' }}>
                                        <img
                                            className="questionProfileImg"
                                            src={question.profilePicture ? process.env.REACT_APP_BACKEND_URL + question.profilePicture : process.env.REACT_APP_BACKEND_URL + process.env.REACT_APP_ProfileAvathar_Url}
                                            alt=""
                                        />
                                    </Link>}
                                </div>
                            
                                <div className="col-10 question_user ml-2">
                                    <div style={{"display": "flex"}}>
                                        <span className="questionUsername">{question.username}</span>
                                            <svg version="1.1" width="7px" id="Layer_1" xmlns="http://www.w3.org/2000/svg" xmlnsXlink="http://www.w3.org/1999/xlink" x="0px" y="0px"
                                                viewBox="0 0 120 120" enable-background="new 0 0 120 120" xmlSpace="preserve">
                                                <circle id="Ellipse_290" fill="#CCD5E5" cx="60" cy="60" r="53"/>
                                            </svg>
                                        <span className="questionDate">{time}</span>
                                    </div>                                    
                                    <span className="questionJob">{question.userJob}</span>
                                    {/* <div className="questionDate ml-0">{time}</div> */}
                                </div>
                            </div>
                            <div className="col-2 cursor">
                                <IconButton
                                    onClick={handleMenuClick}
                                    size="small"
                                    sx={{ ml: 2 }}
                                    style={{"float" : "right"}}
                                    aria-controls={open ? 'account-menu' : undefined}
                                    aria-haspopup="true"
                                    aria-expanded={open ? 'true' : undefined}
                                >
                                    <svg version="1.1" width="25px" id="Layer_1" xmlns="http://www.w3.org/2000/svg" xmlnsXlink="http://www.w3.org/1999/xlink" x="0px" y="0px"
                                        viewBox="0 0 120 120" enable-background="new 0 0 120 120" xmlSpace="preserve">
                                    <g id="Group_2017" transform="translate(-1291 -358)">
                                        <g id="Ellipse_289" transform="translate(1291 358)">
                                            <circle fill="none" cx="60" cy="60" r="56"/>
                                            <circle fill="none" stroke="#BDC9DE" stroke-width="3.7333" cx="60" cy="60" r="54.1"/>
                                        </g>
                                        <g id="Group_2016" transform="translate(1504.627 -2256.78) rotate(90)">
                                            <g id="Ellipse_286" transform="translate(2627.646 188.627)">
                                                <circle fill="none" stroke="#CCD5E5" stroke-width="3.7333" cx="47.8" cy="-63.7" r="6.8"/>
                                            </g>
                                            <g id="Ellipse_287" transform="translate(2627.646 196.351)">
                                                <circle fill="none" stroke="#CCD5E5" stroke-width="3.7333" cx="47.8" cy="-42.6" r="6.8"/>
                                            </g>
                                            <g id="Ellipse_288" transform="translate(2627.646 204.075)">
                                                <circle fill="none" stroke="#CCD5E5" stroke-width="3.7333" cx="47.8" cy="-21.5" r="6.8"/>
                                            </g>
                                        </g>
                                    </g>
                                    </svg>
                                </IconButton>
                                <Menu
                                    anchorEl={anchorEl}
                                    getContentAnchorEl={null}
                                    id="account-menu"
                                    open={open}
                                    onClose={handleMenuClose}
                                    onClick={handleMenuClose}
                                    PaperProps={{
                                        elevation: 0,
                                        sx: {
                                            overflow: 'visible',
                                            filter: 'drop-shadow(0px 2px 8px rgba(0,0,0,0.32))',
                                            mt: 1.5,
                                            '& .MuiAvatar-root': {
                                                width: 32,
                                                height: 32,
                                                ml: -0.5,
                                                mr: 1,
                                            },
                                            '&:before': {
                                                content: '""',
                                                display: 'block',
                                                position: 'absolute',
                                                top: 0,
                                                right: 14,
                                                width: 10,
                                                height: 10,
                                                bgcolor: 'background.paper',
                                                transform: 'translateY(-50%) rotate(45deg)',
                                                zIndex: 0,
                                            },
                                        },
                                    }}
                                    transformOrigin={{ horizontal: 'right', vertical: 'top' }}
                                    anchorOrigin={{ horizontal: 'right', vertical: 'bottom' }}
                                >
                                    {(question.userId === user._id) && (user.userType !== "Guest") ?
                                        <MenuItem onClick={handleEditModalOpen}>
                                            <svg version="1.1" id="Layer_1" width="25px" xmlns="http://www.w3.org/2000/svg" xmlnsXlink="http://www.w3.org/1999/xlink" x="0px" y="0px"
                                                viewBox="0 0 120 120" enableBackground="new 0 0 120 120" xmlSpace="preserve">
                                                <path id="Icon_material-edit" fill="#07BEB8" d="M5.1,92.7V116H28l67.4-68.8L72.5,23.8L5.1,92.7z M113.1,29.1c2.4-2.4,2.4-6.3,0-8.8
                                                    L98.8,5.8c-2.3-2.4-6.1-2.4-8.5-0.1c0,0-0.1,0.1-0.1,0.1L79.1,17.2L102,40.5L113.1,29.1L113.1,29.1z"/>
                                            </svg><span className="menuOptions">Edit</span>
                                        </MenuItem> :
                                        <div></div>
                                    }
                                    <MenuItem onClick={saveHandler}>
                                        {saveIcon()}
                                    </MenuItem>
                                    {(question.userId === user._id) && (user.userType !== "Guest") ?
                                        <MenuItem onClick={deleteQuestion}>
                                            <svg version="1.1" width="25px" id="Layer_1" xmlns="http://www.w3.org/2000/svg" xmlnsXlink="http://www.w3.org/1999/xlink" x="0px" y="0px"
                                                viewBox="0 0 120 120" enable-background="new 0 0 120 120" xmlSpace="preserve">
                                            <g>
                                                <path fill="#6A7791" d="M65.4,41.6h8.1V86h-8.1V41.6z"/>
                                                <path fill="#6A7791" d="M46.5,41.6h8.1V86h-8.1V41.6z"/>
                                                <path fill="#6A7791" d="M69.1,3.7H50.9c-2.9,0-5.6,1.1-7.6,3.2c-2,2-3.2,4.8-3.2,7.6v6.6h-26c-1.4,0-2.8,0.8-3.5,2
                                                    c-0.7,1.2-0.7,2.8,0,4c0.7,1.2,2.1,2,3.5,2h7.2l3.9,70.5h0c0.2,4.5,2.2,8.7,5.5,11.7c3.3,3.1,7.6,4.8,12,4.8h34.6
                                                    c4.5,0,8.8-1.7,12-4.8c3.3-3.1,5.2-7.3,5.5-11.7l3.9-70.5h7.2h0c1.4,0,2.8-0.8,3.5-2c0.7-1.2,0.7-2.8,0-4c-0.7-1.2-2.1-2-3.5-2
                                                    H79.8v-6.6c0-2.9-1.1-5.6-3.2-7.6C74.7,4.9,71.9,3.7,69.1,3.7L69.1,3.7z M48.2,14.5L48.2,14.5c0-1.5,1.2-2.7,2.7-2.7h18.2
                                                    c0.7,0,1.4,0.3,1.9,0.8c0.5,0.5,0.8,1.2,0.8,1.9v6.6H48.2L48.2,14.5z M90.6,29.2l-3.9,70.1c-0.1,2.4-1.2,4.7-2.9,6.3
                                                    c-1.8,1.7-4.1,2.6-6.5,2.6H42.6c-2.4,0-4.7-0.9-6.5-2.6c-1.8-1.7-2.8-3.9-2.9-6.3l-3.9-70.1H90.6z"/>
                                            </g>
                                            </svg><span className="menuOptions">Delete</span>
                                        </MenuItem> :
                                        <div></div>
                                    }
                                    <MenuItem>                                        
                                        <a  href={`https://api.whatsapp.com/send?phone=&text=${process.env.REACT_APP_FRONTEND_URL}` + history.location.pathname + '/' + question._id} >
                                            <svg version="1.1"  width="25px" id="Layer_1" xmlns="http://www.w3.org/2000/svg" xmlnsXlink="http://www.w3.org/1999/xlink" x="0px" y="0px"
                                                viewBox="0 0 120 120" enable-background="new 0 0 120 120" xmlSpace="preserve">
                                                <g id="Icon_feather-share-2" transform="translate(-3.75 -2.25)">
                                                    <path id="Path_121" fill="none" stroke="#7789AC" stroke-width="7.8" stroke-linecap="round" stroke-linejoin="round" d="
                                                        M110.6,25.9c0,8.6-7,15.6-15.6,15.6s-15.6-7-15.6-15.6s7-15.6,15.6-15.6S110.6,17.2,110.6,25.9z"/>
                                                    <path id="Path_122" fill="none" stroke="#7789AC" stroke-width="7.8" stroke-linecap="round" stroke-linejoin="round" d="
                                                        M48.2,62.2c0,8.6-7,15.6-15.6,15.6S17,70.9,17,62.2s7-15.6,15.6-15.6S48.2,53.6,48.2,62.2z"/>
                                                    <path id="Path_123" fill="none" stroke="#7789AC" stroke-width="7.8" stroke-linecap="round" stroke-linejoin="round" d="
                                                        M110.6,98.7c0,8.6-7,15.6-15.6,15.6s-15.6-7-15.6-15.6s7-15.6,15.6-15.6S110.6,90,110.6,98.7z"/>
                                                    <path id="Path_124" fill="none" stroke="#7789AC" stroke-width="7.8" stroke-linecap="round" stroke-linejoin="round" d="M46,70.1
                                                        l35.5,20.7"/>
                                                    <path id="Path_125" fill="none" stroke="#7789AC" stroke-width="7.8" stroke-linecap="round" stroke-linejoin="round" d="
                                                        M81.5,33.7L46,54.4"/>
                                                </g>
                                            </svg><span className="menuOptions">Share</span>
                                        </a>
                                    </MenuItem>
                                </Menu>
                            </div>
                            <Modal
                                    show={showEditModal}
                                    onHide={handleEditModalClose}
                                    size="md"
                                    aria-labelledby="contained-modal-title-vcenter"
                                    centered
                                >
                                    <Modal.Header >
                                        <Modal.Title>Edit</Modal.Title>
                                    </Modal.Header>
                                    <Modal.Body>
                                        <textarea
                                            class="form-control"
                                            id="new_question"
                                            rows="2"
                                            value={editvalue===null?question.question:editvalue}
                                            onChange={(e) => { setEditvalue(e.target.value);}}>
                                        </textarea>
                                    </Modal.Body>
                                    <Modal.Footer>
                                        <Button variant="secondary" onClick={handleEditModalClose}>
                                            Close
                                        </Button>
                                        <Button variant="primary" onClick={updateQuestion}>
                                            Update
                                        </Button>
                                    </Modal.Footer>
                            </Modal>
                        </div>
                        <div className="questionTop my-3">
                            <div className="questionTopLeft">
                                {history.location.pathname === '/community' || history.location.pathname === '/home'  ?
                                    <Link to={{
                                        pathname: '/answers/' + question._id
                                        // state : question
                                    }} style={{ color: 'black' }}>
                                        <span className="questionText mx-1">{question?.question}</span>
                                    </Link> :
                                    <span className="q_answer_topic">{question?.question}</span>}
                            </div>
                            {/* <div className="questionTopRight">
                                {question.solvedBy.length === 0 ?
                                    <></> :
                                    <svg version="1.1" width="25px" id="Layer_1" xmlns="http://www.w3.org/2000/svg" xmlnsXlink="http://www.w3.org/1999/xlink" x="0px" y="0px"
                                        viewBox="0 0 120 120" enableBackground="new 0 0 120 120" xmlSpace="preserve">
                                        <path id="Path_542" fill="#51C8AF" d="M42.8,106l-40-41.3l16.1-14.9l23.9,25.8l59-61.5l15.3,13.5L42.8,106z"/>
                                    </svg>}
                            </div> */}
                        </div>
                        <div className=" m-3">
                            <div className="row no-gutters">
                                <div className="px-0" style={{"display":"flex","flexWrap":"wrap"}}>
                                    {question.sharedTo.map((interest, index) => {
                                        if(index < colorVariants.textColor.length){
                                            colorIndex = index;
                                        }
                                        else{
                                            // colorIndex--;
                                            colorIndex < 0 ? colorIndex++ : colorIndex--;
                                        }
                                        return (
                                            <>
                                            {/* <Button variant="outline-secondary" onClick={() => showFilteredResults(interest.label)} className="space_left mb-2" size="sm" key={index}>{interest.label}</Button> */}
                                                <a key={index} className="cursor px-2 mr-1 " onClick={() => {if(history.location.pathname === '/community')showFilteredResults(interest.label)}} style={{"border" : "1px solid"+ colorVariants.textColor[colorIndex], "background" : colorVariants.background[colorIndex], "borderRadius" : "5px"}}>
                                                    <span style={{"color" : colorVariants.textColor[colorIndex], "fontSize" : "0.8rem"}}>{interest.label}</span>
                                                </a>
                                            </>
                                        );
                                    })}
                                </div>
                                
                            </div>
                            <div className="row mt-3 no-gutters" style={{"justifyContent" : "space-between", "alignItems" : "center"}}>
                                <div className="col-3 cursor" style={{"display" : "flex","justifyContent" : "flex-start", "justifyItems" : "center"}}>
                                    {upvoteIconHandler()}{question.upvotes.length === 1 ? 
                                        <><span className=" like_count" style={{"marginLeft" : "3px"}}>{question.upvotes.length + " "}</span><span className=" like_text" style={{"marginLeft" : "3px"}}> Upvote</span> </>: <><span className=" like_count" style={{"marginLeft" : "3px"}}>{question.upvotes.length + " "}</span><span className=" like_text" style={{"marginLeft" : "3px"}} > Upvotes</span></>}
                                </div>
                                <div className="col-3 cursor" style={{"display" : "flex","justifyContent" : "flex-start", "justifyItems" : "center"}} onClick={{handleModalOpen}}>
                                    <svg version="1.1" id="Layer_1" width="25px" xmlns="http://www.w3.org/2000/svg" xmlnsXlink="http://www.w3.org/1999/xlink" x="0px" y="0px"
                                        viewBox="0 0 120 120" enable-background="new 0 0 120 120" xmlSpace="preserve">
                                        <path fill="#7789AC" stroke="#7789AC" strokeWidth="3" d="M112.4,114.7L81.6,83.9H17.4c-5.4,0-9.8-4.4-9.9-9.8v-59c0-5.4,4.4-9.9,9.9-9.9h85.2c5.4,0,9.9,4.4,9.9,9.9
                                            V114.7z M14.1,74.1c0,1.8,1.5,3.3,3.3,3.3h66.9l21.6,21.6V15.1c0-1.8-1.5-3.3-3.3-3.3H17.4c-1.8,0-3.3,1.5-3.3,3.3V74.1z"/>
                                    </svg> 
                                        <Link to={{
                                            pathname: '/answers/' + question._id
                                            // state : question
                                        }} style={{ color: '#8791A4' }}>{question.answers === 1 ?
                                            <><span className="like_count" style={{"marginLeft" : "3px"}}> {question.answers}</span><span className="like_text"> Answer</span> </>:<><span className=" like_count" style={{"marginLeft" : "3px"}}>{question.answers + " "}</span><span className="like_text"> Answers</span></>}
                                        </Link> 
                                </div>
                                <div className="col-3 cursor" style={{"display" : "flex","justifyContent" : "flex-start", "justifyItems" : "center"}}>
                                    <a href={`https://api.whatsapp.com/send?phone=&text=${process.env.REACT_APP_FRONTEND_URL}` + history.location.pathname + '/' + question._id} style={{"color" : "#8791A4"}}>
                                        <svg version="1.1" width="25px" id="Layer_1" xmlns="http://www.w3.org/2000/svg" xmlnsXlink="http://www.w3.org/1999/xlink" x="0px" y="0px"
                                            viewBox="0 0 120 120" enable-background="new 0 0 120 120" xmlSpace="preserve">
                                            <g id="Icon_feather-share-2" transform="translate(-3.75 -2.25)">
                                                <path id="Path_121" fill="none" stroke="#7789AC" stroke-width="7.8" stroke-linecap="round" stroke-linejoin="round" d="
                                                    M110.6,25.9c0,8.6-7,15.6-15.6,15.6s-15.6-7-15.6-15.6s7-15.6,15.6-15.6S110.6,17.2,110.6,25.9z"/>
                                                <path id="Path_122" fill="none" stroke="#7789AC" stroke-width="7.8" stroke-linecap="round" stroke-linejoin="round" d="
                                                    M48.2,62.2c0,8.6-7,15.6-15.6,15.6S17,70.9,17,62.2s7-15.6,15.6-15.6S48.2,53.6,48.2,62.2z"/>
                                                <path id="Path_123" fill="none" stroke="#7789AC" stroke-width="7.8" stroke-linecap="round" stroke-linejoin="round" d="
                                                    M110.6,98.7c0,8.6-7,15.6-15.6,15.6s-15.6-7-15.6-15.6s7-15.6,15.6-15.6S110.6,90,110.6,98.7z"/>
                                                <path id="Path_124" fill="none" stroke="#7789AC" stroke-width="7.8" stroke-linecap="round" stroke-linejoin="round" d="M46,70.1
                                                    l35.5,20.7"/>
                                                <path id="Path_125" fill="none" stroke="#7789AC" stroke-width="7.8" stroke-linecap="round" stroke-linejoin="round" d="
                                                    M81.5,33.7L46,54.4"/>
                                            </g>
                                        </svg> 
                                        <span className="like_text" style={{"marginLeft" : "3px"}} >Share</span>
                                    </a>
                                </div>
                                <div className="col-3 cursor" style={{"display" : "flex","justifyContent": "flex-end", "justifyItems" : "center"}}>
                                    <div variant="primary" className="btn loginButtonColors rounded-pill " onClick={handleModalOpen}>
                                        <svg version="1.1" id="Layer_1" width="16px" xmlns="http://www.w3.org/2000/svg" xmlnsXlink="http://www.w3.org/1999/xlink" x="0px" y="0px"
                                            viewBox="0 0 120 120" enable-background="new 0 0 120 120" xmlSpace="preserve">
                                            <path fill="#FFFFFF" stroke="#FFFFFF" strokeWidth="3" d="M112.4,114.7L81.6,83.9H17.4c-5.4,0-9.8-4.4-9.9-9.8v-59c0-5.4,4.4-9.9,9.9-9.9h85.2c5.4,0,9.9,4.4,9.9,9.9
                                                V114.7z M14.1,74.1c0,1.8,1.5,3.3,3.3,3.3h66.9l21.6,21.6V15.1c0-1.8-1.5-3.3-3.3-3.3H17.4c-1.8,0-3.3,1.5-3.3,3.3V74.1z"/>
                                        </svg>
                                        <span style={{"fontSize" : "0.9rem", "color" : "white","fontFamily":"RobotoRegular"}}>Answer</span>
                                    </div>
                                </div>
                            </div>
                            <Modal
                                show={showModal}
                                onHide={handleModalClose}
                                size="md"
                                aria-labelledby="contained-modal-title-vcenter"
                                centered
                            >
                                <Modal.Header >
                                    <Modal.Title>Reply</Modal.Title>
                                </Modal.Header>
                                <Modal.Body>
                                    <textarea
                                        class="form-control"
                                        id="new_question"
                                        rows="2"
                                        placeholder="Enter your reply here."
                                        onChange={(e) => { setAnswer(e.target.value) }}>
                                    </textarea>
                                    <FormGroup>
                                        <FormControlLabel control={<Switch onChange={anonymousHandle} />} label="Anonymous" />
                                    </FormGroup>
                                </Modal.Body>
                                <Modal.Footer>
                                    <Button variant="secondary" onClick={handleModalClose}>
                                        Close
                                    </Button>
                                    <Button variant="primary" onClick={submitAnswer}>
                                        Submit
                                    </Button>
                                </Modal.Footer>
                            </Modal>
                        </div>                        
                    </div>
                </div>
                : <div></div>}</>
    );
};

export default SingleQuestion;
