import React from 'react';
import { useState, useEffect, useRef } from "react";
import Radio from '@material-ui/core/Radio';
import axios from "axios";
import Switch from 'react-switch';

export default function SuperSettingsDashboard() {
  const [forumDashboard, setForumDashboard] = useState([]);
  const [chatDashboard, setChatDashboard] = useState([]);
  const [articleDashboard, setArticleDashboard] = useState([]);


  const [show, setShow] = useState(false);
  const handleClose = () => setShow(false);
  const handleShow = () => setShow(true);
  const nameType = useRef();
  const [pageType, setPageType] = useState('forum');

  const fetchSettings = async () => {
    var res = await axios.get(`${process.env.REACT_APP_BACKEND_URL}/api/settings`);

    var formData=[];
    await (res.data).forEach((dashboards) => {
        if (dashboards.pageType === "forum") {
          formData.push(dashboards);
        }
      })
      setForumDashboard(formData);
      formData=[];
      await (res.data).forEach((dashboards) => {
        if (dashboards.pageType === "chat") {
          formData.push(dashboards);
        }
      })
      setChatDashboard(formData);
      formData=[];
      await (res.data).forEach((dashboards) => {
        if (dashboards.pageType === "article") {
          formData.push(dashboards);
        }
      })
      setArticleDashboard(formData);
      formData=[];
  }
  useEffect(() => {
    fetchSettings();
  }, []);


  const renderHeader = () => {
    let headerElement = ["No", "Function","Guest", "Free", "Paid", "Free Expert","Paid Expert", "Consultant", "Action"]
    return headerElement.map((key, index) => {
      return <th key={index}>{key.toUpperCase()}</th>
    })
  };

  async function removeSettings(nameType) {
    try {
      var option = {
        params: { "nameType": nameType }
      };

      await axios.delete(`${process.env.REACT_APP_BACKEND_URL}/api/settings`, option).then(function (adminData) {
        fetchSettings();
      }).catch(function (error) {
        // handle error
        console.error(error);
      })
    } catch (err) {
      console.error(err);
    }
  };

  const handleSwithChange = async (nameType, active, type) => {
    try {
      var option = {
        "nameType": nameType, type: type, active: !active
      };
      await axios.put(`${process.env.REACT_APP_BACKEND_URL}/api/settings/active`, option).then(function (adminData) {
        // alert("updated successful")
        fetchSettings();
      }).catch(function (error) {
        // handle error
        console.error(error);
      })
    } catch (err) {
      console.error(err);
    }
  };


  const handleClick = async (e) => {
    e.preventDefault();
    const settingsData = {
      pageType: pageType,
      nameType: nameType.current.value,
      guest: false,
      free: false,
      paid: false,
      expert: false,
      consultant: false
    };
    try {
      await axios.post(`${process.env.REACT_APP_BACKEND_URL}/api/settings`, settingsData);
      setShow(false)
      fetchSettings();
    } catch (err) {
      console.log(err, "lol");
      setShow(true);
    }

  };
  const handleChange = (event) => {
    setPageType(event.target.value);
  };

  function renderSettingsForForum() {
    if (forumDashboard.length === 0) {
      return (
        <tr>
          <td> </td>
          <td> </td>
          <td> </td>
          <td></td>
          <td>No settings Found for forum</td>
          <td></td>
          <td></td>
          <td></td>
          <td></td>
        </tr>
      )
    } else {
      return forumDashboard.map((settingsList, index) => {
        return (
          <tr id={settingsList.nameType} key={settingsList.nameType}  >
            <td>{index + 1}</td>
            <td>{settingsList.nameType}</td>
            <td> <Switch
              checked={settingsList.guest}
              onChange={() => handleSwithChange(settingsList.nameType, settingsList.guest, "guest")}
              inputProps={{ 'aria-label': 'controlled' }}
            /></td>
            <td> <Switch
              checked={settingsList.free} 
              onChange={() => handleSwithChange(settingsList.nameType, settingsList.free, "free")}
              inputProps={{ 'aria-label': 'controlled' }}
            /></td>
            <td><Switch
              checked={settingsList.paid}
              onChange={() => handleSwithChange(settingsList.nameType, settingsList.paid, "paid")}
              inputProps={{ 'aria-label': 'controlled' }}
            /></td>
            <td ><Switch
              checked={settingsList.freeExpert}
              onChange={() => handleSwithChange(settingsList.nameType, settingsList.freeExpert, "freeExpert")}
              inputProps={{ 'aria-label': 'controlled' }}
            /></td>
                <td ><Switch
              checked={settingsList.paidExpert}
              onChange={() => handleSwithChange(settingsList.nameType, settingsList.paidExpert, "paidExpert")}
              inputProps={{ 'aria-label': 'controlled' }}
            /></td>
            <td ><Switch
              checked={settingsList.consultant}
              onChange={() => handleSwithChange(settingsList.nameType, settingsList.consultant, "consultant")}
              inputProps={{ 'aria-label': 'controlled' }}
            /></td>
            <td ><button className='button' onClick={() => removeSettings(settingsList.nameType)}>Delete</button></td>
          </tr>
        )
      })
    }
  };

  function renderSettingsForChat() {
    if (chatDashboard.length === 0) {
      return (
        <tr>
          <td> </td>
          <td> </td>
          <td></td>
          <td></td>
          <td>No settings Found for chat</td>
          <td></td>
          <td></td>
          <td></td>
        </tr>
      )
    } else {
      return chatDashboard.map((settingsList, index) => {
        return (
          <tr id={settingsList.nameType} key={settingsList.nameType}  >
            <td>{index + 1}</td>
            <td>{settingsList.nameType}</td>
            <td> <Switch
              checked={settingsList.guest}
              onChange={() => handleSwithChange(settingsList.nameType, settingsList.guest, "guest")}
              inputProps={{ 'aria-label': 'controlled' }}
            /></td>
            <td> <Switch
              checked={settingsList.free}
              onChange={() => handleSwithChange(settingsList.nameType, settingsList.free, "free")}
              inputProps={{ 'aria-label': 'controlled' }}
            /></td>
            <td><Switch
              checked={settingsList.paid}
              onChange={() => handleSwithChange(settingsList.nameType, settingsList.paid, "paid")}
              inputProps={{ 'aria-label': 'controlled' }}
            /></td>
            <td ><Switch
              checked={settingsList.freeExpert}
              onChange={() => handleSwithChange(settingsList.nameType, settingsList.freeExpert, "freeExpert")}
              inputProps={{ 'aria-label': 'controlled' }}
            /></td>
                    <td ><Switch
              checked={settingsList.paidExpert}
              onChange={() => handleSwithChange(settingsList.nameType, settingsList.paidExpert, "paidExpert")}
              inputProps={{ 'aria-label': 'controlled' }}
            /></td>
            <td ><Switch
              checked={settingsList.consultant}
              onChange={() => handleSwithChange(settingsList.nameType, settingsList.consultant, "consultant")}
              inputProps={{ 'aria-label': 'controlled' }}
            /></td>
            <td ><button className='button' onClick={() => removeSettings(settingsList.nameType)}>Delete</button></td>
          </tr>
        )
      })
    }
  };

  function renderSettingsForArticle() {
    if (articleDashboard.length === 0) {
      return (
        <tr>
          <td> </td>
          <td> </td>
          <td></td>
          <td></td>
          <td>No settings Found for article</td>
          <td></td>
          <td></td>
          <td></td>
        </tr>
      )
    } else {
      return articleDashboard.map((settingsList, index) => {
        return (
          <tr id={settingsList.nameType} key={settingsList.nameType}  >
            <td>{index + 1}</td>
            <td>{settingsList.nameType}</td>
            <td> <Switch
              checked={settingsList.guest}
              onChange={() => handleSwithChange(settingsList.nameType, settingsList.guest, "guest")}
              inputProps={{ 'aria-label': 'controlled' }}
            /></td>
            <td> <Switch
              checked={settingsList.free}
              onChange={() => handleSwithChange(settingsList.nameType, settingsList.free, "free")}
              inputProps={{ 'aria-label': 'controlled' }}
            /></td>
            <td><Switch
              checked={settingsList.paid}
              onChange={() => handleSwithChange(settingsList.nameType, settingsList.paid, "paid")}
              inputProps={{ 'aria-label': 'controlled' }}
            /></td>
            <td ><Switch
              checked={settingsList.freeExpert}
              onChange={() => handleSwithChange(settingsList.nameType, settingsList.freeExpert, "freeExpert")}
              inputProps={{ 'aria-label': 'controlled' }}
            /></td>
                   <td ><Switch
              checked={settingsList.paidExpert}
              onChange={() => handleSwithChange(settingsList.nameType, settingsList.paidExpert, "paidExpert")}
              inputProps={{ 'aria-label': 'controlled' }}
            /></td>
            <td ><Switch
              checked={settingsList.consultant}
              onChange={() => handleSwithChange(settingsList.nameType, settingsList.consultant, "consultant")}
              inputProps={{ 'aria-label': 'controlled' }}
            /></td>
            <td ><button className='button' onClick={() => removeSettings(settingsList.nameType)}>Delete</button></td>
          </tr>
        )
      })
    }
  };

  return (
    <>
      {show ? <div className="modelbox2">

        <div className="login2">
          <div className="loginWrapper2">

            <div className="loginRight2">
              <form className="loginBox2" onSubmit={handleClick}>
                <div>
                  Forum <Radio
                    checked={pageType === 'forum'}
                    onChange={handleChange}
                    value="forum"
                    name="radio-buttons"
                    inputProps={{ 'aria-label': 'Forum' }}
                  />
                  Chat <Radio
                    checked={pageType === 'chat'}
                    onChange={handleChange}
                    value="chat"
                    name="radio-buttons"
                    inputProps={{ 'aria-label': 'Chat' }}
                  />
                  article <Radio
                    checked={pageType === 'article'}
                    onChange={handleChange}
                    value="article"
                    name="radio-buttons"
                    inputProps={{ 'aria-label': 'article' }}
                  />
                </div>
                <input
                  placeholder="Name"
                  required
                  ref={nameType}
                  className="loginInput2"
                />

                <button className="loginButton2" type="submit">
                  Create
                </button>
              </form>
              <button className="loginButton12 " onClick={handleClose}>
                Close
              </button>
            </div>
          </div>
        </div>

      </div> :
        <div>
          <button className="loginButton2 adduserbutton2" onClick={handleShow} type="submit">
            Add settings
          </button>
          <div>
            <h1 id='title'>Welcome to Dashboard</h1>
            <h2>Forum</h2>
            <table id='settingslist'>
              <thead>
                <tr>{renderHeader()}</tr>
              </thead>
              <tbody>
                {renderSettingsForForum()}
              </tbody>
            </table>
            <h2>Chat</h2>
            <table id='settingslist'>
              <thead>
                <tr>{renderHeader()}</tr>
              </thead>
              <tbody>
                {renderSettingsForChat()}
              </tbody>
            </table>
            <h2>Article</h2>
            <table id='settingslist'>
              <thead>
                <tr>{renderHeader()}</tr>
              </thead>
              <tbody>
                {renderSettingsForArticle()}
              </tbody>
            </table>
          </div>

        </div>}
    </>
  );
}
