import React, { useEffect,useState } from "react";
import PopularQuestions from "../../components/popularActivity/PopularQuestions";
import Banner from "../../components/banner/Banner";
import {  Group } from "@material-ui/icons";
import NewspaperIcon from '@mui/icons-material/Newspaper';
import axios from "axios";
import AddArticle from "../../components/NewsAndArticles/AddArticle";
import TablePagination from '@mui/material/TablePagination';
import SingleArticle from "../../components/NewsAndArticles/SingleArticle";
import PopularArticle from "../../components/popularActivity/PopularArticle";
import Ads from "../../components/popularActivity/Ads";

const NewsArticleContainer = () => {
    const [articles, setArticles] = useState([]);
    const [articleSize, setArticleSize] = useState()

    const [paginationArticle, setPaginationArticle] = useState([]);
    const [page, setPage] = useState(0);
    const [rowsPerPage, setRowsPerPage] = useState(10);

    const fetchArticles = async () => {
        try {
            var res = await axios.get(`${process.env.REACT_APP_BACKEND_URL}/api/newsandarticles`);
            var sortedList = await res.data.sort((p1, p2) => {
              return new Date(p2.createdAt) - new Date(p1.createdAt);
            })
            setArticles(sortedList);
            var startPage =page*rowsPerPage;
            var endPage= (page+1)*rowsPerPage;
            setPage(0);
            setArticleSize(sortedList.length);
            setPaginationArticle(sortedList.slice(startPage,endPage));
          } catch (err) {
            console.log(err)
          }
    }

    const handleChangePage = (event, newPage) => {
        setPage(newPage);
        var startPage =newPage*rowsPerPage;
        var endPage= (newPage+1)*rowsPerPage;
        setArticleSize(articles.length);
        setPaginationArticle(articles.slice(startPage,endPage));
      };
    
      const handleChangeRowsPerPage = (event) => {
        setRowsPerPage(parseInt(event.target.value, 10));
        setPage(0);
        var startPage =page*event.target.value;
        var endPage= (page+1)*event.target.value;
        setArticleSize(articles.length);
        setPaginationArticle(articles.slice(startPage,endPage));
      };

    useEffect(()=>{
        fetchArticles();
    },[]);
    return (
        <div>
            <div className="space_above">
                {/* <Banner /> */}
            </div>
            <div className="row articles_page_container" style={{"paddingTop" : "10px"}}>           
                <div className="col-sm-7 questionPart">
                    {/* <span className="forum_title">News and Articles</span> */}
                    <div className="row no-gutters d-flex align-items-center articleshadow article-search-cards article_search articleshadow article-search-cards">
                        <div className="col-sm-3">
                            <div className="questionBottomLeft blacktext">                                
                                <div className="question_user" style={{"marginLeft" : "15px"}}>
                                <span className="fontHeader">News </span>
                                {articles.length === 1 ? <span className="info_size">{articles.length} article</span> : <span className="info_size">{articles.length} articles</span>}
                                </div>
                            </div>
                        </div>
                        <div className="col-sm-9" style={{"padding": "5px"}}>
                        <AddArticle fetchData={fetchArticles}/>
                        </div>
                        
                    </div>   
                    {/* <div className="d-flex align-items-center articleshadow article-search-cards">
                        
                            <AddArticle fetchData={fetchArticles}/>
                            
                        </div>                  */}
                    <div>
                        {articles.length === 0 ? <></> : articles.map((a,idx)=>{
                            return (
                                <div className="row p-3" style={{"margin":"15px", "boxShadow":"0 6px 18px rgb(0 0 0 / 5%)","backgroundColor":"white","borderRadius":"10px"}}>
                                    <SingleArticle article = {a} key={idx} fetchData={fetchArticles}/>
                                </div>
                            )
                        })}
                        {/* <SingleArticle articles={articles}/> */}
                        <TablePagination 
                            component="div"
                            count={articleSize}
                            page={page}
                            onPageChange={handleChangePage}
                            rowsPerPage={rowsPerPage}
                            onRowsPerPageChange={handleChangeRowsPerPage}
                        />
                    </div>
                </div>
                <div className="col-3 popularPart">
                    {/* <span className="forum_title">Popular Activities</span> */}
                    <div className="stickLeft">
                    <PopularQuestions />
                    {/* <Ads /> */}
                    </div>
                    
                </div>
            </div>
        </div>
    );
}

export default NewsArticleContainer;