import React, { useEffect,useState } from "react";
import axios from "axios";
import AddArticle from "../../components/NewsAndArticles/AddArticle";
import TablePagination from '@mui/material/TablePagination';
import NewspaperIcon from '@mui/icons-material/Newspaper';
import PopularArticle from "../../components/popularActivity/PopularArticle";
import Ads from "../../components/popularActivity/Ads";

const PublicationsContainer = () => {
    const [articles, setArticles] = useState([]);
    const [articleSize, setArticleSize] = useState()

    const [paginationArticle, setPaginationArticle] = useState([]);
    const [page, setPage] = useState(0);
    const [rowsPerPage, setRowsPerPage] = useState(10);

    const fetchArticles = async () => {
        try {
            var res = await axios.get(`${process.env.REACT_APP_BACKEND_URL}/api/newsandarticles`);
            var sortedList = await res.data.sort((p1, p2) => {
              return new Date(p2.createdAt) - new Date(p1.createdAt);
            })
            setArticles(sortedList);
            var startPage =page*rowsPerPage;
            var endPage= (page+1)*rowsPerPage;
            setPage(0);
            setArticleSize(sortedList.length);
            setPaginationArticle(sortedList.slice(startPage,endPage));
          } catch (err) {
            console.log(err)
          }
    }

    const handleChangePage = (event, newPage) => {
        setPage(newPage);
        var startPage =newPage*rowsPerPage;
        var endPage= (newPage+1)*rowsPerPage;
        setArticleSize(articles.length);
        setPaginationArticle(articles.slice(startPage,endPage));
      };
    
      const handleChangeRowsPerPage = (event) => {
        setRowsPerPage(parseInt(event.target.value, 10));
        setPage(0);
        var startPage =page*event.target.value;
        var endPage= (page+1)*event.target.value;
        setArticleSize(articles.length);
        setPaginationArticle(articles.slice(startPage,endPage));
      };

    useEffect(()=>{
        fetchArticles();
    },[]);
    return (
        <div>
            <div className="space_above">
                {/* <Banner /> */}
            </div>
            <div className="row articles_page_container" style={{"paddingTop" : "10px"}}>           
                <div className="col-sm-9 ">
                    {/* <span className="forum_title">News and Articles</span> */}
                    <div className="row no-gutters d-flex align-items-center articleshadow article-search-cards article_search articleshadow article-search-cards">
                        <div className="col-sm-3">
                            <div className="questionBottomLeft blacktext">
                                <NewspaperIcon fontSize="medium" />
                                <div className="question_user">
                                <span className="fontHeader p-3">News </span>
                                <span className="info_size">221 News articles</span>
                                </div>
                            </div>
                        </div>
                        <div className="col-sm-9" style={{"padding": "5px"}}>
                        <input className="textgreyarea form-control search_bar" type="text" placeholder="Search by typing." />
                        </div>
                        
                    </div>   
                    <div className="d-flex align-items-center articleshadow article-search-cards">
                        
                            <AddArticle fetchData={fetchArticles}/>
                            
                        </div>                 
                    <div>
                        {/* {articles.length === 0 ? <></> : articles.map((a,idx)=>{
                            return (
                                <SingleArticle article = {a} key={idx} fetchData={fetchArticles}/>
                            )
                        })} */}
                        {/* <SingleArticle articles={articles}/> */}
                        <TablePagination 
                            component="div"
                            count={articleSize}
                            page={page}
                            onPageChange={handleChangePage}
                            rowsPerPage={rowsPerPage}
                            onRowsPerPageChange={handleChangeRowsPerPage}
                        />
                    </div>
                </div>
                <div className="col-3 ">
                    {/* <span className="forum_title">Popular Activities</span> */}
                    <div className="stickLeft mr-3">
                    <PopularArticle />
                    <Ads />
                    </div>
                    
                </div>
            </div>
        </div>
    );
}

export default PublicationsContainer;